# -*- coding: UTF-8 -*-
# Copyright 2008-2024 Rumma & Ko Ltd
# License: GNU Affero General Public License v3 (see file COPYING for details)
"""

Here is the script that was used in cosi3 to generate the following code::

    from lino.api.shell import *
    from pprint import pprint

    PLACES_IN_ESTONIA = []
    for obj in countries.Place.objects.filter(country__isocode="EE"):
        args = [obj.id, obj.name, obj.zip_code]
        if obj.parent is None:
            args.append(None)
        else:
            args.append(obj.parent.id)
        if obj.type is None:
            args.append(None)
        else:
            args.append(obj.type.name)
        PLACES_IN_ESTONIA.append(tuple(args))

    pprint(PLACES_IN_ESTONIA)


"""

from collections import namedtuple

fields = ['name', 'type', 'zip_code', 'parent', 'children']
Place = namedtuple("Place", fields)

unresolved_places = [(51, 'Harju', '', None, 'county'),
                     (52, 'Pärnu', '', None, 'county'),
                     (53, 'Rapla', '', None, 'county'),
                     (54, 'Vigala', '', 53, 'municipality'),
                     (55, 'Rapla', '', 53, 'town'),
                     (56, 'Tallinn', '', 51, 'town'),
                     (57, 'Kesklinn', '', 56, 'township'),
                     (58, 'Põhja-Tallinn', '', 56, 'township'),
                     (59, 'Pärnu', '', 52, 'town'),
                     (62, 'Ääsmäe', '', 51, 'town'),
                     (81, 'Haabersti', '', 56, 'township'),
                     (82, 'Kristiine', '', 56, 'township'),
                     (83, 'Lasnamäe', '', 56, 'township'),
                     (84, 'Mustamäe', '', 56, 'township'),
                     (85, 'Nõmme', '', 56, 'township'),
                     (86, 'Pirita', '', 56, 'township'),
                     (87, 'Loksa', '', 51, 'town'),
                     (88, 'Vasalemma', '', 51, 'municipality'),
                     (89, 'Rummu', '', 88, 'smallborough'),
                     (90, 'Veskiküla', '', 88, 'village'),
                     (91, 'Ämari', '', 88, 'smallborough'),
                     (92, 'Lemmaru', '76107', 88, 'village'),
                     (93, 'Nissi', '', 51, 'municipality'),
                     (94, 'Turba', '', 93, 'smallborough'),
                     (95, 'Lehetu', '', 93, 'village'),
                     (96, 'Madila', '', 93, 'village'),
                     (97, 'Riisipere', '', 93, 'smallborough'),
                     (98, 'Kivitammi', '76207', 93, 'village'),
                     (99, 'Mustu', '76216', 93, 'village'),
                     (100, 'Lepaste', '76217', 93, 'village'),
                     (101, 'Tabara', '', 93, 'village'),
                     (102, 'Viruküla', '76206', 93, 'village'),
                     (103, 'Odulemma', '76210', 93, 'village'),
                     (104, 'Ellamaa', '76203', 93, 'village'),
                     (105, 'Jaanika', '76211', 93, 'village'),
                     (106, 'Aude', '76209', 93, 'village'),
                     (107, 'Rehemäe', '76218', 93, 'village'),
                     (108, 'Ürjaste', '76214', 93, 'village'),
                     (109, 'Siimika', '76208', 93, 'village'),
                     (110, 'Nurme', '76215', 93, 'village'),
                     (111, 'Vilumäe', '76212', 93, 'village'),
                     (112, 'Munalaskme', '76318', 93, 'village'),
                     (113, 'Saku', '', 51, 'municipality'),
                     (114, 'Tänassilma', '', 113, 'village'),
                     (115, 'Üksnurme', '', 113, 'village'),
                     (116, 'Rahula', '', 113, 'village'),
                     (117, 'Roobuka', '', 113, 'village'),
                     (118, 'Jälgimäe', '', 113, 'village'),
                     (119, 'Kirdalu', '', 113, 'village'),
                     (120, 'Kasemetsa', '', 113, 'village'),
                     (121, 'Männiku', '', 113, 'village'),
                     (122, 'Tagadi', '', 113, 'village'),
                     (123, 'Kurtna', '', 113, 'village'),
                     (124, 'Metsanurme', '', 113, 'village'),
                     (125, 'Kiisa', '', 113, 'smallborough'),
                     (126, 'Juuliku', '', 113, 'village'),
                     (127, 'Tammejärve', '', 113, 'village'),
                     (128, 'Kanama', '', 113, 'village'),
                     (129, 'Saustinõmme', '', 113, 'village'),
                     (130, 'Tõdva', '', 113, 'village'),
                     (131, 'Lokuti', '', 113, 'village'),
                     (132, 'Tammemäe', '75509', 113, 'village'),
                     (133, 'Kajamaa', '75504', 113, 'village'),
                     (134, 'Sookaera-Metsanurga', '75515', 113, 'village'),
                     (135, 'Saue', '', 51, 'town'),
                     (136, 'Laagri', '', 135, 'smallborough'),
                     (137, 'Aila', '', 135, 'village'),
                     (138, 'Alliku', '', 135, 'village'),
                     (139, 'Ääsmäe', '', 135, 'village'),
                     (140, 'Vatsla', '', 135, 'village'),
                     (141, 'Hüüru', '', 135, 'village'),
                     (142, 'Vanamõisa', '', 135, 'village'),
                     (143, 'Jõgisoo', '', 135, 'village'),
                     (144, 'Püha', '', 135, 'village'),
                     (145, 'Maidla', '', 135, 'village'),
                     (146, 'Valingu', '', 135, 'village'),
                     (147, 'Koppelmaa', '', 135, 'village'),
                     (148, 'Tuula', '', 135, 'village'),
                     (149, 'Pällu', '', 135, 'village'),
                     (150, 'Kiia', '', 135, 'village'),
                     (151, 'Tagametsa', '76409', 135, 'village'),
                     (152, 'Pärinurme', '76408', 135, 'village'),
                     (153, 'Koidu', '76418', 135, 'village'),
                     (154, 'Viimsi', '', 51, 'municipality'),
                     (155, 'Püünsi', '', 154, 'village'),
                     (156, 'Pringi', '', 154, 'village'),
                     (157, 'Muuga', '', 154, 'village'),
                     (158, 'Haabneeme', '', 154, 'smallborough'),
                     (159, 'Laiaküla', '', 154, 'village'),
                     (160, 'Lubja', '', 154, 'village'),
                     (161, 'Rohuneeme', '', 154, 'village'),
                     (162, 'Pärnamäe', '', 154, 'village'),
                     (163, 'Tammneeme', '', 154, 'village'),
                     (164, 'Leppneeme', '', 154, 'village'),
                     (165, 'Metsakasti', '', 154, 'village'),
                     (166, 'Randvere', '', 154, 'village'),
                     (167, 'Miiduranna', '', 154, 'village'),
                     (168, 'Kelvingi', '', 154, 'village'),
                     (169, 'Äigrumäe', '', 154, 'village'),
                     (170, 'Kelnase', '', 154, 'village'),
                     (171, 'Lõunaküla/Storbyn', '74022', 154, 'village'),
                     (172, 'Tagaküla/Bakbyn', '74023', 154, 'village'),
                     (173, 'Lääneotsa', '74007', 154, 'village'),
                     (174, 'Väikeheinamaa/Lillängin', '74024', 154, 'village'),
                     (175, 'Idaotsa', '74005', 154, 'village'),
                     (176, 'Raasiku', '', 51, 'municipality'),
                     (177, 'Aruküla', '', 176, 'smallborough'),
                     (178, 'Kurgla', '', 176, 'village'),
                     (179, 'Kalesi', '', 176, 'village'),
                     (180, 'Kiviloo', '', 176, 'village'),
                     (181, 'Perila', '', 176, 'village'),
                     (182, 'Peningi', '', 176, 'village'),
                     (183, 'Igavere', '', 176, 'village'),
                     (184, 'Kulli', '', 176, 'village'),
                     (185, 'Rätla', '75216', 176, 'village'),
                     (186, 'Järsi', '75204', 176, 'village'),
                     (187, 'Pikavere', '75202', 176, 'village'),
                     (188, 'Härma', '75214', 176, 'village'),
                     (189, 'Tõhelgi', '75223', 176, 'village'),
                     (190, 'Mallavere', '75210', 176, 'village'),
                     (191, 'Jõelähtme', '', 51, 'municipality'),
                     (192, 'Loo', '', 191, 'smallborough'),
                     (193, 'Jägala', '', 191, 'village'),
                     (194, 'Kaberneeme', '', 191, 'village'),
                     (195, 'Liivamäe', '', 191, 'village'),
                     (196, 'Neeme', '', 191, 'village'),
                     (197, 'Manniva', '', 191, 'village'),
                     (198, 'Uusküla', '', 191, 'village'),
                     (199, 'Ülgase', '', 191, 'village'),
                     (200, 'Ihasalu', '', 191, 'village'),
                     (201, 'Kallavere', '', 191, 'village'),
                     (202, 'Kostivere', '', 191, 'smallborough'),
                     (203, 'Iru', '', 191, 'village'),
                     (204, 'Haljava', '', 191, 'village'),
                     (205, 'Koogi', '', 191, 'village'),
                     (206, 'Saviranna', '', 191, 'village'),
                     (207, 'Saha', '', 191, 'village'),
                     (208, 'Rebala', '', 191, 'village'),
                     (209, 'Ruu', '', 191, 'village'),
                     (210, 'Koipsi', '74215', 191, 'village'),
                     (211, 'Rammu', '74227', 191, 'village'),
                     (212, 'Aruaru', '75225', 191, 'village'),
                     (213, 'Võerdla', '74221', 191, 'village'),
                     (214, 'Vandjala', '74229', 191, 'village'),
                     (215, 'Sambu', '75222', 191, 'village'),
                     (216, 'Rohusi', '74219', 191, 'village'),
                     (217, 'Kullamäe', '74218', 191, 'village'),
                     (218, 'Kostiranna', '74225', 191, 'village'),
                     (219, 'Parasmäe', '74230', 191, 'village'),
                     (220, 'Nehatu', '74208', 191, 'village'),
                     (221, 'Koila', '74214', 191, 'village'),
                     (222, 'Maardu', '', 51, 'town'),
                     (223, 'Rae', '', 51, 'municipality'),
                     (224, 'Vaida', '', 223, 'smallborough'),
                     (225, 'Jüri', '', 223, 'smallborough'),
                     (226, 'Patika', '', 223, 'village'),
                     (227, 'Lehmja', '', 223, 'village'),
                     (228, 'Vaskjala', '', 223, 'village'),
                     (229, 'Järveküla', '', 223, 'village'),
                     (230, 'Aaviku', '', 223, 'village'),
                     (231, 'Pajupea', '', 223, 'village'),
                     (232, 'Tuulevälja', '', 223, 'village'),
                     (233, 'Peetri', '', 223, 'smallborough'),
                     (234, 'Lagedi', '', 223, 'smallborough'),
                     (235, 'Karla', '', 223, 'village'),
                     (236, 'Pildiküla', '', 223, 'village'),
                     (237, 'Soodevahe', '', 223, 'village'),
                     (238, 'Kadaka', '', 223, 'village'),
                     (239, 'Ülejõe', '', 223, 'village'),
                     (240, 'Suuresta', '', 223, 'village'),
                     (241, 'Assaku', '', 223, 'smallborough'),
                     (242, 'Veskitaguse', '', 223, 'village'),
                     (243, 'Suursoo', '', 223, 'village'),
                     (244, 'Veneküla', '', 223, 'village'),
                     (245, 'Kurna', '', 223, 'village'),
                     (246, 'Kopli', '', 223, 'village'),
                     (247, 'Urvaste', '', 223, 'village'),
                     (248, 'Salu', '', 223, 'village'),
                     (249, 'Limu', '', 223, 'village'),
                     (250, 'Vaidasoo', '', 223, 'village'),
                     (251, 'Seli', '75311', 223, 'village'),
                     (252, 'Kautjala', '75315', 223, 'village'),
                     (253, 'Aruvalla', '75320', 223, 'village'),
                     (254, 'Harku', '', 51, 'municipality'),
                     (255, 'Tabasalu', '', 254, 'smallborough'),
                     (256, 'Adra', '', 254, 'village'),
                     (257, 'Liikva', '', 254, 'village'),
                     (258, 'Tiskre', '', 254, 'village'),
                     (259, 'Naage', '', 254, 'village'),
                     (260, 'Ilmandu', '', 254, 'village'),
                     (261, 'Muraste', '', 254, 'village'),
                     (262, 'Suurupi', '', 254, 'village'),
                     (263, 'Harkujärve', '', 254, 'village'),
                     (264, 'Rannamõisa', '', 254, 'village'),
                     (265, 'Viti', '', 254, 'village'),
                     (266, 'Türisalu', '', 254, 'village'),
                     (267, 'Kumna', '', 254, 'village'),
                     (268, 'Laabi', '', 254, 'village'),
                     (269, 'Tutermaa', '', 254, 'village'),
                     (270, 'Sõrve', '', 254, 'village'),
                     (271, 'Kütke', '', 254, 'village'),
                     (272, 'Vaila', '', 254, 'village'),
                     (273, 'Vääna', '', 254, 'village'),
                     (274, 'Vääna-Jõesuu', '', 254, 'village'),
                     (275, 'Vahi', '', 254, 'village'),
                     (276, 'Humala', '76707', 254, 'village'),
                     (277, 'Keila', '', 51, 'municipality'),
                     (278, 'Kloogaranna', '', 277, 'village'),
                     (279, 'Klooga', '', 277, 'smallborough'),
                     (280, 'Lehola', '', 277, 'village'),
                     (281, 'Maeru', '', 277, 'village'),
                     (282, 'Laulasmaa', '', 277, 'village'),
                     (283, 'Ohtu', '', 277, 'village'),
                     (284, 'Kulna', '', 277, 'village'),
                     (285, 'Illurma', '', 277, 'village'),
                     (286, 'Tuulna', '', 277, 'village'),
                     (287, 'Meremõisa', '', 277, 'village'),
                     (288, 'Valkse', '', 277, 'village'),
                     (289, 'Keila-Joa', '', 277, 'smallborough'),
                     (290, 'Karjaküla', '', 277, 'smallborough'),
                     (291, 'Lohusalu', '', 277, 'village'),
                     (292, 'Käesalu', '', 277, 'village'),
                     (293, 'Niitvälja', '', 277, 'village'),
                     (294, 'Tõmmiku', '76619', 277, 'village'),
                     (295, 'Laoküla', '76714', 277, 'village'),
                     (296, 'Nahkjala', '76104', 277, 'village'),
                     (297, 'Põllküla', '76712', 277, 'village'),
                     (298, 'Keelva', '76622', 277, 'village'),
                     (299, 'Anija', '', 51, 'municipality'),
                     (300, 'Kehra', '', 51, 'town'),
                     (301, 'Lükati', '', 300, 'village'),
                     (302, 'Alavere', '', 300, 'village'),
                     (303, 'Mustjõe', '', 300, 'village'),
                     (304, 'Pillapalu', '', 300, 'village'),
                     (305, 'Lehtmetsa', '', 300, 'village'),
                     (306, 'Kuusemäe', '', 300, 'village'),
                     (307, 'Soodla', '', 300, 'village'),
                     (308, 'Parila', '75221', 300, 'village'),
                     (309, 'Aavere', '74417', 300, 'village'),
                     (310, 'Paasiku', '74314', 300, 'village'),
                     (311, 'Salumetsa', '74312', 300, 'village'),
                     (312, 'Kihmla', '75219', 300, 'village'),
                     (313, 'Looküla', '74311', 300, 'village'),
                     (314, 'Rasivere', '74403', 300, 'village'),
                     (315, 'Voose', '74410', 300, 'village'),
                     (316, 'Linnakse', '75220', 300, 'village'),
                     (317, 'Arava', '74405', 300, 'village'),
                     (318, 'Partsaare', '74415', 300, 'village'),
                     (319, 'Uuearu', '74407', 300, 'village'),
                     (320, 'Salumäe', '75226', 300, 'village'),
                     (321, 'Kaunissaare', '74309', 300, 'village'),
                     (322, 'Vetla', '74408', 300, 'village'),
                     (323, 'Pikva', '', 300, 'village'),
                     (324, 'Raudoja', '74416', 300, 'village'),
                     (325, 'Rooküla', '74404', 300, 'village'),
                     (326, 'Härmakosu', '74412', 300, 'village'),
                     (327, 'Lilli', '74414', 300, 'village'),
                     (328, 'Kiili', '', 51, 'municipality'),
                     (329, 'Luige', '', 328, 'smallborough'),
                     (330, 'Sausti', '', 328, 'village'),
                     (331, 'Kangru', '', 328, 'smallborough'),
                     (332, 'Nabala', '', 328, 'village'),
                     (333, 'Sookaera', '', 328, 'village'),
                     (334, 'Vaela', '', 328, 'village'),
                     (335, 'Lähtse', '', 328, 'village'),
                     (336, 'Mõisaküla', '', 328, 'village'),
                     (337, 'Sõgula', '75410', 328, 'village'),
                     (338, 'Kurevere', '75405', 328, 'village'),
                     (339, 'Paekna', '75408', 328, 'village'),
                     (340, 'Arusta', '75402', 328, 'village'),
                     (341, 'Piissoo', '75414', 328, 'village'),
                     (342, 'Paldiski', '', 51, 'town'),
                     (343, 'Kose', '', 51, 'municipality'),
                     (344, 'Kose-Uuemõisa', '', 343, 'smallborough'),
                     (345, 'Oru', '', 343, 'village'),
                     (346, 'Tade', '', 343, 'village'),
                     (347, 'Liiva', '', 343, 'village'),
                     (348, 'Ravila', '', 343, 'smallborough'),
                     (349, 'Tuhala', '', 343, 'village'),
                     (350, 'Saula', '', 343, 'village'),
                     (351, 'Ahisilla', '', 343, 'village'),
                     (352, 'Krei', '', 343, 'village'),
                     (353, 'Palvere', '', 343, 'village'),
                     (354, 'Vardja', '', 343, 'village'),
                     (355, 'Nõmbra', '', 343, 'village'),
                     (356, 'Viskla', '', 343, 'village'),
                     (357, 'Sõmeru', '', 343, 'village'),
                     (358, 'Tammiku', '75119', 343, 'village'),
                     (359, 'Nõrava', '75116', 343, 'village'),
                     (360, 'Raveliku', '75112', 343, 'village'),
                     (361, 'Vilama', '75110', 343, 'village'),
                     (362, 'Kata', '75120', 343, 'village'),
                     (363, 'Kolu', '75121', 343, 'village'),
                     (364, 'Kuivajõe', '75123', 343, 'village'),
                     (365, 'Võlle', '75109', 343, 'village'),
                     (366, 'Kanavere', '75105', 343, 'village'),
                     (367, 'Padise', '', 51, 'municipality'),
                     (368, 'Madise', '', 367, 'village'),
                     (369, 'Kurkse', '', 367, 'village'),
                     (370, 'Harju-Risti', '', 367, 'village'),
                     (371, 'Kõmmaste', '76016', 367, 'village'),
                     (372, 'Keibu', '76019', 367, 'village'),
                     (373, 'Vintse', '76021', 367, 'village'),
                     (374, 'Alliklepa', '76018', 367, 'village'),
                     (375, 'Määra', '76010', 367, 'village'),
                     (376, 'Vihterpalu', '76003', 367, 'village'),
                     (377, 'Audevälja', '76005', 367, 'village'),
                     (378, 'Altküla', '76012', 367, 'village'),
                     (379, 'Vilivalla', '76020', 367, 'village'),
                     (380, 'Pae', '76015', 367, 'village'),
                     (381, 'Hatu', '76013', 367, 'village'),
                     (382, 'Metslõugu', '76009', 367, 'village'),
                     (383, 'Langa', '76711', 367, 'village'),
                     (384, 'Laane', '', 367, 'village'),
                     (385, 'Kasepere', '76007', 367, 'village'),
                     (386, 'Pedase', '76014', 367, 'village'),
                     (387, 'Änglema', '76022', 367, 'village'),
                     (388, 'Karilepa', '76006', 367, 'village'),
                     (389, 'Suurküla', '76011', 367, 'village'),
                     (390, 'Kobru', '76004', 367, 'village'),
                     (391, 'Kõue', '', 51, 'municipality'),
                     (392, 'Ardu', '', 391, 'smallborough'),
                     (393, 'Habaja', '', 391, 'smallborough'),
                     (394, 'Harmi', '75034', 391, 'village'),
                     (395, 'Virla', '75021', 391, 'village'),
                     (396, 'Paunaste', '75025', 391, 'village'),
                     (397, 'Aela', '75004', 391, 'village'),
                     (398, 'Katsina', '75005', 391, 'village'),
                     (399, 'Rõõsa', '75015', 391, 'village'),
                     (400, 'Kadja', '75003', 391, 'village'),
                     (401, 'Saarnakõrve', '75023', 391, 'village'),
                     (402, 'Kantküla', '75027', 391, 'village'),
                     (403, 'Vahetüki', '75020', 391, 'village'),
                     (404, 'Uueveski', '75037', 391, 'village'),
                     (405, 'Sae', '75016', 391, 'village'),
                     (406, 'Kukepala', '75010', 391, 'village'),
                     (407, 'Puusepa', '75017', 391, 'village'),
                     (408, 'Kõrvenurga', '75008', 391, 'village'),
                     (409, 'Kiruvere', '75006', 391, 'village'),
                     (410, 'Nutu', '75012', 391, 'village'),
                     (411, 'Alansi', '75035', 391, 'village'),
                     (412, 'Lutsu', '75030', 391, 'village'),
                     (413, 'Kirivalla', '75036', 391, 'village'),
                     (414, 'Paunküla', '75011', 391, 'village'),
                     (415, 'Riidamäe', '75032', 391, 'village'),
                     (416, 'Äksi', '75038', 391, 'village'),
                     (417, 'Silmsi', '75024', 391, 'village'),
                     (418, 'Ojasoo', '75031', 391, 'village'),
                     (419, 'Rava', '75014', 391, 'village'),
                     (420, 'Sääsküla', '75033', 391, 'village'),
                     (421, 'Lööra', '75028', 391, 'village'),
                     (422, 'Leistu', '75026', 391, 'village'),
                     (423, 'Marguse', '75029', 391, 'village'),
                     (424, 'Triigi', '75019', 391, 'village'),
                     (425, 'Nõmmeri', '75013', 391, 'village'),
                     (426, 'Kuusalu', '', 51, 'municipality'),
                     (427, 'Kolga', '', 426, 'smallborough'),
                     (428, 'Kiiu', '', 426, 'smallborough'),
                     (429, 'Valkla', '', 426, 'village'),
                     (430, 'Viinistu', '', 426, 'village'),
                     (431, 'Kaberla', '', 426, 'village'),
                     (432, 'Mäepea', '', 426, 'village'),
                     (433, 'Sõitme', '', 426, 'village'),
                     (434, 'Uuri', '', 426, 'village'),
                     (435, 'Mustametsa', '', 426, 'village'),
                     (436, 'Kolga-Aabla', '', 426, 'village'),
                     (437, 'Salmistu', '', 426, 'village'),
                     (438, 'Kiiu-Aabla', '', 426, 'village'),
                     (439, 'Vihasoo', '', 426, 'village'),
                     (440, 'Kõnnu', '', 426, 'village'),
                     (441, 'Allika', '', 426, 'village'),
                     (442, 'Leesi', '', 426, 'village'),
                     (443, 'Suurpea', '74812', 426, 'village'),
                     (444, 'Saunja', '74636', 426, 'village'),
                     (445, 'Valgejõe', '74712', 426, 'village'),
                     (446, 'Haavakannu', '74628', 426, 'village'),
                     (447, 'Nõmmeveski', '74815', 426, 'village'),
                     (448, 'Tapurla', '74721', 426, 'village'),
                     (449, 'Kemba', '74708', 426, 'village'),
                     (450, 'Kodasoo', '74632', 426, 'village'),
                     (451, 'Virve', '74814', 426, 'village'),
                     (452, 'Hirvli', '74607', 426, 'village'),
                     (453, 'Parksi', '74710', 426, 'village'),
                     (454, 'Tsitre', '74616', 426, 'village'),
                     (455, 'Tõreska', '74617', 426, 'village'),
                     (456, 'Koitjärve', '74622', 426, 'village'),
                     (457, 'Tammispea', '74715', 426, 'village'),
                     (458, 'Põhja', '74635', 426, 'village'),
                     (459, 'Muuksi', '74612', 426, 'village'),
                     (460, 'Suru', '74615', 426, 'village'),
                     (461, 'Kalme', '74714', 426, 'village'),
                     (462, 'Juminda', '74716', 426, 'village'),
                     (463, 'Pala', '', 426, 'village'),
                     (464, 'Kolgaküla', '74808', 426, 'village'),
                     (465, 'Tammistu', '74719', 426, 'village'),
                     (466, 'Hara', '74810', 426, 'village'),
                     (467, 'Pärispea', '74706', 426, 'village'),
                     (468, 'Liiapeksi', '74709', 426, 'village'),
                     (469, 'Pudisoo', '74626', 426, 'village'),
                     (470, 'Murksi', '74713', 426, 'village'),
                     (471, 'Joaveski', '74813', 426, 'village'),
                     (472, 'Kahala', '74621', 426, 'village'),
                     (473, 'Aru', '74606', 426, 'village'),
                     (474, 'Turbuneeme', '74707', 426, 'village'),
                     (475, 'Kursi', '74611', 426, 'village'),
                     (476, 'Pedaspea', '74718', 426, 'village'),
                     (477, 'Kolgu', '74618', 426, 'village'),
                     (478, 'Kasispea', '74811', 426, 'village'),
                     (479, 'Rehatse', '74624', 426, 'village'),
                     (480, 'Kosu', '74608', 426, 'village'),
                     (481, 'Vanaküla', '74711', 426, 'village'),
                     (482, 'Ilmastalu', '74619', 426, 'village'),
                     (483, 'Sigula', '74625', 426, 'village'),
                     (484, 'Kotka', '74809', 426, 'village'),
                     (485, 'Soorinna', '74614', 426, 'village'),
                     (486, 'Külmaallika', '74634', 426, 'village'),
                     (487, 'Kupu', '74610', 426, 'village'),
                     (488, 'Kernu', '', 51, 'municipality'),
                     (489, 'Laitse', '', 488, 'village'),
                     (490, 'Haiba', '', 488, 'village'),
                     (491, 'Ruila', '', 488, 'village'),
                     (492, 'Kustja', '', 488, 'village'),
                     (493, 'Mõnuste', '76310', 488, 'village'),
                     (494, 'Kirikla', '76306', 488, 'village'),
                     (495, 'Kabila', '', 488, 'village'),
                     (496, 'Metsanurga', '', 488, 'village'),
                     (497, 'Hingu', '76312', 488, 'village'),
                     (498, 'Kohatu', '76304', 488, 'village'),
                     (499, 'Muusika', '76309', 488, 'village'),
                     (500, 'Aegviidu', '', 51, 'municipality'),
                     (501, 'Kaasiku', '', 51, 'municipality'),
                     (502, 'Kibuna', '', 51, 'municipality'),
                     (503, 'Vahastu', '', 51, 'municipality'),
                     (504, 'Vansi', '', 51, 'municipality'),
                     (505, 'Vikipalu', '', 51, 'municipality'),
                     (506, 'Jägala-Joa', '', 51, 'municipality'),
                     (507, 'Kersalu', '', 51, 'municipality'),
                     (508, 'Haapse', '', 51, 'municipality'),
                     (509, 'Jõesuu', '', 51, 'municipality'),
                     (510, 'Pohla', '', 51, 'municipality'),
                     (511, 'Andineeme', '', 51, 'municipality'),
                     (512, 'Hiiu', '', None, 'county'),
                     (513, 'Kärdla', '', 512, 'town'),
                     (514, 'Käina', '', 512, 'municipality'),
                     (515, 'Nõmme', '', 514, 'village'),
                     (516, 'Selja', '', 514, 'village'),
                     (517, 'Putkaste', '', 514, 'village'),
                     (518, 'Lelu', '', 514, 'village'),
                     (519, 'Ligema', '', 514, 'village'),
                     (520, 'Ühtri', '', 514, 'village'),
                     (521, 'Niidiküla', '92131', 514, 'village'),
                     (522, 'Kaigutsi', '92164', 514, 'village'),
                     (523, 'Ristivälja', '92135', 514, 'village'),
                     (524, 'Nasva', '92130', 514, 'village'),
                     (525, 'Mäeküla', '92116', 514, 'village'),
                     (526, 'Vaemla', '92137', 514, 'village'),
                     (527, 'Mäeltse', '92129', 514, 'village'),
                     (528, 'Orjaku', '', 514, 'village'),
                     (529, 'Kolga', '92126', 514, 'village'),
                     (530, 'Taterma', '92174', 514, 'village'),
                     (531, 'Kogri', '92125', 514, 'village'),
                     (532, 'Moka', '92128', 514, 'village'),
                     (533, 'Aadma', '92161', 514, 'village'),
                     (534, 'Taguküla', '92112', 514, 'village'),
                     (535, 'Jõeküla', '92118', 514, 'village'),
                     (536, 'Kuriste', '92171', 514, 'village'),
                     (537, 'Utu', '92136', 514, 'village'),
                     (538, 'Kaasiku', '92123', 514, 'village'),
                     (539, 'Esiküla', '92113', 514, 'village'),
                     (540, 'Laheküla', '92115', 514, 'village'),
                     (541, 'Luguse', '92127', 514, 'village'),
                     (542, 'Kleemu', '92124', 514, 'village'),
                     (543, 'Kassari', '92111', 514, 'village'),
                     (544, 'Villemi', '92138', 514, 'village'),
                     (545, 'Männamaa', '92102', 514, 'village'),
                     (546, 'Pärnselja', '92162', 514, 'village'),
                     (547, 'Nõmmerga', '92133', 514, 'village'),
                     (548, 'Allika', '92122', 514, 'village'),
                     (549, 'Kõrgessaare', '', 512, 'municipality'),
                     (550, 'Tahkuna', '', 549, 'village'),
                     (551, 'Lauka', '', 549, 'village'),
                     (552, 'Ülendi', '92229', 549, 'village'),
                     (553, 'Risti', '92224', 549, 'village'),
                     (554, 'Metsaküla', '92249', 549, 'village'),
                     (555, 'Kidaste', '92216', 549, 'village'),
                     (556, 'Kiduspe', '92234', 549, 'village'),
                     (557, 'Hüti', '92243', 549, 'village'),
                     (558, 'Heigi', '92241', 549, 'village'),
                     (559, 'Kopa', '92255', 549, 'village'),
                     (560, 'Laasi', '92231', 549, 'village'),
                     (561, 'Poama', '92259', 549, 'village'),
                     (562, 'Kodeste', '92217', 549, 'village'),
                     (563, 'Mangu', '92220', 549, 'village'),
                     (564, 'Mudaste', '92222', 549, 'village'),
                     (565, 'Hirmuste', '92228', 549, 'village'),
                     (566, 'Kalana', '92230', 549, 'village'),
                     (567, 'Mardihansu', '92256', 549, 'village'),
                     (568, 'Ogandi', '92223', 549, 'village'),
                     (569, 'Vilima', '92237', 549, 'village'),
                     (570, 'Sülluste', '92252', 549, 'village'),
                     (571, 'Puski', '92260', 549, 'village'),
                     (572, 'Lilbi', '92248', 549, 'village'),
                     (573, 'Koidma', '92218', 549, 'village'),
                     (574, 'Kurisu', '', 549, 'village'),
                     (575, 'Pihla', '92264', 549, 'village'),
                     (576, 'Kaleste', '92232', 549, 'village'),
                     (577, 'Kiivera', '92254', 549, 'village'),
                     (578, 'Heistesoo', '92270', 549, 'village'),
                     (579, 'Kauste', '92215', 549, 'village'),
                     (580, 'Reigi', '92265', 549, 'village'),
                     (581, 'Sigala', '92213', 549, 'village'),
                     (582, 'Tiharu', '92269', 549, 'village'),
                     (583, 'Palli', '92258', 549, 'village'),
                     (584, 'Lehtma', '92219', 549, 'village'),
                     (585, 'Isabella', '92244', 549, 'village'),
                     (586, 'Napi', '92250', 549, 'village'),
                     (587, 'Mägipe', '92233', 549, 'village'),
                     (588, 'Villamaa', '92261', 549, 'village'),
                     (589, 'Meelste', '92221', 549, 'village'),
                     (590, 'Viita', '92227', 549, 'village'),
                     (591, 'Ojaküla', '92235', 549, 'village'),
                     (592, 'Viitasoo', '92238', 549, 'village'),
                     (593, 'Malvaste', '92211', 549, 'village'),
                     (594, 'Suurepsi', '92236', 549, 'village'),
                     (595, 'Heiste', '92242', 549, 'village'),
                     (596, 'Suureranna', '92225', 549, 'village'),
                     (597, 'Leigri', '92247', 549, 'village'),
                     (598, 'Luidja', '92202', 549, 'village'),
                     (599, 'Rootsi', '92266', 549, 'village'),
                     (600, 'Jõeranna', '92263', 549, 'village'),
                     (601, 'Paope', '92267', 549, 'village'),
                     (602, 'Kõpu', '92212', 549, 'village'),
                     (603, 'Jõesuu', '92253', 549, 'village'),
                     (604, 'Kanapeeksi', '92214', 549, 'village'),
                     (605, 'Otste', '92251', 549, 'village'),
                     (606, 'Tammistu', '92268', 549, 'village'),
                     (607, 'Pühalepa', '', 512, 'municipality'),
                     (608, 'Hausma', '', 607, 'village'),
                     (609, 'Suuremõisa', '', 607, 'village'),
                     (610, 'Kuri', '', 607, 'village'),
                     (611, 'Loja', '', 607, 'village'),
                     (612, 'Tareste', '', 607, 'village'),
                     (613, 'Hiiessaare', '', 607, 'village'),
                     (614, 'Salinõmme', '92317', 607, 'village'),
                     (615, 'Sarve', '92322', 607, 'village'),
                     (616, 'Lõbembe', '92340', 607, 'village'),
                     (617, 'Reikama', '92344', 607, 'village'),
                     (618, 'Harju', '', 607, 'village'),
                     (619, 'Hagaste', '92332', 607, 'village'),
                     (620, 'Kerema', '92315', 607, 'village'),
                     (621, 'Lõpe', '92341', 607, 'village'),
                     (622, 'Määvli', '92362', 607, 'village'),
                     (623, 'Suuresadama', '92346', 607, 'village'),
                     (624, 'Partsi', '92342', 607, 'village'),
                     (625, 'Soonlepa', '92323', 607, 'village'),
                     (626, 'Tubala', '92311', 607, 'village'),
                     (627, 'Viilupi', '92320', 607, 'village'),
                     (628, 'Valipe', '92319', 607, 'village'),
                     (629, 'Värssu', '92349', 607, 'village'),
                     (630, 'Kalgi', '92314', 607, 'village'),
                     (631, 'Leerimetsa', '92361', 607, 'village'),
                     (632, 'Pilpaküla', '92368', 607, 'village'),
                     (633, 'Ala', '92331', 607, 'village'),
                     (634, 'Prählamäe', '92364', 607, 'village'),
                     (635, 'Vilivalla', '92367', 607, 'village'),
                     (636, 'Linnumäe', '92422', 607, 'village'),
                     (637, 'Sakla', '92345', 607, 'village'),
                     (638, 'Vahtrepa', '92318', 607, 'village'),
                     (639, 'Undama', '92366', 607, 'village'),
                     (640, 'Kõlunõmme', '92338', 607, 'village'),
                     (641, 'Aruküla', '92321', 607, 'village'),
                     (642, 'Sääre', '92347', 607, 'village'),
                     (643, 'Hilleste', '92313', 607, 'village'),
                     (644, 'Nõmba', '92363', 607, 'village'),
                     (645, 'Hellamaa', '92334', 607, 'village'),
                     (646, 'Paluküla', '92420', 607, 'village'),
                     (647, 'Palade', '92301', 607, 'village'),
                     (648, 'Kukka', '92336', 607, 'village'),
                     (649, 'Puliste', '92343', 607, 'village'),
                     (650, 'Tempa', '92348', 607, 'village'),
                     (651, 'Heltermaa', '92312', 607, 'village'),
                     (652, 'Tammela', '92365', 607, 'village'),
                     (653, 'Emmaste', '', 512, 'municipality'),
                     (654, 'Kaderna', '92045', 653, 'village'),
                     (655, 'Reheselja', '92019', 653, 'village'),
                     (656, 'Lepiku', '92014', 653, 'village'),
                     (657, 'Lassi', '92051', 653, 'village'),
                     (658, 'Hindu', '92012', 653, 'village'),
                     (659, 'Jausa', '92003', 653, 'village'),
                     (660, 'Õngu', '92059', 653, 'village'),
                     (661, 'Valgu', '92011', 653, 'village'),
                     (662, 'Muda', '92029', 653, 'village'),
                     (663, 'Haldreka', '92043', 653, 'village'),
                     (664, 'Kabuna', '92041', 653, 'village'),
                     (665, 'Metsapere', '92053', 653, 'village'),
                     (666, 'Külaküla', '92049', 653, 'village'),
                     (667, 'Tilga', '92024', 653, 'village'),
                     (668, 'Tärkma', '92026', 653, 'village'),
                     (669, 'Sõru', '92023', 653, 'village'),
                     (670, 'Külama', '92021', 653, 'village'),
                     (671, 'Sinima', '92058', 653, 'village'),
                     (672, 'Pärna', '92017', 653, 'village'),
                     (673, 'Prassi', '92016', 653, 'village'),
                     (674, 'Nurste', '92002', 653, 'village'),
                     (675, 'Prähnu', '92056', 653, 'village'),
                     (676, 'Kuusiku', '92048', 653, 'village'),
                     (677, 'Mänspe', '92054', 653, 'village'),
                     (678, 'Viiri', '92027', 653, 'village'),
                     (679, 'Kitsa', '92046', 653, 'village'),
                     (680, 'Leisu', '92052', 653, 'village'),
                     (681, 'Tohvri', '92025', 653, 'village'),
                     (682, 'Rannaküla', '92018', 653, 'village'),
                     (683, 'Metsalauka', '92015', 653, 'village'),
                     (684, 'Ole', '92055', 653, 'village'),
                     (685, 'Ulja', '92030', 653, 'village'),
                     (686, 'Laartsa', '92050', 653, 'village'),
                     (687, 'Härma', '92044', 653, 'village'),
                     (688, 'Kõmmusselja', '92013', 653, 'village'),
                     (689, 'Riidaküla', '92020', 653, 'village'),
                     (690, 'Haldi', '92042', 653, 'village'),
                     (691, 'Sepaste', '92022', 653, 'village'),
                     (692, 'Vanamõisa', '92060', 653, 'village'),
                     (693, 'Ida-Viru', '', None, 'county'),
                     (694, 'Lohusuu', '', 693, 'municipality'),
                     (695, 'Kalmaküla', '', 694, 'village'),
                     (696, 'Ninasi', '42003', 694, 'village'),
                     (697, 'Tammispää', '42006', 694, 'village'),
                     (698, 'Raadna', '42004', 694, 'village'),
                     (699, 'Kärasi', '42119', 694, 'village'),
                     (700, 'Piilsi', '42120', 694, 'village'),
                     (701, 'Jõemetsa', '42118', 694, 'village'),
                     (702, 'Separa', '42005', 694, 'village'),
                     (703, 'Vilusi', '42007', 694, 'village'),
                     (704, 'Sonda', '', 693, 'municipality'),
                     (705, 'Erra', '', 704, 'smallborough'),
                     (706, 'Erra-Liiva', '', 704, 'village'),
                     (707, 'Varinurme', '', 704, 'village'),
                     (708, 'Vana-Sonda', '43006', 704, 'village'),
                     (709, 'Uljaste', '43005', 704, 'village'),
                     (710, 'Koljala', '43135', 704, 'village'),
                     (711, 'Vainu', '43136', 704, 'village'),
                     (712, 'Ilmaste', '43138', 704, 'village'),
                     (713, 'Nüri', '43003', 704, 'village'),
                     (714, 'Satsu', '43004', 704, 'village'),
                     (715, 'Toila', '', 693, 'municipality'),
                     (716, 'Voka', '', 715, 'smallborough'),
                     (717, 'Pühajõe', '', 715, 'village'),
                     (718, 'Altküla', '', 715, 'village'),
                     (719, 'Konju', '41714', 715, 'village'),
                     (720, 'Uikala', '41717', 715, 'village'),
                     (721, 'Martsa', '41715', 715, 'village'),
                     (722, 'Päite', '40104', 715, 'village'),
                     (723, 'Metsamägara', '41712', 715, 'village'),
                     (724, 'Vaivina', '40105', 715, 'village'),
                     (725, 'Tudulinna', '', 693, 'municipality'),
                     (726, 'Sahargu', '', 725, 'village'),
                     (727, 'Pikati', '42207', 725, 'village'),
                     (728, 'Rannapungerja', '42208', 725, 'village'),
                     (729, 'Roostoja', '42209', 725, 'village'),
                     (730, 'Peressaare', '42121', 725, 'village'),
                     (731, 'Oonurme', '42206', 725, 'village'),
                     (732, 'Tagajõe', '42211', 725, 'village'),
                     (733, 'Lemmaku', '42205', 725, 'village'),
                     (734, 'Kellassaare', '42204', 725, 'village'),
                     (735, 'Sillamäe', '', 693, 'town'),
                     (736, 'Püssi', '', 693, 'town'),
                     (737, 'Lüganuse', '', 693, 'municipality'),
                     (738, 'Purtse', '', 737, 'village'),
                     (739, 'Matka', '', 737, 'village'),
                     (740, 'Moldova', '43307', 737, 'village'),
                     (741, 'Irvala', '43132', 737, 'village'),
                     (742, 'Mustmätta', '43308', 737, 'village'),
                     (743, 'Aa', '43311', 737, 'village'),
                     (744, 'Jabara', '43304', 737, 'village'),
                     (745, 'Kopli', '43305', 737, 'village'),
                     (746, 'Liimala', '43306', 737, 'village'),
                     (747, 'Varja', '43309', 737, 'village'),
                     (748, 'Voorepera', '43310', 737, 'village'),
                     (749, 'Lohkuse', '43225', 737, 'village'),
                     (750, 'Vaivara', '', 693, 'municipality'),
                     (751, 'Sinimäe', '', 750, 'smallborough'),
                     (752, 'Olgina', '', 750, 'smallborough'),
                     (753, 'Tõrvajõe', '', 750, 'village'),
                     (754, 'Sõtke', '', 750, 'village'),
                     (755, 'Hiiemetsa', '40108', 750, 'village'),
                     (756, 'Udria', '40118', 750, 'village'),
                     (757, 'Soldina', '40115', 750, 'village'),
                     (758, 'Vodava', '40119', 750, 'village'),
                     (759, 'Perjatsi', '40241', 750, 'village'),
                     (760, 'Pimestiku', '40113', 750, 'village'),
                     (761, 'Hundinurga', '40109', 750, 'village'),
                     (762, 'Auvere', '40107', 750, 'village'),
                     (763, 'Arumäe', '40106', 750, 'village'),
                     (764, 'Kudruküla', '29024', 750, 'village'),
                     (765, 'Mustanina', '40111', 750, 'village'),
                     (766, 'Laagna', '40110', 750, 'village'),
                     (767, 'Puhkova', '40114', 750, 'village'),
                     (768, 'Meriküla', '29025', 750, 'village'),
                     (769, 'Peeterristi', '40112', 750, 'village'),
                     (770, 'Narva', '', 693, 'town'),
                     (771, 'Avinurme', '', 693, 'municipality'),
                     (772, 'Paadenurme', '42113', 771, 'village'),
                     (773, 'Laekannu', '42110', 771, 'village'),
                     (774, 'Tammessaare', '42115', 771, 'village'),
                     (775, 'Adraku', '42103', 771, 'village'),
                     (776, 'Vadi', '42116', 771, 'village'),
                     (777, 'Kiissa', '42106', 771, 'village'),
                     (778, 'Kõrve', '42107', 771, 'village'),
                     (779, 'Sälliksaare', '42114', 771, 'village'),
                     (780, 'Kaevussaare', '42122', 771, 'village'),
                     (781, 'Kõrvemetsa', '42108', 771, 'village'),
                     (782, 'Maetsma', '42112', 771, 'village'),
                     (783, 'Kõveriku', '42109', 771, 'village'),
                     (784, 'Alekere', '42104', 771, 'village'),
                     (785, 'Lepiksaare', '42111', 771, 'village'),
                     (786, 'Änniksaare', '42117', 771, 'village'),
                     (787, 'Ulvi', '42102', 771, 'village'),
                     (788, 'Narva-Jõesuu', '', 693, 'town'),
                     (789, 'Kohtla-Järve', '', 693, 'town'),
                     (790, 'Viivikonna', '', 789, 'township'),
                     (791, 'Aseri', '', 693, 'municipality'),
                     (792, 'Rannu', '', 791, 'village'),
                     (793, 'Kestla', '43303', 791, 'village'),
                     (794, 'Kõrkküla', '43405', 791, 'village'),
                     (795, 'Kõrtsialuse', '43406', 791, 'village'),
                     (796, 'Kalvi', '43403', 791, 'village'),
                     (797, 'Oru', '43407', 791, 'village'),
                     (798, 'Koogu', '43404', 791, 'village'),
                     (799, 'Aseriaru', '43402', 791, 'village'),
                     (800, 'Jõhvi', '', 693, 'town'),
                     (801, 'Puru', '', 800, 'village'),
                     (802, 'Linna', '', 800, 'village'),
                     (803, 'Tammiku', '', 800, 'smallborough'),
                     (804, 'Edise', '', 800, 'village'),
                     (805, 'Kotinuka', '', 800, 'village'),
                     (806, 'Sompa', '', 800, 'village'),
                     (807, 'Pauliku', '', 800, 'village'),
                     (808, 'Kahula', '', 800, 'village'),
                     (809, 'Pajualuse', '', 800, 'village'),
                     (810, 'Pargitaguse', '', 800, 'village'),
                     (811, 'Kose', '', 800, 'village'),
                     (812, 'Iisaku', '', 693, 'municipality'),
                     (813, 'Kuru', '', 812, 'village'),
                     (814, 'Tammetaguse', '41112', 812, 'village'),
                     (815, 'Sõrumäe', '41111', 812, 'village'),
                     (816, 'Jõuga', '41104', 812, 'village'),
                     (817, 'Alliku', '41102', 812, 'village'),
                     (818, 'Lõpe', '42213', 812, 'village'),
                     (819, 'Koldamäe', '41106', 812, 'village'),
                     (820, 'Taga-Roostoja', '42203', 812, 'village'),
                     (821, 'Kauksi', '41008', 812, 'village'),
                     (822, 'Pootsiku', '41109', 812, 'village'),
                     (823, 'Kasevälja', '41105', 812, 'village'),
                     (824, 'Sälliku', '41110', 812, 'village'),
                     (825, 'Varesmetsa', '41115', 812, 'village'),
                     (826, 'Lipniku', '41107', 812, 'village'),
                     (827, 'Vaikla', '41114', 812, 'village'),
                     (828, 'Tärivere', '41113', 812, 'village'),
                     (829, 'Imatu', '41103', 812, 'village'),
                     (830, 'Kiviõli', '', 693, 'town'),
                     (831, 'Alajõe', '', 693, 'municipality'),
                     (832, 'Smolnitsa', '', 831, 'village'),
                     (833, 'Remniku', '', 831, 'village'),
                     (834, 'Vasknarva', '', 831, 'village'),
                     (835, 'Katase', '', 831, 'village'),
                     (836, 'Karjamaa', '41002', 831, 'village'),
                     (837, 'Uusküla', '41006', 831, 'village'),
                     (838, 'Kohtla-Nõmme', '', 693, 'municipality'),
                     (839, 'Maidla', '', 693, 'municipality'),
                     (840, 'Savala', '', 839, 'village'),
                     (841, 'Uniküla', '', 839, 'village'),
                     (842, 'Soonurme', '', 839, 'village'),
                     (843, 'Aidu-Liiva', '', 839, 'village'),
                     (844, 'Kulja', '42311', 839, 'village'),
                     (845, 'Mehide', '42313', 839, 'village'),
                     (846, 'Virunurme', '42324', 839, 'village'),
                     (847, 'Rebu', '42317', 839, 'village'),
                     (848, 'Tarumaa', '41305', 839, 'village'),
                     (849, 'Lümatu', '42312', 839, 'village'),
                     (850, 'Aidu', '42302', 839, 'village'),
                     (851, 'Aidu-Nõmme', '42304', 839, 'village'),
                     (852, 'Koolma', '42310', 839, 'village'),
                     (853, 'Arupäälse', '42307', 839, 'village'),
                     (854, 'Aidu-Sooküla', '42305', 839, 'village'),
                     (855, 'Lipu', '41304', 839, 'village'),
                     (856, 'Rääsa', '42318', 839, 'village'),
                     (857, 'Salaküla', '43133', 839, 'village'),
                     (858, 'Aruküla', '', 839, 'village'),
                     (859, 'Sirtsi', '42320', 839, 'village'),
                     (860, 'Piilse', '42316', 839, 'village'),
                     (861, 'Hirmuse', '42309', 839, 'village'),
                     (862, 'Ojamaa', '42315', 839, 'village'),
                     (863, 'Veneoja', '42323', 839, 'village'),
                     (864, 'Aruvälja', '42308', 839, 'village'),
                     (865, 'Oandu', '42314', 839, 'village'),
                     (866, 'Mäetaguse', '', 693, 'municipality'),
                     (867, 'Kiikla', '', 866, 'village'),
                     (868, 'Rajaküla', '', 866, 'village'),
                     (869, 'Liivakünka', '41314', 866, 'village'),
                     (870, 'Uhe', '41320', 866, 'village'),
                     (871, 'Apandiku', '41306', 866, 'village'),
                     (872, 'Väike-Pungerja', '41324', 866, 'village'),
                     (873, 'Atsalama', '41309', 866, 'village'),
                     (874, 'Võhma', '41321', 866, 'village'),
                     (875, 'Ratva', '41318', 866, 'village'),
                     (876, 'Kalina', '41312', 866, 'village'),
                     (877, 'Ereda', '41310', 866, 'village'),
                     (878, 'Tarakuse', '41319', 866, 'village'),
                     (879, 'Võide', '41322', 866, 'village'),
                     (880, 'Metsküla', '41315', 866, 'village'),
                     (881, 'Arvila', '41308', 866, 'village'),
                     (882, 'Pagari', '41303', 866, 'village'),
                     (883, 'Jõetaguse', '41311', 866, 'village'),
                     (884, 'Võrnu', '41323', 866, 'village'),
                     (885, 'Kohtla', '', 693, 'municipality'),
                     (886, 'Roodu', '', 885, 'village'),
                     (887, 'Servaääre', '30506', 885, 'village'),
                     (888, 'Paate', '30625', 885, 'village'),
                     (889, 'Kabelimetsa', '30624', 885, 'village'),
                     (890, 'Järve', '30331', 885, 'village'),
                     (891, 'Täkumetsa', '30626', 885, 'village'),
                     (892, 'Vitsiku', '30507', 885, 'village'),
                     (893, 'Ontika', '41556', 885, 'village'),
                     (894, 'Saka', '30103', 885, 'village'),
                     (895, 'Mõisamaa', '30332', 885, 'village'),
                     (896, 'Kukruse', '30623', 885, 'village'),
                     (897, 'Amula', '41553', 885, 'village'),
                     (898, 'Kaasikaia', '41554', 885, 'village'),
                     (899, 'Kaasikvälja', '41555', 885, 'village'),
                     (900, 'Peeri', '30333', 885, 'village'),
                     (901, 'Valaste', '41557', 885, 'village'),
                     (902, 'Illuka', '', 693, 'municipality'),
                     (903, 'Kurtna', '', 902, 'village'),
                     (904, 'Kuremäe', '', 902, 'village'),
                     (905, 'Konsu', '41209', 902, 'village'),
                     (906, 'Kivinõmme', '41208', 902, 'village'),
                     (907, 'Rausvere', '41214', 902, 'village'),
                     (908, 'Karoli', '41011', 902, 'village'),
                     (909, 'Permisküla', '41013', 902, 'village'),
                     (910, 'Agusalu', '41211', 902, 'village'),
                     (911, 'Ohakvere', '41210', 902, 'village'),
                     (912, 'Kaatermu', '41205', 902, 'village'),
                     (913, 'Puhatu', '41213', 902, 'village'),
                     (914, 'Kamarna', '41207', 902, 'village'),
                     (915, 'Jaama', '41010', 902, 'village'),
                     (916, 'Edivere', '41203', 902, 'village'),
                     (917, 'Vasavere', '41215', 902, 'village'),
                     (918, 'Kuningaküla', '41012', 902, 'village'),
                     (919, 'Kaidma', '41206', 902, 'village'),
                     (920, 'Ongassaare', '41212', 902, 'village'),
                     (921, 'Jõgeva', '', None, 'county'),
                     (922, 'Torma', '', 921, 'municipality'),
                     (923, 'Sadala', '', 922, 'smallborough'),
                     (924, 'Ookatku', '48512', 922, 'village'),
                     (925, 'Rääbise', '48516', 922, 'village'),
                     (926, 'Kodismaa', '48505', 922, 'village'),
                     (927, 'Sätsuvere', '48517', 922, 'village'),
                     (928, 'Võtikvere', '48525', 922, 'village'),
                     (929, 'Kantküla', '48526', 922, 'village'),
                     (930, 'Rassiku', '48514', 922, 'village'),
                     (931, 'Leedi', '48508', 922, 'village'),
                     (932, 'Tuimõisa', '48519', 922, 'village'),
                     (933, 'Tähkvere', '48521', 922, 'village'),
                     (934, 'Võidivere', '48524', 922, 'village'),
                     (935, 'Vaiatu', '48522', 922, 'village'),
                     (936, 'Iravere', '48503', 922, 'village'),
                     (937, 'Kõnnu', '48507', 922, 'village'),
                     (938, 'Tealama', '48518', 922, 'village'),
                     (939, 'Tõikvere', '48520', 922, 'village'),
                     (940, 'Vanamõisa', '48523', 922, 'village'),
                     (941, 'Näduvere', '48511', 922, 'village'),
                     (942, 'Reastvere', '48515', 922, 'village'),
                     (943, 'Oti', '48513', 922, 'village'),
                     (944, 'Liikatku', '48509', 922, 'village'),
                     (945, 'Lilastvere', '48510', 922, 'village'),
                     (946, 'Koimula', '48506', 922, 'village'),
                     (947, 'Põltsamaa', '', 921, 'town'),
                     (948, 'Adavere', '', 947, 'smallborough'),
                     (949, 'Esku', '', 947, 'village'),
                     (950, 'Kuningamäe', '', 947, 'village'),
                     (951, 'Mõhküla', '', 947, 'village'),
                     (952, 'Lustivere', '', 947, 'village'),
                     (953, 'Kaavere', '48006', 947, 'village'),
                     (954, 'Tõrenurme', '48025', 947, 'village'),
                     (955, 'Väike-Kamari', '48030', 947, 'village'),
                     (956, 'Pilu', '48018', 947, 'village'),
                     (957, 'Annikvere', '48004', 947, 'village'),
                     (958, 'Kablaküla', '48007', 947, 'village'),
                     (959, 'Lebavere', '48012', 947, 'village'),
                     (960, 'Võhmanõmme', '48028', 947, 'village'),
                     (961, 'Vitsjärve', '48027', 947, 'village'),
                     (962, 'Rõstla', '48022', 947, 'village'),
                     (963, 'Kaliküla', '48008', 947, 'village'),
                     (964, 'Kalme', '48031', 947, 'village'),
                     (965, 'Umbusi', '48026', 947, 'village'),
                     (966, 'Neanurme', '48015', 947, 'village'),
                     (967, 'Mällikvere', '48014', 947, 'village'),
                     (968, 'Pauastvere', '48017', 947, 'village'),
                     (969, 'Pudivere', '48019', 947, 'village'),
                     (970, 'Puduküla', '48020', 947, 'village'),
                     (971, 'Nõmavere', '48016', 947, 'village'),
                     (972, 'Sulustvere', '48024', 947, 'village'),
                     (973, 'Puiatu', '48021', 947, 'village'),
                     (974, 'Võisiku', '48029', 947, 'village'),
                     (975, 'Kamari', '48003', 947, 'smallborough'),
                     (976, 'Alastvere', '48010', 947, 'village'),
                     (977, 'Räsna', '48023', 947, 'village'),
                     (978, 'Tabivere', '', 921, 'municipality'),
                     (979, 'Voldi', '', 978, 'village'),
                     (980, 'Kõduküla', '', 978, 'village'),
                     (981, 'Lilu', '49113', 978, 'village'),
                     (982, 'Sortsi', '49119', 978, 'village'),
                     (983, 'Kaitsemõisa', '49106', 978, 'village'),
                     (984, 'Kõnnujõe', '49110', 978, 'village'),
                     (985, 'Elistvere', '49103', 978, 'village'),
                     (986, 'Reinu', '49117', 978, 'village'),
                     (987, 'Valgma', '49123', 978, 'village'),
                     (988, 'Tormi', '49120', 978, 'village'),
                     (989, 'Õvanurme', '49125', 978, 'village'),
                     (990, 'Pataste', '49115', 978, 'village'),
                     (991, 'Otslava', '49114', 978, 'village'),
                     (992, 'Maarja-Magdaleena', '49126', 978, 'village'),
                     (993, 'Vahi', '49122', 978, 'village'),
                     (994, 'Kassema', '49107', 978, 'village'),
                     (995, 'Juula', '49104', 978, 'village'),
                     (996, 'Kärksi', '49112', 978, 'village'),
                     (997, 'Uhmardu', '49121', 978, 'village'),
                     (998, 'Sepa', '49118', 978, 'village'),
                     (999, 'Koogi', '49108', 978, 'village'),
                     (1000, 'Kaiavere', '', 978, 'village'),
                     (1001, 'Raigastvere', '49116', 978, 'village'),
                     (1002, 'Kõrenduse', '49111', 978, 'village'),
                     (1003, 'Mustvee', '', 921, 'town'),
                     (1004, 'Jõgeva', '', 921, 'town'),
                     (1005, 'Kuremaa', '', 1004, 'smallborough'),
                     (1006, 'Õuna', '', 1004, 'village'),
                     (1007, 'Mooritsa', '', 1004, 'village'),
                     (1008, 'Laiuse', '', 1004, 'smallborough'),
                     (1009, 'Siimusti', '', 1004, 'smallborough'),
                     (1010, 'Vana-Jõgeva', '', 1004, 'village'),
                     (1011, 'Lemuvere', '48417', 1004, 'village'),
                     (1012, 'Liivoja', '48418', 1004, 'village'),
                     (1013, 'Alavere', '48405', 1004, 'village'),
                     (1014, 'Kõola', '48414', 1004, 'village'),
                     (1015, 'Rohe', '48428', 1004, 'village'),
                     (1016, 'Viruvere', '48435', 1004, 'village'),
                     (1017, 'Painküla', '48422', 1004, 'village'),
                     (1018, 'Lõpe', '48440', 1004, 'village'),
                     (1019, 'Kaude', '48411', 1004, 'village'),
                     (1020, 'Ellakvere', '48406', 1004, 'village'),
                     (1021, 'Selli', '48429', 1004, 'village'),
                     (1022, 'Endla', '48407', 1004, 'village'),
                     (1023, 'Kaera', '48409', 1004, 'village'),
                     (1024, 'Raaduvere', '48427', 1004, 'village'),
                     (1025, 'Pedja', '48426', 1004, 'village'),
                     (1026, 'Vilina', '48434', 1004, 'village'),
                     (1027, 'Väljaotsa', '48441', 1004, 'village'),
                     (1028, 'Pakaste', '48423', 1004, 'village'),
                     (1029, 'Kurista', '48413', 1004, 'village'),
                     (1030, 'Paduvere', '48421', 1004, 'village'),
                     (1031, 'Patjala', '48425', 1004, 'village'),
                     (1032, 'Laiusevälja', '48416', 1004, 'village'),
                     (1033, 'Soomevere', '48430', 1004, 'village'),
                     (1034, 'Võduvere', '48436', 1004, 'village'),
                     (1035, 'Vaimastvere', '48446', 1004, 'village'),
                     (1036, 'Võikvere', '48437', 1004, 'village'),
                     (1037, 'Palupere', '48424', 1004, 'village'),
                     (1038, 'Kivijärve', '48412', 1004, 'village'),
                     (1039, 'Teilma', '48431', 1004, 'village'),
                     (1040, 'Tooma', '48432', 1004, 'village'),
                     (1041, 'Kassinurme', '48410', 1004, 'village'),
                     (1042, 'Kärde', '48415', 1004, 'village'),
                     (1043, 'Mõisamaa', '48420', 1004, 'village'),
                     (1044, 'Palamuse', '', 921, 'municipality'),
                     (1045, 'Ehavere', '49205', 1044, 'village'),
                     (1046, 'Süvalepa', '49219', 1044, 'village'),
                     (1047, 'Eerikvere', '49204', 1044, 'village'),
                     (1048, 'Imukvere', '49206', 1044, 'village'),
                     (1049, 'Sudiste', '49218', 1044, 'village'),
                     (1050, 'Pikkjärve', '49213', 1044, 'village'),
                     (1051, 'Kudina', '49210', 1044, 'village'),
                     (1052, 'Järvepera', '49207', 1044, 'village'),
                     (1053, 'Visusti', '49224', 1044, 'village'),
                     (1054, 'Mullavere', '49211', 1044, 'village'),
                     (1055, 'Ronivere', '49217', 1044, 'village'),
                     (1056, 'Vanavälja', '49222', 1044, 'village'),
                     (1057, 'Praaklima', '49227', 1044, 'village'),
                     (1058, 'Varbevere', '49223', 1044, 'village'),
                     (1059, 'Änkküla', '49225', 1044, 'village'),
                     (1060, 'Kaarepere', '49201', 1044, 'village'),
                     (1061, 'Vaidavere', '49221', 1044, 'village'),
                     (1062, 'Luua', '49203', 1044, 'village'),
                     (1063, 'Rahivere', '49216', 1044, 'village'),
                     (1064, 'Toovere', '49220', 1044, 'village'),
                     (1065, 'Nava', '49212', 1044, 'village'),
                     (1066, 'Kivimäe', '49209', 1044, 'village'),
                     (1067, 'Kassivere', '49208', 1044, 'village'),
                     (1068, 'Raadivere', '49228', 1044, 'village'),
                     (1069, 'Puurmani', '', 921, 'municipality'),
                     (1070, 'Tammiku', '49012', 1069, 'village'),
                     (1071, 'Härjanurme', '49003', 1069, 'village'),
                     (1072, 'Pikknurme', '49009', 1069, 'village'),
                     (1073, 'Jõune', '49004', 1069, 'village'),
                     (1074, 'Jüriküla', '49005', 1069, 'village'),
                     (1075, 'Kirikuvalla', '49006', 1069, 'village'),
                     (1076, 'Altnurga', '49002', 1069, 'village'),
                     (1077, 'Tõrve', '49013', 1069, 'village'),
                     (1078, 'Saduküla', '49011', 1069, 'village'),
                     (1079, 'Kursi', '49007', 1069, 'village'),
                     (1080, 'Laasme', '49008', 1069, 'village'),
                     (1081, 'Pööra', '49010', 1069, 'village'),
                     (1082, 'Saare', '', 921, 'municipality'),
                     (1083, 'Voore', '', 1082, 'village'),
                     (1084, 'Koseveski', '', 1082, 'village'),
                     (1085, 'Sirguvere', '49317', 1082, 'village'),
                     (1086, 'Vassevere', '49321', 1082, 'village'),
                     (1087, 'Putu', '49313', 1082, 'village'),
                     (1088, 'Pedassaare', '49312', 1082, 'village'),
                     (1089, 'Odivere', '49311', 1082, 'village'),
                     (1090, 'Vanassaare', '49320', 1082, 'village'),
                     (1091, 'Ruskavere', '49315', 1082, 'village'),
                     (1092, 'Saarjärve', '49316', 1082, 'village'),
                     (1093, 'Nautrasi', '49310', 1082, 'village'),
                     (1094, 'Kiisli', '49306', 1082, 'village'),
                     (1095, 'Kallivere', '49305', 1082, 'village'),
                     (1096, 'Halliku', '49303', 1082, 'village'),
                     (1097, 'Maardla', '49309', 1082, 'village'),
                     (1098, 'Veia', '49322', 1082, 'village'),
                     (1099, 'Tarakvere', '49318', 1082, 'village'),
                     (1100, 'Pällu', '49314', 1082, 'village'),
                     (1101, 'Levala', '49308', 1082, 'village'),
                     (1102, 'Jaama', '49304', 1082, 'village'),
                     (1103, 'Kääpa', '49323', 1082, 'village'),
                     (1104, 'Tuulavere', '49319', 1082, 'village'),
                     (1105, 'Kasepää', '', 921, 'municipality'),
                     (1106, 'Tiheda', '', 1105, 'village'),
                     (1107, 'Raja', '', 1105, 'village'),
                     (1108, 'Kükita', '', 1105, 'village'),
                     (1109, 'Metsaküla', '49505', 1105, 'village'),
                     (1110, 'Omedu', '49507', 1105, 'village'),
                     (1111, 'Nõmme', '49506', 1105, 'village'),
                     (1112, 'Kaasiku', '49502', 1105, 'village'),
                     (1113, 'Pajusi', '', 921, 'municipality'),
                     (1114, 'Vägari', '', 1113, 'village'),
                     (1115, 'Pisisaare', '', 1113, 'village'),
                     (1116, 'Kalana', '', 1113, 'village'),
                     (1117, 'Lahavere', '', 1113, 'village'),
                     (1118, 'Tapiku', '48218', 1113, 'village'),
                     (1119, 'Kõpu', '48208', 1113, 'village'),
                     (1120, 'Loopre', '48211', 1113, 'village'),
                     (1121, 'Uuevälja', '48220', 1113, 'village'),
                     (1122, 'Tõivere', '48219', 1113, 'village'),
                     (1123, 'Kauru', '48206', 1113, 'village'),
                     (1124, 'Nurga', '48215', 1113, 'village'),
                     (1125, 'Aidu', '48202', 1113, 'village'),
                     (1126, 'Mõisaküla', '48213', 1113, 'village'),
                     (1127, 'Kõrkküla', '48209', 1113, 'village'),
                     (1128, 'Väljataguse', '48223', 1113, 'village'),
                     (1129, 'Kose', '48207', 1113, 'village'),
                     (1130, 'Arisvere', '48203', 1113, 'village'),
                     (1131, 'Kaave', '48204', 1113, 'village'),
                     (1132, 'Vorsti', '48221', 1113, 'village'),
                     (1133, 'Luige', '48212', 1113, 'village'),
                     (1134, 'Mõrtsi', '48214', 1113, 'village'),
                     (1135, 'Sopimetsa', '48217', 1113, 'village'),
                     (1136, 'Pala', '', 921, 'municipality'),
                     (1137, 'Kodavere', '49407', 1136, 'village'),
                     (1138, 'Haavakivi', '49404', 1136, 'village'),
                     (1139, 'Lümati', '49425', 1136, 'village'),
                     (1140, 'Kokanurga', '49408', 1136, 'village'),
                     (1141, 'Nõva', '49411', 1136, 'village'),
                     (1142, 'Sassukvere', '49418', 1136, 'village'),
                     (1143, 'Kadrina', '49405', 1136, 'village'),
                     (1144, 'Sõõru', '49419', 1136, 'village'),
                     (1145, 'Sääritsa', '49420', 1136, 'village'),
                     (1146, 'Vea', '49422', 1136, 'village'),
                     (1147, 'Ranna', '49417', 1136, 'village'),
                     (1148, 'Perametsa', '49412', 1136, 'village'),
                     (1149, 'Raatvere', '49416', 1136, 'village'),
                     (1150, 'Äteniidi', '49423', 1136, 'village'),
                     (1151, 'Tagumaa', '49421', 1136, 'village'),
                     (1152, 'Kirtsi', '49406', 1136, 'village'),
                     (1153, 'Piibumäe', '49413', 1136, 'village'),
                     (1154, 'Piirivarbe', '49414', 1136, 'village'),
                     (1155, 'Moku', '49410', 1136, 'village'),
                     (1156, 'Assikvere', '49403', 1136, 'village'),
                     (1157, 'Metsanurga', '49409', 1136, 'village'),
                     (1158, 'Punikvere', '49415', 1136, 'village'),
                     (1159, 'Vägeva', '', 921, 'municipality'),
                     (1160, 'Järva', '', None, 'county'),
                     (1161, 'Türi', '', 1160, 'municipality'),
                     (1162, 'Särevere', '', 1161, 'smallborough'),
                     (1163, 'Oisu', '', 1161, 'smallborough'),
                     (1164, 'Lokuta', '', 1161, 'village'),
                     (1165, 'Jändja', '', 1161, 'village'),
                     (1166, 'Kabala', '', 1161, 'village'),
                     (1167, 'Türi-Alliku', '', 1161, 'village'),
                     (1168, 'Poaka', '', 1161, 'village'),
                     (1169, 'Karjaküla', '72242', 1161, 'village'),
                     (1170, 'Rikassaare', '72307', 1161, 'village'),
                     (1171, 'Väljaotsa', '72311', 1161, 'village'),
                     (1172, 'Villevere', '72006', 1161, 'village'),
                     (1173, 'Kirna', '72231', 1161, 'village'),
                     (1174, 'Rassi', '72007', 1161, 'village'),
                     (1175, 'Raukla', '72305', 1161, 'village'),
                     (1176, 'Laupa', '72102', 1161, 'village'),
                     (1177, 'Saareotsa', '72308', 1161, 'village'),
                     (1178, 'Tännassilma', '72310', 1161, 'village'),
                     (1179, 'Pibari', '72005', 1161, 'village'),
                     (1180, 'Pala', '72234', 1161, 'village'),
                     (1181, 'Kurla', '72009', 1161, 'village'),
                     (1182, 'Ollepa', '72002', 1161, 'village'),
                     (1183, 'Äiamaa', '72312', 1161, 'village'),
                     (1184, 'Vilita', '72245', 1161, 'village'),
                     (1185, 'Retla', '72306', 1161, 'village'),
                     (1186, 'Sagevere', '72003', 1161, 'village'),
                     (1187, 'Arkma', '72011', 1161, 'village'),
                     (1188, 'Änari', '72241', 1161, 'village'),
                     (1189, 'Metsaküla', '72303', 1161, 'village'),
                     (1190, 'Põikva', '72244', 1161, 'village'),
                     (1191, 'Kärevere', '72302', 1161, 'village'),
                     (1192, 'Tori', '72230', 1161, 'village'),
                     (1193, 'Taikse', '72309', 1161, 'village'),
                     (1194, 'Meossaare', '72010', 1161, 'village'),
                     (1195, 'Näsuvere', '72246', 1161, 'village'),
                     (1196, 'Roosna-Alliku', '', 1160, 'municipality'),
                     (1197, 'Viisu', '', 1196, 'village'),
                     (1198, 'Valasti', '73210', 1196, 'village'),
                     (1199, 'Kihme', '73206', 1196, 'village'),
                     (1200, 'Koordi', '73212', 1196, 'village'),
                     (1201, 'Oeti', '73208', 1196, 'village'),
                     (1202, 'Kodasema', '73207', 1196, 'village'),
                     (1203, 'Kirisaare', '73211', 1196, 'village'),
                     (1204, 'Kaaruka', '73205', 1196, 'village'),
                     (1205, 'Tännapere', '73209', 1196, 'village'),
                     (1206, 'Allikjärve', '73203', 1196, 'village'),
                     (1207, 'Vedruka', '73213', 1196, 'village'),
                     (1208, 'Paide', '', 1160, 'town'),
                     (1209, 'Tarbja', '', 1208, 'village'),
                     (1210, 'Kriilevälja', '', 1208, 'village'),
                     (1211, 'Sargvere', '', 1208, 'village'),
                     (1212, 'Sillaotsa', '', 1208, 'village'),
                     (1213, 'Sõmeru', '72614', 1208, 'village'),
                     (1214, 'Viraksaare', '', 1208, 'village'),
                     (1215, 'Veskiaru', '72760', 1208, 'village'),
                     (1216, 'Mustla', '72607', 1208, 'village'),
                     (1217, 'Ojaküla', '72610', 1208, 'village'),
                     (1218, 'Mustla-Nõmme', '72608', 1208, 'village'),
                     (1219, 'Eivere', '72757', 1208, 'village'),
                     (1220, 'Mäeküla', '', 1208, 'village'),
                     (1221, 'Korba', '72753', 1208, 'village'),
                     (1222, 'Valgma', '72606', 1208, 'village'),
                     (1223, 'Võõbu', '72615', 1208, 'village'),
                     (1224, 'Kirila', '72755', 1208, 'village'),
                     (1225, 'Mündi', '72762', 1208, 'village'),
                     (1226, 'Seinapalu', '72761', 1208, 'village'),
                     (1227, 'Otiku', '72611', 1208, 'village'),
                     (1228, 'Nurme', '72609', 1208, 'village'),
                     (1229, 'Prääma', '72763', 1208, 'village'),
                     (1230, 'Nurmsi', '72603', 1208, 'village'),
                     (1231, 'Purdi', '72613', 1208, 'village'),
                     (1232, 'Mäo', '72751', 1208, 'village'),
                     (1233, 'Suurpalu', '72605', 1208, 'village'),
                     (1234, 'Anna', '72601', 1208, 'village'),
                     (1235, 'Pikaküla', '72756', 1208, 'village'),
                     (1236, 'Väätsa', '', 1160, 'municipality'),
                     (1237, 'Aasuvälja', '', 1236, 'village'),
                     (1238, 'Reopalu', '', 1236, 'village'),
                     (1239, 'Ülejõe', '', 1236, 'village'),
                     (1240, 'Lõõla', '72814', 1236, 'village'),
                     (1241, 'Roovere', '72805', 1236, 'village'),
                     (1242, 'Vissuvere', '72812', 1236, 'village'),
                     (1243, 'Väljataguse', '72802', 1236, 'village'),
                     (1244, 'Saueaugu', '72813', 1236, 'village'),
                     (1245, 'Röa', '72806', 1236, 'village'),
                     (1246, 'Piiumetsa', '72804', 1236, 'village'),
                     (1247, 'Ambla', '', 1160, 'municipality'),
                     (1248, 'Aravete', '', 1247, 'smallborough'),
                     (1249, 'Käravete', '', 1247, 'smallborough'),
                     (1250, 'Raka', '', 1247, 'village'),
                     (1251, 'Kurisoo', '', 1247, 'village'),
                     (1252, 'Jõgisoo', '', 1247, 'village'),
                     (1253, 'Roosna', '', 1247, 'village'),
                     (1254, 'Märjandi', '73513', 1247, 'village'),
                     (1255, 'Sääsküla', '73511', 1247, 'village'),
                     (1256, 'Kukevere', '73512', 1247, 'village'),
                     (1257, 'Mägise', '73510', 1247, 'village'),
                     (1258, 'Reinevere', '73507', 1247, 'village'),
                     (1259, 'Rava', '73506', 1247, 'village'),
                     (1260, 'Järva-Jaani', '', 1160, 'municipality'),
                     (1261, 'Karinu', '', 1260, 'village'),
                     (1262, 'Metsla', '73307', 1260, 'village'),
                     (1263, 'Kuksema', '73306', 1260, 'village'),
                     (1264, 'Jalalõpe', '73303', 1260, 'village'),
                     (1265, 'Jalgsema', '73304', 1260, 'village'),
                     (1266, 'Kagavere', '73305', 1260, 'village'),
                     (1267, 'Seliküla', '73310', 1260, 'village'),
                     (1268, 'Metstaguse', '73308', 1260, 'village'),
                     (1269, 'Ramma', '73309', 1260, 'village'),
                     (1270, 'Koeru', '', 1160, 'municipality'),
                     (1271, 'Ervita', '', 1270, 'village'),
                     (1272, 'Vao', '', 1270, 'village'),
                     (1273, 'Rõhu', '73018', 1270, 'village'),
                     (1274, 'Udeva', '73019', 1270, 'village'),
                     (1275, 'Tammiku', '73023', 1270, 'village'),
                     (1276, 'Preedi', '73017', 1270, 'village'),
                     (1277, 'Norra', '73016', 1270, 'village'),
                     (1278, 'Kuusna', '73008', 1270, 'village'),
                     (1279, 'Visusti', '73012', 1270, 'village'),
                     (1280, 'Valila', '73024', 1270, 'village'),
                     (1281, 'Tudre', '73010', 1270, 'village'),
                     (1282, 'Väinjärve', '73021', 1270, 'village'),
                     (1283, 'Santovi', '73005', 1270, 'village'),
                     (1284, 'Koidu-Ellavere', '73027', 1270, 'village'),
                     (1285, 'Vahuküla', '73020', 1270, 'village'),
                     (1286, 'Aruküla', '73004', 1270, 'village'),
                     (1287, 'Jõeküla', '73014', 1270, 'village'),
                     (1288, 'Kalitsa', '73022', 1270, 'village'),
                     (1289, 'Liusvere', '73015', 1270, 'village'),
                     (1290, 'Kapu', '73007', 1270, 'village'),
                     (1291, 'Puhmu', '73006', 1270, 'village'),
                     (1292, 'Laaneotsa', '73013', 1270, 'village'),
                     (1293, 'Salutaguse', '73009', 1270, 'village'),
                     (1294, 'Vuti', '73011', 1270, 'village'),
                     (1295, 'Merja', '73026', 1270, 'village'),
                     (1296, 'Abaja', '73025', 1270, 'village'),
                     (1297, 'Kareda', '', 1160, 'municipality'),
                     (1298, 'Esna', '', 1297, 'village'),
                     (1299, 'Peetri', '', 1297, 'smallborough'),
                     (1300, 'Õle', '73108', 1297, 'village'),
                     (1301, 'Köisi', '73104', 1297, 'village'),
                     (1302, 'Ataste', '73103', 1297, 'village'),
                     (1303, 'Müüsleri', '73105', 1297, 'village'),
                     (1304, 'Vodja', '73111', 1297, 'village'),
                     (1305, 'Küti', '73106', 1297, 'village'),
                     (1306, 'Ämbra', '73110', 1297, 'village'),
                     (1307, 'Ammuta', '73107', 1297, 'village'),
                     (1308, 'Öötla', '73112', 1297, 'village'),
                     (1309, 'Albu', '', 1160, 'municipality'),
                     (1310, 'Pullevere', '', 1309, 'village'),
                     (1311, 'Järva-Madise', '', 1309, 'village'),
                     (1312, 'Ahula', '', 1309, 'village'),
                     (1313, 'Seidla', '73407', 1309, 'village'),
                     (1314, 'Vetepere', '73416', 1309, 'village'),
                     (1315, 'Ageri', '73408', 1309, 'village'),
                     (1316, 'Soosalu', '73414', 1309, 'village'),
                     (1317, 'Mägede', '73412', 1309, 'village'),
                     (1318, 'Orgmetsa', '73405', 1309, 'village'),
                     (1319, 'Sugalepa', '73415', 1309, 'village'),
                     (1320, 'Kaalepi', '73403', 1309, 'village'),
                     (1321, 'Lehtmetsa', '73410', 1309, 'village'),
                     (1322, 'Mõnuvere', '73411', 1309, 'village'),
                     (1323, 'Neitla', '73404', 1309, 'village'),
                     (1324, 'Peedu', '73413', 1309, 'village'),
                     (1325, 'Imavere', '', 1160, 'municipality'),
                     (1326, 'Käsukonna', '', 1325, 'village'),
                     (1327, 'Taadikvere', '', 1325, 'village'),
                     (1328, 'Jalametsa', '72403', 1325, 'village'),
                     (1329, 'Võrevere', '72409', 1325, 'village'),
                     (1330, 'Eistvere', '72402', 1325, 'village'),
                     (1331, 'Laimetsa', '72410', 1325, 'village'),
                     (1332, 'Kiigevere', '72405', 1325, 'village'),
                     (1333, 'Pällastvere', '72412', 1325, 'village'),
                     (1334, 'Puiatu', '', 1325, 'village'),
                     (1335, 'Järavere', '72404', 1325, 'village'),
                     (1336, 'Tammeküla', '72411', 1325, 'village'),
                     (1337, 'Koigi', '', 1160, 'municipality'),
                     (1338, 'Päinurme', '', 1337, 'village'),
                     (1339, 'Huuksi', '72503', 1337, 'village'),
                     (1340, 'Vaali', '72513', 1337, 'village'),
                     (1341, 'Tamsi', '72509', 1337, 'village'),
                     (1342, 'Lähevere', '72511', 1337, 'village'),
                     (1343, 'Silmsi', '72507', 1337, 'village'),
                     (1344, 'Sõrandu', '72508', 1337, 'village'),
                     (1345, 'Keri', '72505', 1337, 'village'),
                     (1346, 'Väike-Kareda', '72510', 1337, 'village'),
                     (1347, 'Prandi', '72506', 1337, 'village'),
                     (1348, 'Kahala', '', 1337, 'village'),
                     (1349, 'Rutikvere', '72512', 1337, 'village'),
                     (1350, 'Kolu', '', 1160, 'municipality'),
                     (1351, 'Lääne', '', None, 'county'),
                     (1352, 'Lihula', '', 1351, 'town'),
                     (1353, 'Hälvati', '', 1352, 'village'),
                     (1354, 'Tuudi', '', 1352, 'village'),
                     (1355, 'Kirbla', '', 1352, 'village'),
                     (1356, 'Penijõe', '90305', 1352, 'village'),
                     (1357, 'Seira', '90214', 1352, 'village'),
                     (1358, 'Kloostri', '90206', 1352, 'village'),
                     (1359, 'Parivere', '90228', 1352, 'village'),
                     (1360, 'Lautna', '90212', 1352, 'village'),
                     (1361, 'Võhma', '90215', 1352, 'village'),
                     (1362, 'Matsalu', '90230', 1352, 'village'),
                     (1363, 'Petaaluse', '90223', 1352, 'village'),
                     (1364, 'Rumba', '90213', 1352, 'village'),
                     (1365, 'Vagivere', '90226', 1352, 'village'),
                     (1366, 'Metsküla', '90232', 1352, 'village'),
                     (1367, 'Tuhu', '90225', 1352, 'village'),
                     (1368, 'Valuste', '90227', 1352, 'village'),
                     (1369, 'Kirikuküla', '90221', 1352, 'village'),
                     (1370, 'Poanse', '90224', 1352, 'village'),
                     (1371, 'Meelva', '90231', 1352, 'village'),
                     (1372, 'Kelu', '90205', 1352, 'village'),
                     (1373, 'Alaküla', '90219', 1352, 'village'),
                     (1374, 'Kunila', '90222', 1352, 'village'),
                     (1375, 'Pagasi', '90207', 1352, 'village'),
                     (1376, 'Saastna', '90233', 1352, 'village'),
                     (1377, 'Järise', '90220', 1352, 'village'),
                     (1378, 'Risti', '', 1351, 'municipality'),
                     (1379, 'Jaakna', '90911', 1378, 'village'),
                     (1380, 'Kuijõe', '90903', 1378, 'village'),
                     (1381, 'Piirsalu', '90902', 1378, 'village'),
                     (1382, 'Rõuma', '90904', 1378, 'village'),
                     (1383, 'Ridala', '', 1351, 'municipality'),
                     (1384, 'Uuemõisa', '', 1383, 'smallborough'),
                     (1385, 'Paralepa', '', 1383, 'smallborough'),
                     (1386, 'Valgevälja', '', 1383, 'village'),
                     (1387, 'Herjava', '', 1383, 'village'),
                     (1388, 'Tanska', '', 1383, 'village'),
                     (1389, 'Vilkla', '', 1383, 'village'),
                     (1390, 'Rohuküla', '', 1383, 'village'),
                     (1391, 'Nõmme', '', 1383, 'village'),
                     (1392, 'Mäeküla', '', 1383, 'village'),
                     (1393, 'Pusku', '', 1383, 'village'),
                     (1394, 'Kiltsi', '', 1383, 'village'),
                     (1395, 'Sinalepa', '', 1383, 'village'),
                     (1396, 'Saardu', '90424', 1383, 'village'),
                     (1397, 'Lannuste', '90414', 1383, 'village'),
                     (1398, 'Liivaküla', '', 1383, 'village'),
                     (1399, 'Metsaküla', '90436', 1383, 'village'),
                     (1400, 'Allika', '90405', 1383, 'village'),
                     (1401, 'Üsse', '90461', 1383, 'village'),
                     (1402, 'Tuuru', '90426', 1383, 'village'),
                     (1403, 'Põgari-Sassi', '90421', 1383, 'village'),
                     (1404, 'Kiideva', '90409', 1383, 'village'),
                     (1405, 'Rohense', '90457', 1383, 'village'),
                     (1406, 'Tammiku', '', 1383, 'village'),
                     (1407, 'Jõõdre', '90412', 1383, 'village'),
                     (1408, 'Hobulaiu', '90432', 1383, 'village'),
                     (1409, 'Vätse', '90481', 1383, 'village'),
                     (1410, 'Parila', '90418', 1383, 'village'),
                     (1411, 'Emmuvere', '90431', 1383, 'village'),
                     (1412, 'Kadaka', '90455', 1383, 'village'),
                     (1413, 'Väike-Ahli', '90446', 1383, 'village'),
                     (1414, 'Koheri', '90434', 1383, 'village'),
                     (1415, 'Koidu', '90410', 1383, 'village'),
                     (1416, 'Rummu', '90458', 1383, 'village'),
                     (1417, 'Haeska', '90407', 1383, 'village'),
                     (1418, 'Kolila', '90411', 1383, 'village'),
                     (1419, 'Kaevere', '90408', 1383, 'village'),
                     (1420, 'Mägari', '90438', 1383, 'village'),
                     (1421, 'Suure-Ahli', '90443', 1383, 'village'),
                     (1422, 'Aamse', '90450', 1383, 'village'),
                     (1423, 'Käpla', '90413', 1383, 'village'),
                     (1424, 'Erja', '90451', 1383, 'village'),
                     (1425, 'Litu', '90416', 1383, 'village'),
                     (1426, 'Kolu', '90435', 1383, 'village'),
                     (1427, 'Varni', '90445', 1383, 'village'),
                     (1428, 'Puise', '90420', 1383, 'village'),
                     (1429, 'Espre', '90452', 1383, 'village'),
                     (1430, 'Ammuta', '90406', 1383, 'village'),
                     (1431, 'Laheva', '90456', 1383, 'village'),
                     (1432, 'Uneste', '90427', 1383, 'village'),
                     (1433, 'Lõbe', '90417', 1383, 'village'),
                     (1434, 'Sepaküla', '90442', 1383, 'village'),
                     (1435, 'Puiatu', '90419', 1383, 'village'),
                     (1436, 'Kabrametsa', '90454', 1383, 'village'),
                     (1437, 'Saanika', '90423', 1383, 'village'),
                     (1438, 'Võnnu', '90460', 1383, 'village'),
                     (1439, 'Kiviküla', '90433', 1383, 'village'),
                     (1440, 'Panga', '90402', 1383, 'village'),
                     (1441, 'Haapsalu', '', 1351, 'town'),
                     (1442, 'Hanila', '', 1351, 'municipality'),
                     (1443, 'Virtsu', '', 1442, 'smallborough'),
                     (1444, 'Voose', '', 1442, 'village'),
                     (1445, 'Kõmsi', '', 1442, 'village'),
                     (1446, 'Rame', '90127', 1442, 'village'),
                     (1447, 'Rannaküla', '', 1442, 'village'),
                     (1448, 'Massu', '90111', 1442, 'village'),
                     (1449, 'Ullaste', '90117', 1442, 'village'),
                     (1450, 'Pajumaa', '90125', 1442, 'village'),
                     (1451, 'Kokuta', '90108', 1442, 'village'),
                     (1452, 'Vatla', '90103', 1442, 'village'),
                     (1453, 'Karuse', '90112', 1442, 'village'),
                     (1454, 'Mäense', '90113', 1442, 'village'),
                     (1455, 'Linnuse', '90121', 1442, 'village'),
                     (1456, 'Kõera', '90110', 1442, 'village'),
                     (1457, 'Kaseküla', '90106', 1442, 'village'),
                     (1458, 'Esivere', '90104', 1442, 'village'),
                     (1459, 'Ridase', '90131', 1442, 'village'),
                     (1460, 'Äila', '90128', 1442, 'village'),
                     (1461, 'Pivarootsi', '90126', 1442, 'village'),
                     (1462, 'Lõo', '90122', 1442, 'village'),
                     (1463, 'Nehatu', '90123', 1442, 'village'),
                     (1464, 'Kiska', '90120', 1442, 'village'),
                     (1465, 'Kuke', '90109', 1442, 'village'),
                     (1466, 'Kause', '90107', 1442, 'village'),
                     (1467, 'Nurmsi', '90124', 1442, 'village'),
                     (1468, 'Kinksi', '90130', 1442, 'village'),
                     (1469, 'Salevere', '90116', 1442, 'village'),
                     (1470, 'Taebla', '', 1351, 'municipality'),
                     (1471, 'Palivere', '', 1470, 'smallborough'),
                     (1472, 'Luigu', '', 1470, 'village'),
                     (1473, 'Vidruka', '', 1470, 'village'),
                     (1474, 'Nigula', '', 1470, 'village'),
                     (1475, 'Pälli', '', 1470, 'village'),
                     (1476, 'Väänla', '90819', 1470, 'village'),
                     (1477, 'Võntküla', '90820', 1470, 'village'),
                     (1478, 'Allikmaa', '90811', 1470, 'village'),
                     (1479, 'Nihka', '90808', 1470, 'village'),
                     (1480, 'Koela', '90806', 1470, 'village'),
                     (1481, 'Leediküla', '90813', 1470, 'village'),
                     (1482, 'Kedre', '90812', 1470, 'village'),
                     (1483, 'Kadarpiku', '90804', 1470, 'village'),
                     (1484, 'Kirimäe', '90805', 1470, 'village'),
                     (1485, 'Tagavere', '90816', 1470, 'village'),
                     (1486, 'Turvalepa', '90817', 1470, 'village'),
                     (1487, 'Oru', '', 1351, 'municipality'),
                     (1488, 'Linnamäe', '', 1487, 'village'),
                     (1489, 'Saunja', '', 1487, 'village'),
                     (1490, 'Niibi', '91015', 1487, 'village'),
                     (1491, 'Jalukse', '91004', 1487, 'village'),
                     (1492, 'Ingküla', '91003', 1487, 'village'),
                     (1493, 'Soolu', '91012', 1487, 'village'),
                     (1494, 'Auaste', '91002', 1487, 'village'),
                     (1495, 'Seljaküla', '91011', 1487, 'village'),
                     (1496, 'Mõisaküla', '', 1487, 'village'),
                     (1497, 'Kärbla', '91006', 1487, 'village'),
                     (1498, 'Keedika', '91005', 1487, 'village'),
                     (1499, 'Uugla', '91013', 1487, 'village'),
                     (1500, 'Salajõe', '91016', 1487, 'village'),
                     (1501, 'Vedra', '91014', 1487, 'village'),
                     (1502, 'Vormsi', '', 1351, 'municipality'),
                     (1503, 'Hullo', '', 1502, 'village'),
                     (1504, 'Sviby', '91313', 1502, 'village'),
                     (1505, 'Söderby', '91314', 1502, 'village'),
                     (1506, 'Rälby', '91310', 1502, 'village'),
                     (1507, 'Saxby', '91311', 1502, 'village'),
                     (1508, 'Norrby', '91308', 1502, 'village'),
                     (1509, 'Rumpo', '91309', 1502, 'village'),
                     (1510, 'Kersleti', '91307', 1502, 'village'),
                     (1511, 'Förby', '91305', 1502, 'village'),
                     (1512, 'Borrby', '91302', 1502, 'village'),
                     (1513, 'Suuremõisa', '91312', 1502, 'village'),
                     (1514, 'Fällarna', '91304', 1502, 'village'),
                     (1515, 'Diby', '91303', 1502, 'village'),
                     (1516, 'Martna', '', 1351, 'municipality'),
                     (1517, 'Rõude', '', 1516, 'village'),
                     (1518, 'Kaasiku', '', 1516, 'village'),
                     (1519, 'Niinja', '90628', 1516, 'village'),
                     (1520, 'Oonga', '90616', 1516, 'village'),
                     (1521, 'Ehmja', '90620', 1516, 'village'),
                     (1522, 'Uusküla', '90634', 1516, 'village'),
                     (1523, 'Väike-Lähtru', '90636', 1516, 'village'),
                     (1524, 'Soo-otsa', '90646', 1516, 'village'),
                     (1525, 'Enivere', '90621', 1516, 'village'),
                     (1526, 'Keskküla', '90606', 1516, 'village'),
                     (1527, 'Kokre', '90626', 1516, 'village'),
                     (1528, 'Kirna', '90625', 1516, 'village'),
                     (1529, 'Keskvere', '90642', 1516, 'village'),
                     (1530, 'Ohtla', '90630', 1516, 'village'),
                     (1531, 'Tuka', '90617', 1516, 'village'),
                     (1532, 'Kaare', '90640', 1516, 'village'),
                     (1533, 'Putkaste', '90631', 1516, 'village'),
                     (1534, 'Kabeli', '90641', 1516, 'village'),
                     (1535, 'Jõesse', '90622', 1516, 'village'),
                     (1536, 'Laiküla', '90612', 1516, 'village'),
                     (1537, 'Kasari', '90605', 1516, 'village'),
                     (1538, 'Keravere', '90614', 1516, 'village'),
                     (1539, 'Kurevere', '90643', 1516, 'village'),
                     (1540, 'Kuluse', '90627', 1516, 'village'),
                     (1541, 'Suure-Lähtru', '90632', 1516, 'village'),
                     (1542, 'Männiku', '90644', 1516, 'village'),
                     (1543, 'Allikotsa', '90613', 1516, 'village'),
                     (1544, 'Rannajõe', '90645', 1516, 'village'),
                     (1545, 'Kesu', '90624', 1516, 'village'),
                     (1546, 'Noarootsi', '', 1351, 'municipality'),
                     (1547, 'Spithami', '', 1546, 'village'),
                     (1548, 'Pürksi', '', 1546, 'village'),
                     (1549, 'Suur-Nõmmküla', '91232', 1546, 'village'),
                     (1550, 'Saare', '91205', 1546, 'village'),
                     (1551, 'Rooslepa', '91219', 1546, 'village'),
                     (1552, 'Einbi', '91203', 1546, 'village'),
                     (1553, 'Väike-Nõmmküla', '91233', 1546, 'village'),
                     (1554, 'Telise/Tällnäs', '91208', 1546, 'village'),
                     (1555, 'Elbiku', '91202', 1546, 'village'),
                     (1556, 'Paslepa/Pasklepi', '91204', 1546, 'village'),
                     (1557, 'Sutlepa', '91230', 1546, 'village'),
                     (1558, 'Dirhami', '91214', 1546, 'village'),
                     (1559, 'Hosby', '', 1546, 'village'),
                     (1560, 'Vanaküla', '', 1546, 'village'),
                     (1561, 'Aulepa', '91231', 1546, 'village'),
                     (1562, 'Tahu', '91206', 1546, 'village'),
                     (1563, 'Kudani/Gutanäsi', '91216', 1546, 'village'),
                     (1564, 'Hara', '91211', 1546, 'village'),
                     (1565, 'Höbringi', '91213', 1546, 'village'),
                     (1566, 'Tuksi', '91221', 1546, 'village'),
                     (1567, 'Riguldi', '91218', 1546, 'village'),
                     (1568, 'Osmussaare', '91217', 1546, 'village'),
                     (1569, 'Österby', '91207', 1546, 'village'),
                     (1570, 'Nõva', '', 1351, 'municipality'),
                     (1571, 'Hindaste', '91102', 1570, 'village'),
                     (1572, 'Peraküla', '91114', 1570, 'village'),
                     (1573, 'Variku', '91106', 1570, 'village'),
                     (1574, 'Vaisi', '91105', 1570, 'village'),
                     (1575, 'Tusari', '91112', 1570, 'village'),
                     (1576, 'Nõmmemaa', '91103', 1570, 'village'),
                     (1577, 'Kullamaa', '', 1351, 'municipality'),
                     (1578, 'Koluvere', '', 1577, 'village'),
                     (1579, 'Lemmikküla', '90714', 1577, 'village'),
                     (1580, 'Jõgisoo', '90710', 1577, 'village'),
                     (1581, 'Ubasalu', '90719', 1577, 'village'),
                     (1582, 'Kullametsa', '90713', 1577, 'village'),
                     (1583, 'Üdruma', '90720', 1577, 'village'),
                     (1584, 'Silla', '90718', 1577, 'village'),
                     (1585, 'Päri', '90717', 1577, 'village'),
                     (1586, 'Kalju', '90703', 1577, 'village'),
                     (1587, 'Kastja', '90715', 1577, 'village'),
                     (1588, 'Mõrdu', '90716', 1577, 'village'),
                     (1589, 'Leila', '90704', 1577, 'village'),
                     (1590, 'Liivi', '90711', 1577, 'village'),
                     (1591, 'Lääne-Viru', '', None, 'county'),
                     (1592, 'Tapa', '', 1591, 'municipality'),
                     (1593, 'Lehtse', '', 1592, 'smallborough'),
                     (1594, 'Kuru', '', 1592, 'village'),
                     (1595, 'Jäneda', '', 1592, 'village'),
                     (1596, 'Imastu', '45001', 1592, 'village'),
                     (1597, 'Nõmmküla', '', 1592, 'village'),
                     (1598, 'Karkuse', '', 1592, 'village'),
                     (1599, 'Näo', '45007', 1592, 'village'),
                     (1600, 'Linnape', '73606', 1592, 'village'),
                     (1601, 'Läpi', '73607', 1592, 'village'),
                     (1602, 'Läste', '73608', 1592, 'village'),
                     (1603, 'Vahakulmu', '45011', 1592, 'village'),
                     (1604, 'Raudla', '73612', 1592, 'village'),
                     (1605, 'Rabasaare', '73611', 1592, 'village'),
                     (1606, 'Kõrveküla', '', 1592, 'village'),
                     (1607, 'Räsna', '73614', 1592, 'village'),
                     (1608, 'Lokuta', '45004', 1592, 'village'),
                     (1609, 'Patika', '73609', 1592, 'village'),
                     (1610, 'Tõõrakõrve', '73615', 1592, 'village'),
                     (1611, 'Pruuna', '73610', 1592, 'village'),
                     (1612, 'Jootme', '73603', 1592, 'village'),
                     (1613, 'Saiakopli', '45009', 1592, 'village'),
                     (1614, 'Piilu', '45008', 1592, 'village'),
                     (1615, 'Saksi', '45010', 1592, 'village'),
                     (1616, 'Loksu', '45003', 1592, 'village'),
                     (1617, 'Moe', '45005', 1592, 'village'),
                     (1618, 'Rakvere', '', 1591, 'municipality'),
                     (1619, 'Lepna', '', 1618, 'smallborough'),
                     (1620, 'Päide', '', 1618, 'village'),
                     (1621, 'Tõrremäe', '', 1618, 'village'),
                     (1622, 'Veltsi', '', 1618, 'village'),
                     (1623, 'Lasila', '', 1618, 'village'),
                     (1624, 'Taaravainu', '', 1618, 'village'),
                     (1625, 'Kõrgemäe', '', 1618, 'village'),
                     (1626, 'Arkna', '', 1618, 'village'),
                     (1627, 'Tõrma', '44406', 1618, 'village'),
                     (1628, 'Eesküla', '44405', 1618, 'village'),
                     (1629, 'Paatna', '44411', 1618, 'village'),
                     (1630, 'Mädapea', '44409', 1618, 'village'),
                     (1631, 'Karunga', '44404', 1618, 'village'),
                     (1632, 'Levala', '', 1618, 'village'),
                     (1633, 'Kullaaru', '44410', 1618, 'village'),
                     (1634, 'Tobia', '44416', 1618, 'village'),
                     (1635, 'Kloodi', '44413', 1618, 'village'),
                     (1636, 'Järni', '44407', 1618, 'village'),
                     (1637, 'Karivärava', '44412', 1618, 'village'),
                     (1638, 'Karitsa', '44403', 1618, 'village'),
                     (1639, 'Vinni', '', 1591, 'municipality'),
                     (1640, 'Tudu', '', 1639, 'smallborough'),
                     (1641, 'Piira', '', 1639, 'village'),
                     (1642, 'Mõdriku', '', 1639, 'village'),
                     (1643, 'Roela', '', 1639, 'smallborough'),
                     (1644, 'Lähtse', '', 1639, 'village'),
                     (1645, 'Vetiku', '', 1639, 'village'),
                     (1646, 'Kakumäe', '', 1639, 'village'),
                     (1647, 'Küti', '', 1639, 'village'),
                     (1648, 'Pajusti', '', 1639, 'smallborough'),
                     (1649, 'Kadila', '', 1639, 'village'),
                     (1650, 'Viru-Jaagupi', '', 1639, 'smallborough'),
                     (1651, 'Veadla', '', 1639, 'village'),
                     (1652, 'Allika', '46612', 1639, 'village'),
                     (1653, 'Obja', '46629', 1639, 'village'),
                     (1654, 'Anguse', '46615', 1639, 'village'),
                     (1655, 'Kannastiku', '46622', 1639, 'village'),
                     (1656, 'Suigu', '46637', 1639, 'village'),
                     (1657, 'Lepiku', '46627', 1639, 'village'),
                     (1658, 'Koeravere', '46613', 1639, 'village'),
                     (1659, 'Rünga', '46634', 1639, 'village'),
                     (1660, 'Rasivere', '46632', 1639, 'village'),
                     (1661, 'Aravuse', '46616', 1639, 'village'),
                     (1662, 'Kaukvere', '46623', 1639, 'village'),
                     (1663, 'Soonuka', '46636', 1639, 'village'),
                     (1664, 'Palasi', '46630', 1639, 'village'),
                     (1665, 'Nurmetu', '46628', 1639, 'village'),
                     (1666, 'Võhu', '46620', 1639, 'village'),
                     (1667, 'Mäetaguse', '46639', 1639, 'village'),
                     (1668, 'Ristiküla', '46633', 1639, 'village'),
                     (1669, 'Voore', '46642', 1639, 'village'),
                     (1670, 'Puka', '46631', 1639, 'village'),
                     (1671, 'Kulina', '46625', 1639, 'village'),
                     (1672, 'Aruküla', '46617', 1639, 'village'),
                     (1673, 'Alavere', '46611', 1639, 'village'),
                     (1674, 'Inju', '46619', 1639, 'village'),
                     (1675, 'Vana-Vinni', '46640', 1639, 'village'),
                     (1676, 'Saara', '46635', 1639, 'village'),
                     (1677, 'Kehala', '46624', 1639, 'village'),
                     (1678, 'Aruvälja', '46618', 1639, 'village'),
                     (1679, 'Tamsalu', '', 1591, 'town'),
                     (1680, 'Sääse', '', 1679, 'smallborough'),
                     (1681, 'Vajangu', '', 1679, 'village'),
                     (1682, 'Porkuni', '', 1679, 'village'),
                     (1683, 'Assamalla', '', 1679, 'village'),
                     (1684, 'Sauvälja', '46023', 1679, 'village'),
                     (1685, 'Järsi', '46007', 1679, 'village'),
                     (1686, 'Savalduma', '46024', 1679, 'village'),
                     (1687, 'Järvajõe', '46008', 1679, 'village'),
                     (1688, 'Araski', '46005', 1679, 'village'),
                     (1689, 'Uudeküla', '46026', 1679, 'village'),
                     (1690, 'Koplitaguse', '46013', 1679, 'village'),
                     (1691, 'Naistevälja', '46020', 1679, 'village'),
                     (1692, 'Lemmküla', '46017', 1679, 'village'),
                     (1693, 'Vadiküla', '46027', 1679, 'village'),
                     (1694, 'Kerguta', '46011', 1679, 'village'),
                     (1695, 'Vistla', '46028', 1679, 'village'),
                     (1696, 'Kuie', '46014', 1679, 'village'),
                     (1697, 'Kaeva', '46010', 1679, 'village'),
                     (1698, 'Loksa', '46018', 1679, 'village'),
                     (1699, 'Alupere', '46004', 1679, 'village'),
                     (1700, 'Võhmetu', '46029', 1679, 'village'),
                     (1701, 'Kursi', '46016', 1679, 'village'),
                     (1702, 'Võhmuta', '46030', 1679, 'village'),
                     (1703, 'Koiduküla', '46012', 1679, 'village'),
                     (1704, 'Kullenga', '46015', 1679, 'village'),
                     (1705, 'Metskaevu', '46019', 1679, 'village'),
                     (1706, 'Põdrangu', '46022', 1679, 'village'),
                     (1707, 'Piisupi', '46021', 1679, 'village'),
                     (1708, 'Türje', '46025', 1679, 'village'),
                     (1709, 'Rakke', '', 1591, 'municipality'),
                     (1710, 'Suure-Rakke', '', 1709, 'village'),
                     (1711, 'Mõisamaa', '', 1709, 'village'),
                     (1712, 'Edru', '46304', 1709, 'village'),
                     (1713, 'Mäiste', '46320', 1709, 'village'),
                     (1714, 'Kõpsta', '46314', 1709, 'village'),
                     (1715, 'Padaküla', '46323', 1709, 'village'),
                     (1716, 'Tammiku', '', 1709, 'village'),
                     (1717, 'Ao', '46303', 1709, 'village'),
                     (1718, 'Kadiküla', '46308', 1709, 'village'),
                     (1719, 'Väike-Rakke', '46331', 1709, 'village'),
                     (1720, 'Väike-Tammiku', '46332', 1709, 'village'),
                     (1721, 'Emumäe', '46305', 1709, 'village'),
                     (1722, 'Sootaguse', '', 1709, 'village'),
                     (1723, 'Piibe', '46324', 1709, 'village'),
                     (1724, 'Liigvalla', '46318', 1709, 'village'),
                     (1725, 'Olju', '46322', 1709, 'village'),
                     (1726, 'Kellamäe', '46310', 1709, 'village'),
                     (1727, 'Kamariku', '46309', 1709, 'village'),
                     (1728, 'Koluvere', '46313', 1709, 'village'),
                     (1729, 'Kitsemetsa', '46311', 1709, 'village'),
                     (1730, 'Kaavere', '46307', 1709, 'village'),
                     (1731, 'Lahu', '46315', 1709, 'village'),
                     (1732, 'Salla', '46302', 1709, 'village'),
                     (1733, 'Villakvere', '46330', 1709, 'village'),
                     (1734, 'Koila', '', 1709, 'village'),
                     (1735, 'Räitsvere', '46325', 1709, 'village'),
                     (1736, 'Lasinurme', '46317', 1709, 'village'),
                     (1737, 'Lammasküla', '46316', 1709, 'village'),
                     (1738, 'Väike-Maarja', '', 1591, 'municipality'),
                     (1739, 'Simuna', '', 1738, 'smallborough'),
                     (1740, 'Kiltsi', '', 1738, 'smallborough'),
                     (1741, 'Triigi', '', 1738, 'village'),
                     (1742, 'Vao', '', 1738, 'village'),
                     (1743, 'Ebavere', '', 1738, 'village'),
                     (1744, 'Nadalama', '46221', 1738, 'village'),
                     (1745, 'Raigu', '46227', 1738, 'village'),
                     (1746, 'Aburi', '46206', 1738, 'village'),
                     (1747, 'Eipri', '46210', 1738, 'village'),
                     (1748, 'Pikevere', '46204', 1738, 'village'),
                     (1749, 'Käru', '46217', 1738, 'village'),
                     (1750, 'Orguse', '46223', 1738, 'village'),
                     (1751, 'Imukvere', '46212', 1738, 'village'),
                     (1752, 'Koonu', '46213', 1738, 'village'),
                     (1753, 'Pudivere', '46225', 1738, 'village'),
                     (1754, 'Avanduse', '46207', 1738, 'village'),
                     (1755, 'Pandivere', '46224', 1738, 'village'),
                     (1756, 'Rastla', '46228', 1738, 'village'),
                     (1757, 'Varangu', '', 1738, 'village'),
                     (1758, 'Uuemõisa', '46229', 1738, 'village'),
                     (1759, 'Kännuküla', '46215', 1738, 'village'),
                     (1760, 'Raeküla', '46226', 1738, 'village'),
                     (1761, 'Vorsti', '46232', 1738, 'village'),
                     (1762, 'Äntu', '46234', 1738, 'village'),
                     (1763, 'Ärina', '46235', 1738, 'village'),
                     (1764, 'Määri', '46219', 1738, 'village'),
                     (1765, 'Nõmme', '46222', 1738, 'village'),
                     (1766, 'Kurtna', '46214', 1738, 'village'),
                     (1767, 'Aavere', '', 1738, 'village'),
                     (1768, 'Liivaküla', '46218', 1738, 'village'),
                     (1769, 'Võivere', '46233', 1738, 'village'),
                     (1770, 'Avispea', '46208', 1738, 'village'),
                     (1771, 'Hirla', '46211', 1738, 'village'),
                     (1772, 'Kärsa', '46216', 1738, 'village'),
                     (1773, 'Müüriku', '46220', 1738, 'village'),
                     (1774, 'Sõmeru', '', 1591, 'municipality'),
                     (1775, 'Uhtna', '', 1774, 'smallborough'),
                     (1776, 'Ubja', '', 1774, 'village'),
                     (1777, 'Toomla', '', 1774, 'village'),
                     (1778, 'Ussimäe', '', 1774, 'village'),
                     (1779, 'Näpi', '', 1774, 'smallborough'),
                     (1780, 'Roodevälja', '', 1774, 'village'),
                     (1781, 'Vaeküla', '', 1774, 'village'),
                     (1782, 'Kohala', '', 1774, 'village'),
                     (1783, 'Rägavere', '', 1774, 'village'),
                     (1784, 'Põlula', '', 1774, 'village'),
                     (1785, 'Nõmmise', '46710', 1774, 'village'),
                     (1786, 'Viru-Kabala', '46714', 1774, 'village'),
                     (1787, 'Miila', '46706', 1774, 'village'),
                     (1788, 'Sae', '46712', 1774, 'village'),
                     (1789, 'Kantküla', '46703', 1774, 'village'),
                     (1790, 'Kõrma', '46704', 1774, 'village'),
                     (1791, 'Nurkse', '46709', 1774, 'village'),
                     (1792, 'Lavi', '46705', 1774, 'village'),
                     (1793, 'Mõedaka', '46708', 1774, 'village'),
                     (1794, 'Ulvi', '46701', 1774, 'village'),
                     (1795, 'Aasuvälja', '46702', 1774, 'village'),
                     (1796, 'Uljaste', '46713', 1774, 'village'),
                     (1797, 'Männikvälja', '46707', 1774, 'village'),
                     (1798, 'Katku', '44214', 1774, 'village'),
                     (1799, 'Sämi-Tagaküla', '44225', 1774, 'village'),
                     (1800, 'Sooaluse', '44223', 1774, 'village'),
                     (1801, 'Jäätma', '', 1774, 'village'),
                     (1802, 'Kohala-Eesküla', '44216', 1774, 'village'),
                     (1803, 'Koovälja', '44217', 1774, 'village'),
                     (1804, 'Katela', '44213', 1774, 'village'),
                     (1805, 'Raudlepa', '44221', 1774, 'village'),
                     (1806, 'Sämi', '44224', 1774, 'village'),
                     (1807, 'Aluvere', '44208', 1774, 'village'),
                     (1808, 'Aresi', '44210', 1774, 'village'),
                     (1809, 'Kaarli', '44212', 1774, 'village'),
                     (1810, 'Nurme', '44219', 1774, 'village'),
                     (1811, 'Rahkla', '', 1774, 'village'),
                     (1812, 'Raudvere', '44222', 1774, 'village'),
                     (1813, 'Varudi-Altküla', '44228', 1774, 'village'),
                     (1814, 'Varudi-Vanaküla', '44229', 1774, 'village'),
                     (1815, 'Muru', '44218', 1774, 'village'),
                     (1816, 'Andja', '44209', 1774, 'village'),
                     (1817, 'Papiaru', '44206', 1774, 'village'),
                     (1818, 'Vihula', '', 1591, 'municipality'),
                     (1819, 'Võsu', '', 1818, 'smallborough'),
                     (1820, 'Käsmu', '', 1818, 'village'),
                     (1821, 'Sagadi', '', 1818, 'village'),
                     (1822, 'Võsupere', '', 1818, 'village'),
                     (1823, 'Palmse', '', 1818, 'village'),
                     (1824, 'Oandu', '', 1818, 'village'),
                     (1825, 'Metsiku', '45427', 1818, 'village'),
                     (1826, 'Annikvere', '45410', 1818, 'village'),
                     (1827, 'Ilumäe', '45414', 1818, 'village'),
                     (1828, 'Adaka', '45407', 1818, 'village'),
                     (1829, 'Kakuvälja', '45416', 1818, 'village'),
                     (1830, 'Villandi', '45449', 1818, 'village'),
                     (1831, 'Koolimäe', '45420', 1818, 'village'),
                     (1832, 'Natturi', '45430', 1818, 'village'),
                     (1833, 'Lahe', '45423', 1818, 'village'),
                     (1834, 'Joandu', '45415', 1818, 'village'),
                     (1835, 'Vila', '45448', 1818, 'village'),
                     (1836, 'Rutja', '45451', 1818, 'village'),
                     (1837, 'Metsanurga', '45426', 1818, 'village'),
                     (1838, 'Lauli', '45424', 1818, 'village'),
                     (1839, 'Altja', '45408', 1818, 'village'),
                     (1840, 'Pajuveski', '45434', 1818, 'village'),
                     (1841, 'Võhma', '', 1818, 'village'),
                     (1842, 'Karula', '45417', 1818, 'village'),
                     (1843, 'Noonu', '45431', 1818, 'village'),
                     (1844, 'Korjuse', '45421', 1818, 'village'),
                     (1845, 'Haili', '45413', 1818, 'village'),
                     (1846, 'Tepelvälja', '45440', 1818, 'village'),
                     (1847, 'Mustoja', '45429', 1818, 'village'),
                     (1848, 'Tõugu', '45444', 1818, 'village'),
                     (1849, 'Muike', '45428', 1818, 'village'),
                     (1850, 'Tidriku', '45441', 1818, 'village'),
                     (1851, 'Toolse', '45443', 1818, 'village'),
                     (1852, 'Eru', '45412', 1818, 'village'),
                     (1853, 'Pihlaspea', '45437', 1818, 'village'),
                     (1854, 'Salatse', '45439', 1818, 'village'),
                     (1855, 'Paasi', '45433', 1818, 'village'),
                     (1856, 'Tiigi', '45442', 1818, 'village'),
                     (1857, 'Lobi', '45425', 1818, 'village'),
                     (1858, 'Karepa', '45401', 1818, 'village'),
                     (1859, 'Aasumetsa', '45406', 1818, 'village'),
                     (1860, 'Andi', '45409', 1818, 'village'),
                     (1861, 'Kosta', '45422', 1818, 'village'),
                     (1862, 'Vainupea', '45446', 1818, 'village'),
                     (1863, 'Pedassaare', '45436', 1818, 'village'),
                     (1864, 'Koljaku', '45419', 1818, 'village'),
                     (1865, 'Vatku', '45447', 1818, 'village'),
                     (1866, 'Sakussaare', '45438', 1818, 'village'),
                     (1867, 'Uusküla', '45445', 1818, 'village'),
                     (1868, 'Kiva', '45418', 1818, 'village'),
                     (1869, 'Vergi', '45404', 1818, 'village'),
                     (1870, 'Haljala', '', 1591, 'municipality'),
                     (1871, 'Essu', '', 1870, 'village'),
                     (1872, 'Aaspere', '', 1870, 'village'),
                     (1873, 'Vanamõisa', '45319', 1870, 'village'),
                     (1874, 'Kandle', '45308', 1870, 'village'),
                     (1875, 'Pehka', '45315', 1870, 'village'),
                     (1876, 'Kärmu', '45311', 1870, 'village'),
                     (1877, 'Põdruse', '45316', 1870, 'village'),
                     (1878, 'Tatruse', '45318', 1870, 'village'),
                     (1879, 'Auküla', '45306', 1870, 'village'),
                     (1880, 'Kõldu', '45312', 1870, 'village'),
                     (1881, 'Kisuvere', '45310', 1870, 'village'),
                     (1882, 'Kavastu', '45309', 1870, 'village'),
                     (1883, 'Aasu', '45304', 1870, 'village'),
                     (1884, 'Lihulõpe', '45313', 1870, 'village'),
                     (1885, 'Võle', '45321', 1870, 'village'),
                     (1886, 'Idavere', '45307', 1870, 'village'),
                     (1887, 'Aaviku', '45305', 1870, 'village'),
                     (1888, 'Sauste', '45317', 1870, 'village'),
                     (1889, 'Liiguste', '45314', 1870, 'village'),
                     (1890, 'Kunda', '', 1591, 'town'),
                     (1891, 'Kadrina', '', 1591, 'municipality'),
                     (1892, 'Viitna', '', 1891, 'village'),
                     (1893, 'Hulja', '', 1891, 'smallborough'),
                     (1894, 'Tokolopi', '', 1891, 'village'),
                     (1895, 'Kadapiku', '', 1891, 'village'),
                     (1896, 'Tirbiku', '', 1891, 'village'),
                     (1897, 'Mõndavere', '45222', 1891, 'village'),
                     (1898, 'Võduvere', '45238', 1891, 'village'),
                     (1899, 'Kihlevere', '45215', 1891, 'village'),
                     (1900, 'Mäo', '45223', 1891, 'village'),
                     (1901, 'Põima', '45228', 1891, 'village'),
                     (1902, 'Vandu', '45237', 1891, 'village'),
                     (1903, 'Uku', '45234', 1891, 'village'),
                     (1904, 'Läsna', '45221', 1891, 'village'),
                     (1905, 'Vohnja', '45204', 1891, 'village'),
                     (1906, 'Ohepalu', '45225', 1891, 'village'),
                     (1907, 'Arbavere', '45206', 1891, 'village'),
                     (1908, 'Kiku', '45216', 1891, 'village'),
                     (1909, 'Vaiatu', '45236', 1891, 'village'),
                     (1910, 'Ama', '45205', 1891, 'village'),
                     (1911, 'Loobu', '45220', 1891, 'village'),
                     (1912, 'Udriku', '45233', 1891, 'village'),
                     (1913, 'Hõbeda', '45207', 1891, 'village'),
                     (1914, 'Rõmeda', '45230', 1891, 'village'),
                     (1915, 'Kallukse', '45214', 1891, 'village'),
                     (1916, 'Jõepere', '45209', 1891, 'village'),
                     (1917, 'Undla', '45235', 1891, 'village'),
                     (1918, 'Neeruti', '45224', 1891, 'village'),
                     (1919, 'Ridaküla', '45229', 1891, 'village'),
                     (1920, 'Lante', '45218', 1891, 'village'),
                     (1921, 'Võipere', '45239', 1891, 'village'),
                     (1922, 'Leikude', '45219', 1891, 'village'),
                     (1923, 'Härjadi', '45208', 1891, 'village'),
                     (1924, 'Orutaguse', '45226', 1891, 'village'),
                     (1925, 'Jõetaguse', '45210', 1891, 'village'),
                     (1926, 'Salda', '45231', 1891, 'village'),
                     (1927, 'Saukse', '45232', 1891, 'village'),
                     (1928, 'Pariisi', '45227', 1891, 'village'),
                     (1929, 'Laekvere', '', 1591, 'municipality'),
                     (1930, 'Muuga', '', 1929, 'village'),
                     (1931, 'Vassivere', '46519', 1929, 'village'),
                     (1932, 'Alekvere', '46505', 1929, 'village'),
                     (1933, 'Rajaküla', '46513', 1929, 'village'),
                     (1934, 'Kellavere', '46508', 1929, 'village'),
                     (1935, 'Salutaguse', '46516', 1929, 'village'),
                     (1936, 'Venevere', '46504', 1929, 'village'),
                     (1937, 'Rohu', '46515', 1929, 'village'),
                     (1938, 'Moora', '46510', 1929, 'village'),
                     (1939, 'Arukse', '46514', 1929, 'village'),
                     (1940, 'Kaasiksaare', '46507', 1929, 'village'),
                     (1941, 'Sirevere', '46517', 1929, 'village'),
                     (1942, 'Ilistvere', '46506', 1929, 'village'),
                     (1943, 'Padu', '46512', 1929, 'village'),
                     (1944, 'Luusika', '46509', 1929, 'village'),
                     (1945, 'Paasvere', '46511', 1929, 'village'),
                     (1946, 'Viru-Nigula', '', 1591, 'municipality'),
                     (1947, 'Siberi', '44028', 1946, 'village'),
                     (1948, 'Selja', '44027', 1946, 'village'),
                     (1949, 'Vasta', '44034', 1946, 'village'),
                     (1950, 'Kabeli', '44004', 1946, 'village'),
                     (1951, 'Kuura', '44012', 1946, 'village'),
                     (1952, 'Malla', '44016', 1946, 'village'),
                     (1953, 'Võrkla', '44035', 1946, 'village'),
                     (1954, 'Kaliküla', '44005', 1946, 'village'),
                     (1955, 'Samma', '44026', 1946, 'village'),
                     (1956, 'Ojaküla', '44020', 1946, 'village'),
                     (1957, 'Letipea', '44013', 1946, 'village'),
                     (1958, 'Nugeri', '44019', 1946, 'village'),
                     (1959, 'Linnuse', '44014', 1946, 'village'),
                     (1960, 'Pikaristi', '44024', 1946, 'village'),
                     (1961, 'Iila', '44003', 1946, 'village'),
                     (1962, 'Tüükri', '44031', 1946, 'village'),
                     (1963, 'Toomika', '44030', 1946, 'village'),
                     (1964, 'Kutsala', '44011', 1946, 'village'),
                     (1965, 'Kurna', '44010', 1946, 'village'),
                     (1966, 'Aasukalda', '44002', 1946, 'village'),
                     (1967, 'Mahu', '44015', 1946, 'village'),
                     (1968, 'Paasküla', '44021', 1946, 'village'),
                     (1969, 'Varudi', '44033', 1946, 'village'),
                     (1970, 'Pärna', '44025', 1946, 'village'),
                     (1971, 'Simunamäe', '44029', 1946, 'village'),
                     (1972, 'Pada', '44023', 1946, 'village'),
                     (1973, 'Pada-Aruküla', '44022', 1946, 'village'),
                     (1974, 'Villavere', '44037', 1946, 'village'),
                     (1975, 'Kanguristi', '44006', 1946, 'village'),
                     (1976, 'Marinu', '44017', 1946, 'village'),
                     (1977, 'Metsavälja', '44018', 1946, 'village'),
                     (1978, 'Kiviküla', '44007', 1946, 'village'),
                     (1979, 'Unukse', '44032', 1946, 'village'),
                     (1980, 'Eisma', '', 1591, 'municipality'),
                     (1981, 'Põlva', '', None, 'county'),
                     (1982, 'Räpina', '', 1981, 'town'),
                     (1983, 'Ristipalo', '', 1982, 'village'),
                     (1984, 'Ruusa', '', 1982, 'village'),
                     (1985, 'Leevaku', '', 1982, 'village'),
                     (1986, 'Linte', '', 1982, 'village'),
                     (1987, 'Naha', '64411', 1982, 'village'),
                     (1988, 'Kõnnu', '64407', 1982, 'village'),
                     (1989, 'Võiardi', '64426', 1982, 'village'),
                     (1990, 'Saareküla', '64419', 1982, 'village'),
                     (1991, 'Tsirksi', '64425', 1982, 'village'),
                     (1992, 'Sillapää', '64420', 1982, 'village'),
                     (1993, 'Köstrimäe', '64408', 1982, 'village'),
                     (1994, 'Toolamaa', '64423', 1982, 'village'),
                     (1995, 'Võuküla', '64427', 1982, 'village'),
                     (1996, 'Mägiotsa', '64410', 1982, 'village'),
                     (1997, 'Nulga', '64412', 1982, 'village'),
                     (1998, 'Pindi', '64413', 1982, 'village'),
                     (1999, 'Kassilaane', '64406', 1982, 'village'),
                     (2000, 'Raigla', '64417', 1982, 'village'),
                     (2001, 'Tooste', '64424', 1982, 'village'),
                     (2002, 'Meelva', '64409', 1982, 'village'),
                     (2003, 'Jaanikeste', '64405', 1982, 'village'),
                     (2004, 'Rahumäe', '64416', 1982, 'village'),
                     (2005, 'Pääsna', '64414', 1982, 'village'),
                     (2006, 'Sülgoja', '64422', 1982, 'village'),
                     (2007, 'Raadama', '64415', 1982, 'village'),
                     (2008, 'Suure-Veerksu', '64421', 1982, 'village'),
                     (2009, 'Põlva', '', 1981, 'town'),
                     (2010, 'Soesaare', '', 2009, 'village'),
                     (2011, 'Rosma', '', 2009, 'village'),
                     (2012, 'Himmaste', '', 2009, 'village'),
                     (2013, 'Taevaskoja', '', 2009, 'village'),
                     (2014, 'Mammaste', '', 2009, 'village'),
                     (2015, 'Tromsi', '63223', 2009, 'village'),
                     (2016, 'Adiste', '63204', 2009, 'village'),
                     (2017, 'Valgesoo', '63226', 2009, 'village'),
                     (2018, 'Vanaküla', '63227', 2009, 'village'),
                     (2019, 'Metste', '63213', 2009, 'village'),
                     (2020, 'Nooritsmetsa', '63215', 2009, 'village'),
                     (2021, 'Peri', '63218', 2009, 'village'),
                     (2022, 'Holvandi', '63207', 2009, 'village'),
                     (2023, 'Puskaru', '63219', 2009, 'village'),
                     (2024, 'Meemaste', '63212', 2009, 'village'),
                     (2025, 'Eoste', '63206', 2009, 'village'),
                     (2026, 'Puuri', '63220', 2009, 'village'),
                     (2027, 'Kähri', '63209', 2009, 'village'),
                     (2028, 'Orajõe', '63216', 2009, 'village'),
                     (2029, 'Aarna', '63203', 2009, 'village'),
                     (2030, 'Lutsu', '63210', 2009, 'village'),
                     (2031, 'Tännassilma', '63224', 2009, 'village'),
                     (2032, 'Kiuma', '', 2009, 'village'),
                     (2033, 'Uibujärve', '63225', 2009, 'village'),
                     (2034, 'Miiaste', '63214', 2009, 'village'),
                     (2035, 'Partsi', '63217', 2009, 'village'),
                     (2036, 'Andre', '63205', 2009, 'village'),
                     (2037, 'Veriora', '', 1981, 'municipality'),
                     (2038, 'Leevi', '', 2037, 'village'),
                     (2039, 'Männisalu', '64215', 2037, 'village'),
                     (2040, 'Viira', '64224', 2037, 'village'),
                     (2041, 'Kullamäe', '64210', 2037, 'village'),
                     (2042, 'Haavapää', '64203', 2037, 'village'),
                     (2043, 'Nohipalo', '64216', 2037, 'village'),
                     (2044, 'Koolmajärve', '64209', 2037, 'village'),
                     (2045, 'Kunksilla', '64211', 2037, 'village'),
                     (2046, 'Laho', '', 2037, 'village'),
                     (2047, 'Süvahavva', '64220', 2037, 'village'),
                     (2048, 'Soohara', '64219', 2037, 'village'),
                     (2049, 'Timo', '64221', 2037, 'village'),
                     (2050, 'Sarvemäe', '64218', 2037, 'village'),
                     (2051, 'Vareste', '64222', 2037, 'village'),
                     (2052, 'Kikka', '64206', 2037, 'village'),
                     (2053, 'Lihtensteini', '64213', 2037, 'village'),
                     (2054, 'Väike-Veerksu', '64228', 2037, 'village'),
                     (2055, 'Kirmsi', '64207', 2037, 'village'),
                     (2056, 'Vändra', '64229', 2037, 'village'),
                     (2057, 'Võika', '64227', 2037, 'village'),
                     (2058, 'Jõeveere', '64233', 2037, 'village'),
                     (2059, 'Himmiste', '64204', 2037, 'village'),
                     (2060, 'Viluste', '64225', 2037, 'village'),
                     (2061, 'Mõtsavaara', '64214', 2037, 'village'),
                     (2062, 'Koolma', '64208', 2037, 'village'),
                     (2063, 'Vinso', '64226', 2037, 'village'),
                     (2064, 'Pahtpää', '64217', 2037, 'village'),
                     (2065, 'Jõevaara', '64205', 2037, 'village'),
                     (2066, 'Verioramõisa', '64223', 2037, 'village'),
                     (2067, 'Kanepi', '', 1981, 'municipality'),
                     (2068, 'Põlgaste', '', 2067, 'village'),
                     (2069, 'Magari', '', 2067, 'village'),
                     (2070, 'Jõgehara', '63109', 2067, 'village'),
                     (2071, 'Peetrimõisa', '63118', 2067, 'village'),
                     (2072, 'Kooraste', '63114', 2067, 'village'),
                     (2073, 'Sõreste', '63121', 2067, 'village'),
                     (2074, 'Lauri', '63115', 2067, 'village'),
                     (2075, 'Soodoma', '63124', 2067, 'village'),
                     (2076, 'Jõksi', '63110', 2067, 'village'),
                     (2077, 'Heisri', '63106', 2067, 'village'),
                     (2078, 'Koigera', '63113', 2067, 'village'),
                     (2079, 'Hino', '63107', 2067, 'village'),
                     (2080, 'Rebaste', '63120', 2067, 'village'),
                     (2081, 'Kaagvere', '63103', 2067, 'village'),
                     (2082, 'Närapää', '63117', 2067, 'village'),
                     (2083, 'Erastvere', '63105', 2067, 'village'),
                     (2084, 'Piigandi', '63119', 2067, 'village'),
                     (2085, 'Kaagna', '63111', 2067, 'village'),
                     (2086, 'Hurmi', '63108', 2067, 'village'),
                     (2087, 'Varbuse', '63122', 2067, 'village'),
                     (2088, 'Karste', '63112', 2067, 'village'),
                     (2089, 'Ahja', '', 1981, 'municipality'),
                     (2090, 'Ibaste', '63703', 2089, 'village'),
                     (2091, 'Akste', '63702', 2089, 'village'),
                     (2092, 'Mõtsküla', '63708', 2089, 'village'),
                     (2093, 'Vanamõisa', '63709', 2089, 'village'),
                     (2094, 'Kosova', '63704', 2089, 'village'),
                     (2095, 'Mustakurmu', '63707', 2089, 'village'),
                     (2096, 'Loko', '63706', 2089, 'village'),
                     (2097, 'Kärsa', '63705', 2089, 'village'),
                     (2098, 'Kõlleste', '', 1981, 'municipality'),
                     (2099, 'Krootuse', '', 2098, 'village'),
                     (2100, 'Prangli', '', 2098, 'village'),
                     (2101, 'Veski', '63511', 2098, 'village'),
                     (2102, 'Häätaru', '63502', 2098, 'village'),
                     (2103, 'Tõdu', '63510', 2098, 'village'),
                     (2104, 'Karaski', '63504', 2098, 'village'),
                     (2105, 'Voorepalu', '63512', 2098, 'village'),
                     (2106, 'Piigaste', '63507', 2098, 'village'),
                     (2107, 'Palutaja', '63506', 2098, 'village'),
                     (2108, 'Tuulemäe', '63509', 2098, 'village'),
                     (2109, 'Ihamaru', '63503', 2098, 'village'),
                     (2110, 'Vastse-Kuuste', '', 1981, 'municipality'),
                     (2111, 'Vooreküla', '', 2110, 'village'),
                     (2112, 'Karilatsi', '', 2110, 'village'),
                     (2113, 'Valgemetsa', '63610', 2110, 'village'),
                     (2114, 'Kiidjärve', '63604', 2110, 'village'),
                     (2115, 'Koorvere', '63605', 2110, 'village'),
                     (2116, 'Logina', '63607', 2110, 'village'),
                     (2117, 'Padari', '63609', 2110, 'village'),
                     (2118, 'Lootvina', '63608', 2110, 'village'),
                     (2119, 'Leevijõe', '63606', 2110, 'village'),
                     (2120, 'Värska', '', 1981, 'municipality'),
                     (2121, 'Lobotka', '', 2120, 'village'),
                     (2122, 'Tonja', '64025', 2120, 'village'),
                     (2123, 'Popovitsa', '64019', 2120, 'village'),
                     (2124, 'Rääptsova', '64020', 2120, 'village'),
                     (2125, 'Velna', '64030', 2120, 'village'),
                     (2126, 'Õrsava', '64035', 2120, 'village'),
                     (2127, 'Väike-Rõsna', '64034', 2120, 'village'),
                     (2128, 'Podmotsa', '64018', 2120, 'village'),
                     (2129, 'Verhulitsa', '64031', 2120, 'village'),
                     (2130, 'Litvina', '64011', 2120, 'village'),
                     (2131, 'Korela', '64007', 2120, 'village'),
                     (2132, 'Vaartsi', '64028', 2120, 'village'),
                     (2133, 'Saatse', '64037', 2120, 'village'),
                     (2134, 'Matsuri', '64036', 2120, 'village'),
                     (2135, 'Vedernika', '64029', 2120, 'village'),
                     (2136, 'Ulitina', '64027', 2120, 'village'),
                     (2137, 'Perdaku', '64017', 2120, 'village'),
                     (2138, 'Kremessova', '64009', 2120, 'village'),
                     (2139, 'Saabolda', '64021', 2120, 'village'),
                     (2140, 'Sesniki', '64023', 2120, 'village'),
                     (2141, 'Koidula', '64004', 2120, 'village'),
                     (2142, 'Kolodavitsa', '64005', 2120, 'village'),
                     (2143, 'Kolossova', '64006', 2120, 'village'),
                     (2144, 'Lutepää', '64013', 2120, 'village'),
                     (2145, 'Pattina', '64016', 2120, 'village'),
                     (2146, 'Nedsaja', '64015', 2120, 'village'),
                     (2147, 'Säpina', '64024', 2120, 'village'),
                     (2148, 'Võpolsova', '64033', 2120, 'village'),
                     (2149, 'Kundruse', '64010', 2120, 'village'),
                     (2150, 'Voropi', '64032', 2120, 'village'),
                     (2151, 'Määsovitsa', '64014', 2120, 'village'),
                     (2152, 'Kostkova', '64008', 2120, 'village'),
                     (2153, 'Samarina', '64022', 2120, 'village'),
                     (2154, 'Treski', '64026', 2120, 'village'),
                     (2155, 'Mikitamäe', '', 1981, 'municipality'),
                     (2156, 'Võõpsu', '', 2155, 'village'),
                     (2157, 'Lüübnitsa', '', 2155, 'village'),
                     (2158, 'Beresje', '', 2155, 'village'),
                     (2159, 'Niitsiku', '64319', 2155, 'village'),
                     (2160, 'Puugnitsa', '64311', 2155, 'village'),
                     (2161, 'Rõsna', '64312', 2155, 'village'),
                     (2162, 'Igrise', '64304', 2155, 'village'),
                     (2163, 'Audjassaare', '64302', 2155, 'village'),
                     (2164, 'Järvepää', '64305', 2155, 'village'),
                     (2165, 'Usinitsa', '64316', 2155, 'village'),
                     (2166, 'Selise', '64314', 2155, 'village'),
                     (2167, 'Rääsolaane', '64313', 2155, 'village'),
                     (2168, 'Varesmäe', '64317', 2155, 'village'),
                     (2169, 'Laossina', '64308', 2155, 'village'),
                     (2170, 'Karisilla', '64307', 2155, 'village'),
                     (2171, 'Toomasmäe', '64315', 2155, 'village'),
                     (2172, 'Mooste', '', 1981, 'municipality'),
                     (2173, 'Terepi', '64613', 2172, 'village'),
                     (2174, 'Kastmekoja', '64608', 2172, 'village'),
                     (2175, 'Rasina', '64618', 2172, 'village'),
                     (2176, 'Jaanimõisa', '64604', 2172, 'village'),
                     (2177, 'Säässaare', '64612', 2172, 'village'),
                     (2178, 'Säkna', '64611', 2172, 'village'),
                     (2179, 'Kauksi', '64617', 2172, 'village'),
                     (2180, 'Viisli', '64614', 2172, 'village'),
                     (2181, 'Savimäe', '64609', 2172, 'village'),
                     (2182, 'Kanassaare', '64607', 2172, 'village'),
                     (2183, 'Kaaru', '64605', 2172, 'village'),
                     (2184, 'Kadaja', '64606', 2172, 'village'),
                     (2185, 'Suurmetsa', '64610', 2172, 'village'),
                     (2186, 'Orava', '', 1981, 'municipality'),
                     (2187, 'Piusa', '', 2186, 'village'),
                     (2188, 'Suuremetsa', '64105', 2186, 'village'),
                     (2189, 'Kliima', '64110', 2186, 'village'),
                     (2190, 'Tamme', '64106', 2186, 'village'),
                     (2191, 'Hanikase', '64107', 2186, 'village'),
                     (2192, 'Luuska', '64117', 2186, 'village'),
                     (2193, 'Praakmani', '64104', 2186, 'village'),
                     (2194, 'Kakusuu', '64109', 2186, 'village'),
                     (2195, 'Madi', '64118', 2186, 'village'),
                     (2196, 'Kõvera', '64115', 2186, 'village'),
                     (2197, 'Liinamäe', '64116', 2186, 'village'),
                     (2198, 'Korgõmõisa', '64112', 2186, 'village'),
                     (2199, 'Vivva', '64131', 2186, 'village'),
                     (2200, 'Päka', '64123', 2186, 'village'),
                     (2201, 'Jantra', '64103', 2186, 'village'),
                     (2202, 'Tuderna', '64130', 2186, 'village'),
                     (2203, 'Kahkva', '', 2186, 'village'),
                     (2204, 'Rõssa', '64127', 2186, 'village'),
                     (2205, 'Kamnitsa', '64111', 2186, 'village'),
                     (2206, 'Riihora', '64126', 2186, 'village'),
                     (2207, 'Lepassaare', '64102', 2186, 'village'),
                     (2208, 'Oro', '64121', 2186, 'village'),
                     (2209, 'Pääväkese', '64124', 2186, 'village'),
                     (2210, 'Marga', '64119', 2186, 'village'),
                     (2211, 'Kõivsaare', '64113', 2186, 'village'),
                     (2212, 'Soe', '64128', 2186, 'village'),
                     (2213, 'Soena', '64129', 2186, 'village'),
                     (2214, 'Rebasmäe', '64125', 2186, 'village'),
                     (2215, 'Kõliküla', '64114', 2186, 'village'),
                     (2216, 'Valgjärve', '', 1981, 'municipality'),
                     (2217, 'Saverna', '', 2216, 'village'),
                     (2218, 'Sirvaste', '63413', 2216, 'village'),
                     (2219, 'Abissaare', '63404', 2216, 'village'),
                     (2220, 'Hauka', '63406', 2216, 'village'),
                     (2221, 'Krüüdneri', '63408', 2216, 'village'),
                     (2222, 'Sulaoja', '63414', 2216, 'village'),
                     (2223, 'Maaritsa', '63417', 2216, 'village'),
                     (2224, 'Vissi', '63416', 2216, 'village'),
                     (2225, 'Aiaste', '63405', 2216, 'village'),
                     (2226, 'Puugi', '63412', 2216, 'village'),
                     (2227, 'Tiido', '63415', 2216, 'village'),
                     (2228, 'Pikajärve', '63410', 2216, 'village'),
                     (2229, 'Mügra', '63409', 2216, 'village'),
                     (2230, 'Kooli', '63407', 2216, 'village'),
                     (2231, 'Pikareinu', '63411', 2216, 'village'),
                     (2232, 'Laheda', '', 1981, 'municipality'),
                     (2233, 'Tilsi', '', 2232, 'village'),
                     (2234, 'Himma', '63002', 2232, 'village'),
                     (2235, 'Pragi', '63007', 2232, 'village'),
                     (2236, 'Lahe', '63004', 2232, 'village'),
                     (2237, 'Vardja', '63011', 2232, 'village'),
                     (2238, 'Mustajõe', '63005', 2232, 'village'),
                     (2239, 'Vana-Koiola', '63010', 2232, 'village'),
                     (2240, 'Roosi', '63008', 2232, 'village'),
                     (2241, 'Naruski', '63006', 2232, 'village'),
                     (2242, 'Joosu', '63003', 2232, 'village'),
                     (2243, 'Suurküla', '63009', 2232, 'village'),
                     (2244, 'Halinga', '', 52, 'municipality'),
                     (2245, 'Libatse', '', 2244, 'village'),
                     (2246, 'Pärnu-Jaagupi', '', 2244, 'borough'),
                     (2247, 'Tõrdu', '', 2244, 'village'),
                     (2248, 'Pitsalu', '87230', 2244, 'village'),
                     (2249, 'Rukkiküla', '87233', 2244, 'village'),
                     (2250, 'Kodesmaa', '87217', 2244, 'village'),
                     (2251, 'Salu', '87234', 2244, 'village'),
                     (2252, 'Mäeküla', '87225', 2244, 'village'),
                     (2253, 'Helenurme', '87213', 2244, 'village'),
                     (2254, 'Altküla', '87204', 2244, 'village'),
                     (2255, 'Anelema', '87205', 2244, 'village'),
                     (2256, 'Kuninga', '87218', 2244, 'village'),
                     (2257, 'Arase', '87206', 2244, 'village'),
                     (2258, 'Tarva', '', 2244, 'village'),
                     (2259, 'Kablima', '87214', 2244, 'village'),
                     (2260, 'Oese', '87227', 2244, 'village'),
                     (2261, 'Valistre', '87242', 2244, 'village'),
                     (2262, 'Vakalepa', '87241', 2244, 'village'),
                     (2263, 'Sepaküla', '87235', 2244, 'village'),
                     (2264, 'Enge', '87210', 2244, 'village'),
                     (2265, 'Vahenurme', '87101', 2244, 'village'),
                     (2266, 'Pereküla', '87229', 2244, 'village'),
                     (2267, 'Sõõrike', '87237', 2244, 'village'),
                     (2268, 'Vee', '87243', 2244, 'village'),
                     (2269, 'Ertsma', '87211', 2244, 'village'),
                     (2270, 'Maima', '87223', 2244, 'village'),
                     (2271, 'Mõisaküla', '87224', 2244, 'village'),
                     (2272, 'Kaelase', '87215', 2244, 'village'),
                     (2273, 'Roodi', '87232', 2244, 'village'),
                     (2274, 'Pallika', '87228', 2244, 'village'),
                     (2275, 'Loomse', '87222', 2244, 'village'),
                     (2276, 'Lehtmetsa', '87220', 2244, 'village'),
                     (2277, 'Langerma', '87219', 2244, 'village'),
                     (2278, 'Lehu', '87221', 2244, 'village'),
                     (2279, 'Kangru', '87216', 2244, 'village'),
                     (2280, 'Tühjasma', '87240', 2244, 'village'),
                     (2281, 'Eense', '87208', 2244, 'village'),
                     (2282, 'Soosalu', '87236', 2244, 'village'),
                     (2283, 'Aasa', '87203', 2244, 'village'),
                     (2284, 'Eerma', '87209', 2244, 'village'),
                     (2285, 'Pööravere', '87231', 2244, 'village'),
                     (2286, 'Naartse', '87226', 2244, 'village'),
                     (2287, 'Tootsi', '', 52, 'municipality'),
                     (2288, 'Vändra', '', 52, 'municipality'),
                     (2289, 'Vihtra', '', 2288, 'village'),
                     (2290, 'Võidula', '', 2288, 'village'),
                     (2291, 'Kergu', '', 2288, 'village'),
                     (2292, 'Suurejõe', '', 2288, 'village'),
                     (2293, 'Kaisma', '', 2288, 'village'),
                     (2294, 'Viluvere', '87633', 2288, 'village'),
                     (2295, 'Rahnoja', '87622', 2288, 'village'),
                     (2296, 'Luuri', '87614', 2288, 'village'),
                     (2297, 'Kullimaa', '87611', 2288, 'village'),
                     (2298, 'Ünnaste', '87636', 2288, 'village'),
                     (2299, 'Kobra', '87609', 2288, 'village'),
                     (2300, 'Massu', '87616', 2288, 'village'),
                     (2301, 'Rõusa', '87624', 2288, 'village'),
                     (2302, 'Allikõnnu', '87604', 2288, 'village'),
                     (2303, 'Oriküla', '87619', 2288, 'village'),
                     (2304, 'Kalmaru', '87607', 2288, 'village'),
                     (2305, 'Kirikumõisa', '87608', 2288, 'village'),
                     (2306, 'Kurgja', '87612', 2288, 'village'),
                     (2307, 'Metsavere', '87405', 2288, 'village'),
                     (2308, 'Veskisoo', '87632', 2288, 'village'),
                     (2309, 'Leetva', '87613', 2288, 'village'),
                     (2310, 'Tagassaare', '87629', 2288, 'village'),
                     (2311, 'Lüüste', '87615', 2288, 'village'),
                     (2312, 'Rätsepa', '', 2288, 'village'),
                     (2313, 'Aluste', '87601', 2288, 'village'),
                     (2314, 'Rae', '87621', 2288, 'village'),
                     (2315, 'Kose', '87610', 2288, 'village'),
                     (2316, 'Pärnjõe', '87620', 2288, 'village'),
                     (2317, 'Reinumurru', '87623', 2288, 'village'),
                     (2318, 'Rahkama', '87406', 2288, 'village'),
                     (2319, 'Sikana', '87627', 2288, 'village'),
                     (2320, 'Kaansoo', '87605', 2288, 'village'),
                     (2321, 'Võiera', '87635', 2288, 'village'),
                     (2322, 'Kõnnu', '87403', 2288, 'village'),
                     (2323, 'Venekuusiku', '87631', 2288, 'village'),
                     (2324, 'Sohlu', '87407', 2288, 'village'),
                     (2325, 'Säästla', '87628', 2288, 'village'),
                     (2326, 'Samliku', '87626', 2288, 'village'),
                     (2327, 'Kadjaste', '87606', 2288, 'village'),
                     (2328, 'Vaki', '87630', 2288, 'village'),
                     (2329, 'Mustaru', '87617', 2288, 'village'),
                     (2330, 'Mädara', '87618', 2288, 'village'),
                     (2331, 'Tori', '', 52, 'municipality'),
                     (2332, 'Jõesuu', '', 2331, 'village'),
                     (2333, 'Piistaoja', '', 2331, 'village'),
                     (2334, 'Kõrsa', '', 2331, 'village'),
                     (2335, 'Selja', '', 2331, 'village'),
                     (2336, 'Taali', '', 2331, 'village'),
                     (2337, 'Urumarja', '', 2331, 'village'),
                     (2338, 'Kildemaa', '86805', 2331, 'village'),
                     (2339, 'Oore', '86812', 2331, 'village'),
                     (2340, 'Elbi', '86804', 2331, 'village'),
                     (2341, 'Aesoo', '86803', 2331, 'village'),
                     (2342, 'Muti', '86811', 2331, 'village'),
                     (2343, 'Riisa', '86815', 2331, 'village'),
                     (2344, 'Levi', '86808', 2331, 'village'),
                     (2345, 'Kuiaru', '86806', 2331, 'village'),
                     (2346, 'Muraka', '86810', 2331, 'village'),
                     (2347, 'Tohera', '86819', 2331, 'village'),
                     (2348, 'Mannare', '86809', 2331, 'village'),
                     (2349, 'Randivälja', '86814', 2331, 'village'),
                     (2350, 'Võlli', '86821', 2331, 'village'),
                     (2351, 'Tõstamaa', '', 52, 'municipality'),
                     (2352, 'Kiraste', '88108', 2351, 'village'),
                     (2353, 'Lao', '88110', 2351, 'village'),
                     (2354, 'Pootsi', '88115', 2351, 'village'),
                     (2355, 'Tõlli', '88119', 2351, 'village'),
                     (2356, 'Rammuka', '88117', 2351, 'village'),
                     (2357, 'Ranniku', '88118', 2351, 'village'),
                     (2358, 'Lõuka', '88111', 2351, 'village'),
                     (2359, 'Tõhela', '88102', 2351, 'village'),
                     (2360, 'Seliste', '88103', 2351, 'village'),
                     (2361, 'Peerni', '88114', 2351, 'village'),
                     (2362, 'Kastna', '88106', 2351, 'village'),
                     (2363, 'Alu', '88104', 2351, 'village'),
                     (2364, 'Ermistu', '88105', 2351, 'village'),
                     (2365, 'Kavaru', '88107', 2351, 'village'),
                     (2366, 'Värati', '88120', 2351, 'village'),
                     (2367, 'Männikuste', '88113', 2351, 'village'),
                     (2368, 'Päraküla', '88116', 2351, 'village'),
                     (2369, 'Manija', '88112', 2351, 'village'),
                     (2370, 'Kõpu', '88109', 2351, 'village'),
                     (2371, 'Tahkuranna', '', 52, 'municipality'),
                     (2372, 'Reiu', '', 2371, 'village'),
                     (2373, 'Uulu', '', 2371, 'village'),
                     (2374, 'Võiste', '', 2371, 'smallborough'),
                     (2375, 'Lepaküla', '', 2371, 'village'),
                     (2376, 'Laadi', '', 2371, 'village'),
                     (2377, 'Piirumi', '86507', 2371, 'village'),
                     (2378, 'Metsaküla', '', 2371, 'village'),
                     (2379, 'Leina', '86504', 2371, 'village'),
                     (2380, 'Sauga', '', 52, 'municipality'),
                     (2381, 'Tammiste', '', 2380, 'village'),
                     (2382, 'Kilksama', '', 2380, 'village'),
                     (2383, 'Eametsa', '', 2380, 'village'),
                     (2384, 'Nurme', '', 2380, 'village'),
                     (2385, 'Urge', '', 2380, 'village'),
                     (2386, 'Vainu', '', 2380, 'village'),
                     (2387, 'Räägu', '85006', 2380, 'village'),
                     (2388, 'Kiisa', '85002', 2380, 'village'),
                     (2389, 'Rütavere', '85007', 2380, 'village'),
                     (2390, 'Pulli', '85005', 2380, 'village'),
                     (2391, 'Paikuse', '', 52, 'municipality'),
                     (2392, 'Silla', '', 2391, 'village'),
                     (2393, 'Seljametsa', '', 2391, 'village'),
                     (2394, 'Tammuru', '', 2391, 'village'),
                     (2395, 'Põlendmaa', '86603', 2391, 'village'),
                     (2396, 'Vaskrääma', '86606', 2391, 'village'),
                     (2397, 'Sindi', '', 52, 'town'),
                     (2398, 'Audru', '', 52, 'municipality'),
                     (2399, 'Kõima', '', 2398, 'village'),
                     (2400, 'Papsaare', '', 2398, 'village'),
                     (2401, 'Lemmetsa', '', 2398, 'village'),
                     (2402, 'Liiva', '', 2398, 'village'),
                     (2403, 'Malda', '', 2398, 'village'),
                     (2404, 'Marksa', '', 2398, 'village'),
                     (2405, 'Kihlepa', '', 2398, 'village'),
                     (2406, 'Lindi', '', 2398, 'village'),
                     (2407, 'Jõõpre', '', 2398, 'village'),
                     (2408, 'Kabriste', '', 2398, 'village'),
                     (2409, 'Põldeotsa', '', 2398, 'village'),
                     (2410, 'Saulepa', '', 2398, 'village'),
                     (2411, 'Valgeranna', '', 2398, 'village'),
                     (2412, 'Ahaste', '', 2398, 'village'),
                     (2413, 'Oara', '88316', 2398, 'village'),
                     (2414, 'Soeva', '88323', 2398, 'village'),
                     (2415, 'Tuuraste', '88325', 2398, 'village'),
                     (2416, 'Saari', '88321', 2398, 'village'),
                     (2417, 'Soomra', '', 2398, 'village'),
                     (2418, 'Kärbu', '88310', 2398, 'village'),
                     (2419, 'Põhara', '88318', 2398, 'village'),
                     (2420, 'Liu', '88313', 2398, 'village'),
                     (2421, 'Eassalu', '88307', 2398, 'village'),
                     (2422, 'Ridalepa', '88320', 2398, 'village'),
                     (2423, 'Häädemeeste', '', 52, 'municipality'),
                     (2424, 'Kabli', '', 2423, 'village'),
                     (2425, 'Rannametsa', '86016', 2423, 'village'),
                     (2426, 'Papisilla', '86013', 2423, 'village'),
                     (2427, 'Penu', '86014', 2423, 'village'),
                     (2428, 'Metsapoole', '86010', 2423, 'village'),
                     (2429, 'Orajõe', '86012', 2423, 'village'),
                     (2430, 'Urissaare', '86019', 2423, 'village'),
                     (2431, 'Arumetsa', '86006', 2423, 'village'),
                     (2432, 'Sooküla', '86017', 2423, 'village'),
                     (2433, 'Massiaru', '86004', 2423, 'village'),
                     (2434, 'Majaka', '', 2423, 'village'),
                     (2435, 'Soometsa', '86018', 2423, 'village'),
                     (2436, 'Krundiküla', '86008', 2423, 'village'),
                     (2437, 'Võidu', '86021', 2423, 'village'),
                     (2438, 'Uuemaa', '86020', 2423, 'village'),
                     (2439, 'Pulgoja', '86015', 2423, 'village'),
                     (2440, 'Jaagupi', '86007', 2423, 'village'),
                     (2441, 'Ikla', '86005', 2423, 'village'),
                     (2442, 'Nepste', '86011', 2423, 'village'),
                     (2443, 'Treimani', '86003', 2423, 'village'),
                     (2444, 'Kilingi-Nõmme', '', 52, 'town'),
                     (2445, 'Are', '', 52, 'municipality'),
                     (2446, 'Kurena', '', 2445, 'village'),
                     (2447, 'Parisselja', '87308', 2445, 'village'),
                     (2448, 'Suigu', '87302', 2445, 'village'),
                     (2449, 'Elbu', '87304', 2445, 'village'),
                     (2450, 'Niidu', '87307', 2445, 'village'),
                     (2451, 'Pärivere', '87309', 2445, 'village'),
                     (2452, 'Tabria', '87311', 2445, 'village'),
                     (2453, 'Lepplaane', '87306', 2445, 'village'),
                     (2454, 'Murru', '87310', 2445, 'village'),
                     (2455, 'Eavere', '87303', 2445, 'village'),
                     (2456, 'Võlla', '87312', 2445, 'village'),
                     (2457, 'Lavassaare', '', 52, 'municipality'),
                     (2458, 'Varbla', '', 52, 'municipality'),
                     (2459, 'Käru', '88217', 2458, 'village'),
                     (2460, 'Kidise', '88212', 2458, 'village'),
                     (2461, 'Saare', '88231', 2458, 'village'),
                     (2462, 'Paatsalu', '88204', 2458, 'village'),
                     (2463, 'Sookalda', '88233', 2458, 'village'),
                     (2464, 'Maade', '88218', 2458, 'village'),
                     (2465, 'Kilgi', '88213', 2458, 'village'),
                     (2466, 'Tiilima', '88235', 2458, 'village'),
                     (2467, 'Matsi', '88219', 2458, 'village'),
                     (2468, 'Koeri', '88214', 2458, 'village'),
                     (2469, 'Ännikse', '88240', 2458, 'village'),
                     (2470, 'Korju', '88215', 2458, 'village'),
                     (2471, 'Õhu', '88239', 2458, 'village'),
                     (2472, 'Tõusi', '88236', 2458, 'village'),
                     (2473, 'Piha', '88225', 2458, 'village'),
                     (2474, 'Täpsi', '88237', 2458, 'village'),
                     (2475, 'Mõtsu', '88222', 2458, 'village'),
                     (2476, 'Raheste', '88227', 2458, 'village'),
                     (2477, 'Paadrema', '88202', 2458, 'village'),
                     (2478, 'Kulli', '88216', 2458, 'village'),
                     (2479, 'Mereäärse', '88220', 2458, 'village'),
                     (2480, 'Raespa', '88226', 2458, 'village'),
                     (2481, 'Aruküla', '88206', 2458, 'village'),
                     (2482, 'Helmküla', '88208', 2458, 'village'),
                     (2483, 'Hõbesalu', '88209', 2458, 'village'),
                     (2484, 'Rauksi', '88229', 2458, 'village'),
                     (2485, 'Muriste', '88221', 2458, 'village'),
                     (2486, 'Mäliküla', '88223', 2458, 'village'),
                     (2487, 'Kanamardi', '88211', 2458, 'village'),
                     (2488, 'Saulepi', '88203', 2458, 'village'),
                     (2489, 'Tamba', '88234', 2458, 'village'),
                     (2490, 'Vaiste', '88238', 2458, 'village'),
                     (2491, 'Haapsi', '88207', 2458, 'village'),
                     (2492, 'Rädi', '88230', 2458, 'village'),
                     (2493, 'Allika', '88205', 2458, 'village'),
                     (2494, 'Rannaküla', '88228', 2458, 'village'),
                     (2495, 'Kadaka', '88210', 2458, 'village'),
                     (2496, 'Nõmme', '88224', 2458, 'village'),
                     (2497, 'Saarde', '', 52, 'municipality'),
                     (2498, 'Tihemetsa', '', 2497, 'smallborough'),
                     (2499, 'Veelikse', '', 2497, 'village'),
                     (2500, 'Tõlla', '', 2497, 'village'),
                     (2501, 'Tali', '', 2497, 'village'),
                     (2502, 'Tuuliku', '86108', 2497, 'village'),
                     (2503, 'Sigaste', '86214', 2497, 'village'),
                     (2504, 'Reinu', '86107', 2497, 'village'),
                     (2505, 'Leipste', '86209', 2497, 'village'),
                     (2506, 'Kalita', '86206', 2497, 'village'),
                     (2507, 'Marina', '86105', 2497, 'village'),
                     (2508, 'Jäärja', '86205', 2497, 'village'),
                     (2509, 'Laiksaare', '86103', 2497, 'village'),
                     (2510, 'Väljaküla', '86215', 2497, 'village'),
                     (2511, 'Mustla', '86212', 2497, 'village'),
                     (2512, 'Viisireiu', '86109', 2497, 'village'),
                     (2513, 'Pihke', '86106', 2497, 'village'),
                     (2514, 'Kamali', '86207', 2497, 'village'),
                     (2515, 'Lodja', '86210', 2497, 'village'),
                     (2516, 'Lanksaare', '86104', 2497, 'village'),
                     (2517, 'Marana', '86211', 2497, 'village'),
                     (2518, 'Kanaküla', '86204', 2497, 'village'),
                     (2519, 'Kärsu', '86208', 2497, 'village'),
                     (2520, 'Oissaare', '86216', 2497, 'village'),
                     (2521, 'Surju', '', 52, 'municipality'),
                     (2522, 'Kalda', '', 2521, 'village'),
                     (2523, 'Ristiküla', '86410', 2521, 'village'),
                     (2524, 'Jaamaküla', '86403', 2521, 'village'),
                     (2525, 'Lähkma', '86407', 2521, 'village'),
                     (2526, 'Kikepera', '86405', 2521, 'village'),
                     (2527, 'Rabaküla', '86409', 2521, 'village'),
                     (2528, 'Kõveri', '86406', 2521, 'village'),
                     (2529, 'Saunametsa', '86411', 2521, 'village'),
                     (2530, 'Ilvese', '86402', 2521, 'village'),
                     (2531, 'Kihnu', '', 52, 'municipality'),
                     (2532, 'Linaküla', '', 2531, 'village'),
                     (2533, 'Lemsi', '88002', 2531, 'village'),
                     (2534, 'Sääre', '88005', 2531, 'village'),
                     (2535, 'Rootsiküla', '88004', 2531, 'village'),
                     (2536, 'Koonga', '', 52, 'municipality'),
                     (2537, 'Võrungi', '88441', 2536, 'village'),
                     (2538, 'Tamme', '88434', 2536, 'village'),
                     (2539, 'Ura', '88436', 2536, 'village'),
                     (2540, 'Paimvere', '88425', 2536, 'village'),
                     (2541, 'Irta', '88407', 2536, 'village'),
                     (2542, 'Pikavere', '88430', 2536, 'village'),
                     (2543, 'Peantse', '88428', 2536, 'village'),
                     (2544, 'Kibura', '88415', 2536, 'village'),
                     (2545, 'Vastaba', '88438', 2536, 'village'),
                     (2546, 'Iska', '88408', 2536, 'village'),
                     (2547, 'Kurese', '88418', 2536, 'village'),
                     (2548, 'Nätsi', '88424', 2536, 'village'),
                     (2549, 'Sookatse', '88433', 2536, 'village'),
                     (2550, 'Jänistvere', '88410', 2536, 'village'),
                     (2551, 'Järve', '88411', 2536, 'village'),
                     (2552, 'Tõitse', '88435', 2536, 'village'),
                     (2553, 'Joonuse', '88409', 2536, 'village'),
                     (2554, 'Urita', '88437', 2536, 'village'),
                     (2555, 'Õepa', '88442', 2536, 'village'),
                     (2556, 'Karuba', '88414', 2536, 'village'),
                     (2557, 'Võitra', '88440', 2536, 'village'),
                     (2558, 'Kuhu', '88417', 2536, 'village'),
                     (2559, 'Emmu', '88405', 2536, 'village'),
                     (2560, 'Kiisamaa', '88416', 2536, 'village'),
                     (2561, 'Rabavere', '88431', 2536, 'village'),
                     (2562, 'Palatu', '88426', 2536, 'village'),
                     (2563, 'Nedrema', '88423', 2536, 'village'),
                     (2564, 'Oidrema', '88404', 2536, 'village'),
                     (2565, 'Naissoo', '88422', 2536, 'village'),
                     (2566, 'Kalli', '88412', 2536, 'village'),
                     (2567, 'Veltsa', '88439', 2536, 'village'),
                     (2568, 'Hõbeda', '88406', 2536, 'village'),
                     (2569, 'Salevere', '88432', 2536, 'village'),
                     (2570, 'Mihkli', '88421', 2536, 'village'),
                     (2571, 'Maikse', '88420', 2536, 'village'),
                     (2572, 'Piisu', '88429', 2536, 'village'),
                     (2573, 'Karinõmme', '88413', 2536, 'village'),
                     (2574, 'Parasmaa', '88427', 2536, 'village'),
                     (2575, 'Lõpe', '88402', 2536, 'village'),
                     (2576, 'Metsaääre', '', 52, 'municipality'),
                     (2577, 'Aruvälja', '', 52, 'municipality'),
                     (2578, 'Kehtna', '', 53, 'municipality'),
                     (2579, 'Lelle', '', 2578, 'smallborough'),
                     (2580, 'Eidapere', '', 2578, 'smallborough'),
                     (2581, 'Kaerepere', '', 2578, 'smallborough'),
                     (2582, 'Saksa', '', 2578, 'village'),
                     (2583, 'Ohekatku', '', 2578, 'village'),
                     (2584, 'Rõue', '', 2578, 'village'),
                     (2585, 'Keava', '', 2578, 'smallborough'),
                     (2586, 'Käbiküla', '', 2578, 'village'),
                     (2587, 'Metsaääre', '', 2578, 'village'),
                     (2588, 'Kehtna-Nurme', '79051', 2578, 'village'),
                     (2589, 'Laeste', '79064', 2578, 'village'),
                     (2590, 'Koogimäe', '79052', 2578, 'village'),
                     (2591, 'Palasi', '79018', 2578, 'village'),
                     (2592, 'Kärpla', '79063', 2578, 'village'),
                     (2593, 'Kastna', '79016', 2578, 'village'),
                     (2594, 'Vastja', '79071', 2578, 'village'),
                     (2595, 'Lau', '79008', 2578, 'village'),
                     (2596, 'Linnaaluste', '79050', 2578, 'village'),
                     (2597, 'Reonda', '79015', 2578, 'village'),
                     (2598, 'Kõrbja', '79023', 2578, 'village'),
                     (2599, 'Selja', '79110', 2578, 'village'),
                     (2600, 'Ellamaa', '79011', 2578, 'village'),
                     (2601, 'Sooaluste', '79070', 2578, 'village'),
                     (2602, 'Ahekõnnu', '79111', 2578, 'village'),
                     (2603, 'Kalbu', '79061', 2578, 'village'),
                     (2604, 'Mukri', '79013', 2578, 'village'),
                     (2605, 'Saarepõllu', '79014', 2578, 'village'),
                     (2606, 'Lokuta', '', 2578, 'village'),
                     (2607, 'Põrsaku', '79524', 2578, 'village'),
                     (2608, 'Hertu', '79521', 2578, 'village'),
                     (2609, 'Pae', '79009', 2578, 'village'),
                     (2610, 'Nadalama', '79068', 2578, 'village'),
                     (2611, 'Lellapere-Nurme', '79066', 2578, 'village'),
                     (2612, 'Lalli', '79017', 2578, 'village'),
                     (2613, 'Nõlva', '79112', 2578, 'village'),
                     (2614, 'Hiie', '79060', 2578, 'village'),
                     (2615, 'Kenni', '79012', 2578, 'village'),
                     (2616, 'Haakla', '79021', 2578, 'village'),
                     (2617, 'Paluküla', '79019', 2578, 'village'),
                     (2618, 'Saunaküla', '79526', 2578, 'village'),
                     (2619, 'Koogiste', '79022', 2578, 'village'),
                     (2620, 'Lellapere', '79065', 2578, 'village'),
                     (2621, 'Valtu-Nurme', '79527', 2578, 'village'),
                     (2622, 'Kumma', '79523', 2578, 'village'),
                     (2623, 'Ingliste', '79004', 2578, 'village'),
                     (2624, 'Põllu', '79020', 2578, 'village'),
                     (2625, 'Uusküla', '', 55, 'village'),
                     (2626, 'Hagudi', '', 55, 'smallborough'),
                     (2627, 'Alu', '', 55, 'smallborough'),
                     (2628, 'Sulupere', '', 55, 'village'),
                     (2629, 'Mahlamäe', '', 55, 'village'),
                     (2630, 'Tuti', '', 55, 'village'),
                     (2631, 'Kuusiku', '', 55, 'smallborough'),
                     (2632, 'Kalevi', '', 55, 'village'),
                     (2633, 'Kuku', '', 55, 'village'),
                     (2634, 'Purila', '', 55, 'village'),
                     (2635, 'Valtu', '', 55, 'village'),
                     (2636, 'Kodila', '', 55, 'village'),
                     (2637, 'Sikeldi', '', 55, 'village'),
                     (2638, 'Ülejõe', '', 55, 'village'),
                     (2639, 'Oola', '79643', 55, 'village'),
                     (2640, 'Kõrgu', '79615', 55, 'village'),
                     (2641, 'Alu-Metsküla', '79605', 55, 'village'),
                     (2642, 'Seli', '79604', 55, 'village'),
                     (2643, 'Tõrma', '79622', 55, 'village'),
                     (2644, 'Seli-Nurme', '79634', 55, 'village'),
                     (2645, 'Röa', '79614', 55, 'village'),
                     (2646, 'Aranküla', '79640', 55, 'village'),
                     (2647, 'Oela', '79617', 55, 'village'),
                     (2648, 'Ohulepa', '79618', 55, 'village'),
                     (2649, 'Kodila-Metsküla', '79613', 55, 'village'),
                     (2650, 'Äherdi', '79644', 55, 'village'),
                     (2651, 'Juula', '79540', 55, 'village'),
                     (2652, 'Mõisaaseme', '79632', 55, 'village'),
                     (2653, 'Tapupere', '79621', 55, 'village'),
                     (2654, 'Ridaküla', '79528', 55, 'village'),
                     (2655, 'Palamulla', '79619', 55, 'village'),
                     (2656, 'Väljataguse', '79543', 55, 'village'),
                     (2657, 'Lipstu', '79519', 55, 'village'),
                     (2658, 'Kelba', '79611', 55, 'village'),
                     (2659, 'Koigi', '79630', 55, 'village'),
                     (2660, 'Kuusiku-Nõmme', '79518', 55, 'village'),
                     (2661, 'Mällu', '79616', 55, 'village'),
                     (2662, 'Nõmme', '79642', 55, 'village'),
                     (2663, 'Raka', '79620', 55, 'village'),
                     (2664, 'Iira', '79517', 55, 'village'),
                     (2665, 'Märjamaa', '', 53, 'municipality'),
                     (2666, 'Sõtke', '', 2665, 'village'),
                     (2667, 'Maidla', '', 2665, 'village'),
                     (2668, 'Sipa', '', 2665, 'village'),
                     (2669, 'Moka', '78236', 2665, 'village'),
                     (2670, 'Kasti', '78221', 2665, 'village'),
                     (2671, 'Vana-Nurtu', '78258', 2665, 'village'),
                     (2672, 'Kangru', '78220', 2665, 'village'),
                     (2673, 'Sõmeru', '78255', 2665, 'village'),
                     (2674, 'Purga', '78249', 2665, 'village'),
                     (2675, 'Velise-Nõlva', '78260', 2665, 'village'),
                     (2676, 'Laukna', '', 2665, 'village'),
                     (2677, 'Napanurga', '78240', 2665, 'village'),
                     (2678, 'Inda', '78216', 2665, 'village'),
                     (2679, 'Pajaka', '78248', 2665, 'village'),
                     (2680, 'Risu-Suurküla', '78252', 2665, 'village'),
                     (2681, 'Veski', '78261', 2665, 'village'),
                     (2682, 'Urevere', '78120', 2665, 'village'),
                     (2683, 'Mõraste', '78116', 2665, 'village'),
                     (2684, 'Loodna', '78113', 2665, 'village'),
                     (2685, 'Kiilaspere', '78223', 2665, 'village'),
                     (2686, 'Paisumaa', '78247', 2665, 'village'),
                     (2687, 'Aravere', '78213', 2665, 'village'),
                     (2688, 'Valgu', '78204', 2665, 'village'),
                     (2689, 'Vanamõisa', '', 2665, 'village'),
                     (2690, 'Konuvere', '78227', 2665, 'village'),
                     (2691, 'Altküla', '78212', 2665, 'village'),
                     (2692, 'Nõmmeotsa', '78242', 2665, 'village'),
                     (2693, 'Rassiotsa', '78251', 2665, 'village'),
                     (2694, 'Varbola', '78203', 2665, 'village'),
                     (2695, 'Nurme', '78241', 2665, 'village'),
                     (2696, 'Ohukotsu', '78244', 2665, 'village'),
                     (2697, 'Mäliste', '78238', 2665, 'village'),
                     (2698, 'Kohtru', '78226', 2665, 'village'),
                     (2699, 'Russalu', '78317', 2665, 'village'),
                     (2700, 'Leevre', '78112', 2665, 'village'),
                     (2701, 'Keskküla', '78222', 2665, 'village'),
                     (2702, 'Kaguvere', '78219', 2665, 'village'),
                     (2703, 'Alaküla', '78211', 2665, 'village'),
                     (2704, 'Metsküla', '', 2665, 'village'),
                     (2705, 'Velise', '78201', 2665, 'village'),
                     (2706, 'Orgita', '78313', 2665, 'village'),
                     (2707, 'Naistevalla', '78239', 2665, 'village'),
                     (2708, 'Paaduotsa', '78246', 2665, 'village'),
                     (2709, 'Nurtu-Nõlva', '78207', 2665, 'village'),
                     (2710, 'Velisemõisa', '78259', 2665, 'village'),
                     (2711, 'Kilgi', '78224', 2665, 'village'),
                     (2712, 'Paeküla', '78206', 2665, 'village'),
                     (2713, 'Sulu', '78253', 2665, 'village'),
                     (2714, 'Vaimõisa', '78205', 2665, 'village'),
                     (2715, 'Kunsu', '78228', 2665, 'village'),
                     (2716, 'Kirna', '78225', 2665, 'village'),
                     (2717, 'Aruküla', '78214', 2665, 'village'),
                     (2718, 'Vilta', '78121', 2665, 'village'),
                     (2719, 'Võeva', '78262', 2665, 'village'),
                     (2720, 'Lestima', '78232', 2665, 'village'),
                     (2721, 'Käriselja', '78231', 2665, 'village'),
                     (2722, 'Päädeva', '78314', 2665, 'village'),
                     (2723, 'Ojaäärse', '78245', 2665, 'village'),
                     (2724, 'Teenuse', '78103', 2665, 'village'),
                     (2725, 'Nääri', '78243', 2665, 'village'),
                     (2726, 'Põlli', '78250', 2665, 'village'),
                     (2727, 'Sooniste', '78118', 2665, 'village'),
                     (2728, 'Kohatu', '78111', 2665, 'village'),
                     (2729, 'Jõeääre', '78218', 2665, 'village'),
                     (2730, 'Haimre', '78202', 2665, 'village'),
                     (2731, 'Luiste', '78114', 2665, 'village'),
                     (2732, 'Männiku', '78117', 2665, 'village'),
                     (2733, 'Suurküla', '78254', 2665, 'village'),
                     (2734, 'Soosalu', '78119', 2665, 'village'),
                     (2735, 'Rangu', '78315', 2665, 'village'),
                     (2736, 'Ringuta', '78316', 2665, 'village'),
                     (2737, 'Koluta', '78311', 2665, 'village'),
                     (2738, 'Hiietse', '78215', 2665, 'village'),
                     (2739, 'Kõrtsuotsa', '78229', 2665, 'village'),
                     (2740, 'Jaaniveski', '78217', 2665, 'village'),
                     (2741, 'Tolli', '78256', 2665, 'village'),
                     (2742, 'Mõisamaa', '78237', 2665, 'village'),
                     (2743, 'Järvakandi', '', 53, 'municipality'),
                     (2744, 'Juuru', '', 53, 'municipality'),
                     (2745, 'Juuru', '', 2744, 'smallborough'),
                     (2746, 'Järlepa', '', 2744, 'village'),
                     (2747, 'Pirgu', '', 2744, 'village'),
                     (2748, 'Orguse', '', 2744, 'village'),
                     (2749, 'Hõreda', '79010', 2744, 'village'),
                     (2750, 'Härgla', '79404', 2744, 'village'),
                     (2751, 'Atla', '79403', 2744, 'village'),
                     (2752, 'Mahtra', '79407', 2744, 'village'),
                     (2753, 'Vankse', '79406', 2744, 'village'),
                     (2754, 'Helda', '79417', 2744, 'village'),
                     (2755, 'Kalda', '79418', 2744, 'village'),
                     (2756, 'Sadala', '79419', 2744, 'village'),
                     (2757, 'Jaluse', '79410', 2744, 'village'),
                     (2758, 'Lõiuse', '79405', 2744, 'village'),
                     (2759, 'Kaiu', '', 53, 'municipality'),
                     (2760, 'Kuimetsa', '', 2759, 'village'),
                     (2761, 'Oblu', '79312', 2759, 'village'),
                     (2762, 'Karitsa', '79320', 2759, 'village'),
                     (2763, 'Kasvandu', '79321', 2759, 'village'),
                     (2764, 'Tolla', '79322', 2759, 'village'),
                     (2765, 'Põlliku', '79325', 2759, 'village'),
                     (2766, 'Vahastu', '79303', 2759, 'village'),
                     (2767, 'Tamsi', '79313', 2759, 'village'),
                     (2768, 'Vaopere', '79314', 2759, 'village'),
                     (2769, 'Suurekivi', '79333', 2759, 'village'),
                     (2770, 'Toomja', '79323', 2759, 'village'),
                     (2771, 'Vana-Kaiu', '79324', 2759, 'village'),
                     (2772, 'Käru', '', 53, 'municipality'),
                     (2773, 'Sonni', '', 2772, 'village'),
                     (2774, 'Lauri', '79215', 2772, 'village'),
                     (2775, 'Kõdu', '79212', 2772, 'village'),
                     (2776, 'Kädva', '79213', 2772, 'village'),
                     (2777, 'Lungu', '79216', 2772, 'village'),
                     (2778, 'Kändliku', '79214', 2772, 'village'),
                     (2779, 'Kullimaa', '79211', 2772, 'village'),
                     (2780, 'Jõeküla', '79218', 2772, 'village'),
                     (2781, 'Kohila', '', 53, 'municipality'),
                     (2782, 'Prillimäe', '', 2781, 'smallborough'),
                     (2783, 'Lohu', '', 2781, 'village'),
                     (2784, 'Urge', '', 2781, 'village'),
                     (2785, 'Hageri', '', 2781, 'smallborough'),
                     (2786, 'Salutaguse', '', 2781, 'village'),
                     (2787, 'Vilivere', '', 2781, 'village'),
                     (2788, 'Sutlema', '', 2781, 'village'),
                     (2789, 'Aespa', '', 2781, 'smallborough'),
                     (2790, 'Masti', '', 2781, 'village'),
                     (2791, 'Pukamäe', '', 2781, 'village'),
                     (2792, 'Angerja', '79741', 2781, 'village'),
                     (2793, 'Lümandu', '', 2781, 'village'),
                     (2794, 'Pihali', '79703', 2781, 'village'),
                     (2795, 'Adila', '79704', 2781, 'village'),
                     (2796, 'Loone', '79831', 2781, 'village'),
                     (2797, 'Põikma', '79709', 2781, 'village'),
                     (2798, 'Rootsi', '79815', 2781, 'village'),
                     (2799, 'Kadaka', '79811', 2781, 'village'),
                     (2800, 'Rabivere', '79610', 2781, 'village'),
                     (2801, 'Aandu', '79810', 2781, 'village'),
                     (2802, 'Mälivere', '79814', 2781, 'village'),
                     (2803, 'Pahkla', '79742', 2781, 'village'),
                     (2804, 'Vana-Aespa', '79748', 2781, 'village'),
                     (2805, 'Vana-Vigala', '78003', 54, 'village'),
                     (2806, 'Kivi-Vigala', '78001', 54, 'village'),
                     (2807, 'Kojastu', '78016', 54, 'village'),
                     (2808, 'Palase', '78025', 54, 'village'),
                     (2809, 'Tiduvere', '78031', 54, 'village'),
                     (2810, 'Paljasmaa', '78026', 54, 'village'),
                     (2811, 'Rääski', '78029', 54, 'village'),
                     (2812, 'Naravere', '78022', 54, 'village'),
                     (2813, 'Oese', '78023', 54, 'village'),
                     (2814, 'Araste', '78011', 54, 'village'),
                     (2815, 'Kurevere', '78018', 54, 'village'),
                     (2816, 'Manni', '78021', 54, 'village'),
                     (2817, 'Vaguja', '78032', 54, 'village'),
                     (2818, 'Tõnumaa', '78004', 54, 'village'),
                     (2819, 'Ojapere', '78024', 54, 'village'),
                     (2820, 'Kausi', '78014', 54, 'village'),
                     (2821, 'Vängla', '78034', 54, 'village'),
                     (2822, 'Kesu', '78015', 54, 'village'),
                     (2823, 'Pallika', '78027', 54, 'village'),
                     (2824, 'Jädivere', '78013', 54, 'village'),
                     (2825, 'Sääla', '78030', 54, 'village'),
                     (2826, 'Läti', '78020', 54, 'village'),
                     (2827, 'Leibre', '78019', 54, 'village'),
                     (2828, 'Konnapere', '78017', 54, 'village'),
                     (2829, 'Päärdu', '78028', 54, 'village'),
                     (2830, 'Avaste', '78012', 54, 'village'),
                     (2831, 'Raikküla', '', 53, 'municipality'),
                     (2832, 'Tamme', '', 2831, 'village'),
                     (2833, 'Loe', '', 2831, 'village'),
                     (2834, 'Nõmmküla', '78408', 2831, 'village'),
                     (2835, 'Jalase', '78415', 2831, 'village'),
                     (2836, 'Purku', '78401', 2831, 'village'),
                     (2837, 'Pühatu', '78421', 2831, 'village'),
                     (2838, 'Keo', '78404', 2831, 'village'),
                     (2839, 'Vahakõnnu', '78411', 2831, 'village'),
                     (2840, 'Põlma', '78410', 2831, 'village'),
                     (2841, 'Lipa', '78405', 2831, 'village'),
                     (2842, 'Lipametsa', '78406', 2831, 'village'),
                     (2843, 'Raela', '78409', 2831, 'village'),
                     (2844, 'Kõrvetaguse', '78417', 2831, 'village'),
                     (2845, 'Riidaku', '78422', 2831, 'village'),
                     (2846, 'Koikse', '78416', 2831, 'village'),
                     (2847, 'Valli', '78413', 2831, 'village'),
                     (2848, 'Nõmmemetsa', '78420', 2831, 'village'),
                     (2849, 'Kaigepere', '78412', 2831, 'village'),
                     (2850, 'Ummaru', '78423', 2831, 'village'),
                     (2851, 'Lõpemetsa', '78419', 2831, 'village'),
                     (2852, 'Saare', '', None, 'county'),
                     (2853, 'Leisi', '', 2852, 'municipality'),
                     (2854, 'Parasmetsa', '94241', 2853, 'village'),
                     (2855, 'Hiievälja', '94231', 2853, 'village'),
                     (2856, 'Triigi', '94243', 2853, 'village'),
                     (2857, 'Lõpi', '94255', 2853, 'village'),
                     (2858, 'Luulupe', '94251', 2853, 'village'),
                     (2859, 'Metsküla', '94271', 2853, 'village'),
                     (2860, 'Asuka', '94257', 2853, 'village'),
                     (2861, 'Paaste', '94240', 2853, 'village'),
                     (2862, 'Moosi', '94236', 2853, 'village'),
                     (2863, 'Jõiste', '94232', 2853, 'village'),
                     (2864, 'Angla', '94244', 2853, 'village'),
                     (2865, 'Purtsa', '94264', 2853, 'village'),
                     (2866, 'Mätja', '94214', 2853, 'village'),
                     (2867, 'Laugu', '94233', 2853, 'village'),
                     (2868, 'Kopli', '94249', 2853, 'village'),
                     (2869, 'Tareste', '94216', 2853, 'village'),
                     (2870, 'Linnaka', '94213', 2853, 'village'),
                     (2871, 'Tõre', '94217', 2853, 'village'),
                     (2872, 'Pöitse', '94259', 2853, 'village'),
                     (2873, 'Poka', '94258', 2853, 'village'),
                     (2874, 'Tiitsuotsa', '94265', 2853, 'village'),
                     (2875, 'Veske', '94247', 2853, 'village'),
                     (2876, 'Nihatu', '94215', 2853, 'village'),
                     (2877, 'Ratla', '94223', 2853, 'village'),
                     (2878, 'Nurme', '', 2853, 'village'),
                     (2879, 'Õeste', '94219', 2853, 'village'),
                     (2880, 'Külma', '94211', 2853, 'village'),
                     (2881, 'Nava', '94252', 2853, 'village'),
                     (2882, 'Metsaääre', '94222', 2853, 'village'),
                     (2883, 'Roobaka', '94242', 2853, 'village'),
                     (2884, 'Mujaste', '94237', 2853, 'village'),
                     (2885, 'Räägi', '94225', 2853, 'village'),
                     (2886, 'Aru', '94245', 2853, 'village'),
                     (2887, 'Koiduvälja', '94261', 2853, 'village'),
                     (2888, 'Oitme', '94239', 2853, 'village'),
                     (2889, 'Murika', '94272', 2853, 'village'),
                     (2890, 'Selja', '94256', 2853, 'village'),
                     (2891, 'Koikla', '94221', 2853, 'village'),
                     (2892, 'Meiuste', '94235', 2853, 'village'),
                     (2893, 'Pammana', '94273', 2853, 'village'),
                     (2894, 'Täätsi', '94224', 2853, 'village'),
                     (2895, 'Aruste', '94212', 2853, 'village'),
                     (2896, 'Tutku', '94250', 2853, 'village'),
                     (2897, 'Peederga', '94246', 2853, 'village'),
                     (2898, 'Soela', '94274', 2853, 'village'),
                     (2899, 'Pärsama', '94201', 2853, 'village'),
                     (2900, 'Pamma', '94263', 2853, 'village'),
                     (2901, 'Karja', '94248', 2853, 'village'),
                     (2902, 'Kaisa', '94254', 2853, 'village'),
                     (2903, 'Salme', '', 2852, 'municipality'),
                     (2904, 'Rahuste', '93235', 2903, 'village'),
                     (2905, 'Lõu', '93234', 2903, 'village'),
                     (2906, 'Kaimri', '93232', 2903, 'village'),
                     (2907, 'Anseküla', '93211', 2903, 'village'),
                     (2908, 'Üüdibe', '93224', 2903, 'village'),
                     (2909, 'Imara', '93213', 2903, 'village'),
                     (2910, 'Metsalõuka', '93218', 2903, 'village'),
                     (2911, 'Hindu', '', 2903, 'village'),
                     (2912, 'Järve', '93271', 2903, 'village'),
                     (2913, 'Tiirimetsa', '93223', 2903, 'village'),
                     (2914, 'Länga', '93215', 2903, 'village'),
                     (2915, 'Tehumardi', '93222', 2903, 'village'),
                     (2916, 'Kaugatoma', '93233', 2903, 'village'),
                     (2917, 'Toomalõuka', '93261', 2903, 'village'),
                     (2918, 'Lahetaguse', '93260', 2903, 'village'),
                     (2919, 'Läätsa', '93216', 2903, 'village'),
                     (2920, 'Möldri', '93220', 2903, 'village'),
                     (2921, 'Lõmala', '93217', 2903, 'village'),
                     (2922, 'Suurna', '93221', 2903, 'village'),
                     (2923, 'Lassi', '93214', 2903, 'village'),
                     (2924, 'Easte', '93212', 2903, 'village'),
                     (2925, 'Vintri', '93237', 2903, 'village'),
                     (2926, 'Kaarma', '', 2852, 'municipality'),
                     (2927, 'Aste', '', 2926, 'smallborough'),
                     (2928, 'Nasva', '', 2926, 'smallborough'),
                     (2929, 'Kudjape', '', 2926, 'smallborough'),
                     (2930, 'Mändjala', '', 2926, 'village'),
                     (2931, 'Muratsi', '', 2926, 'village'),
                     (2932, 'Praakli', '', 2926, 'village'),
                     (2933, 'Laheküla', '', 2926, 'village'),
                     (2934, 'Kirikuküla', '', 2926, 'village'),
                     (2935, 'Sikassaare', '', 2926, 'village'),
                     (2936, 'Upa', '', 2926, 'village'),
                     (2937, 'Vaivere', '', 2926, 'village'),
                     (2938, 'Randvere', '', 2926, 'village'),
                     (2939, 'Abruka', '93826', 2926, 'village'),
                     (2940, 'Kaisvere', '93733', 2926, 'village'),
                     (2941, 'Kiratsi', '93741', 2926, 'village'),
                     (2942, 'Tamsalu', '93840', 2926, 'village'),
                     (2943, 'Hübja', '93715', 2926, 'village'),
                     (2944, 'Õha', '93888', 2926, 'village'),
                     (2945, 'Tõrise', '93886', 2926, 'village'),
                     (2946, 'Parila', '93836', 2926, 'village'),
                     (2947, 'Anijala', '93831', 2926, 'village'),
                     (2948, 'Lilbi', '93853', 2926, 'village'),
                     (2949, 'Kellamäe', '93723', 2926, 'village'),
                     (2950, 'Asuküla', '93717', 2926, 'village'),
                     (2951, 'Ansi', '93832', 2926, 'village'),
                     (2952, 'Kungla', '', 2926, 'village'),
                     (2953, 'Hakjala', '93714', 2926, 'village'),
                     (2954, 'Paimala', '93855', 2926, 'village'),
                     (2955, 'Jootme', '93722', 2926, 'village'),
                     (2956, 'Vantri', '93716', 2926, 'village'),
                     (2957, 'Pähkla', '93874', 2926, 'village'),
                     (2958, 'Eikla', '93881', 2926, 'village'),
                     (2959, 'Tõru', '93887', 2926, 'village'),
                     (2960, 'Tõlli', '93841', 2926, 'village'),
                     (2961, 'Endla', '93712', 2926, 'village'),
                     (2962, 'Meedla', '93744', 2926, 'village'),
                     (2963, 'Vestla', '93746', 2926, 'village'),
                     (2964, 'Koidu', '93834', 2926, 'village'),
                     (2965, 'Mullutu', '93835', 2926, 'village'),
                     (2966, 'Piila', '93885', 2926, 'village'),
                     (2967, 'Viira', '', 2926, 'village'),
                     (2968, 'Aula-Vintri', '93711', 2926, 'village'),
                     (2969, 'Kuke', '93734', 2926, 'village'),
                     (2970, 'Käku', '93753', 2926, 'village'),
                     (2971, 'Koidula', '93884', 2926, 'village'),
                     (2972, 'Pärni', '93837', 2926, 'village'),
                     (2973, 'Irase', '93721', 2926, 'village'),
                     (2974, 'Maleva', '93743', 2926, 'village'),
                     (2975, 'Tahula', '93856', 2926, 'village'),
                     (2976, 'Uduvere', '93745', 2926, 'village'),
                     (2977, 'Kasti', '93858', 2926, 'village'),
                     (2978, 'Laadjala', '93742', 2926, 'village'),
                     (2979, 'Kärdu', '', 2926, 'village'),
                     (2980, 'Nõmme', '', 2926, 'village'),
                     (2981, 'Kaarmise', '93833', 2926, 'village'),
                     (2982, 'Haamse', '93713', 2926, 'village'),
                     (2983, 'Laoküla', '93754', 2926, 'village'),
                     (2984, 'Kaubi', '93882', 2926, 'village'),
                     (2985, 'Unimäe', '93875', 2926, 'village'),
                     (2986, 'Vatsküla', '93891', 2926, 'village'),
                     (2987, 'Keskranna', '93890', 2926, 'village'),
                     (2988, 'Saia', '93725', 2926, 'village'),
                     (2989, 'Orissaare', '', 2852, 'municipality'),
                     (2990, 'Pulli', '94612', 2989, 'village'),
                     (2991, 'Tagavere', '94638', 2989, 'village'),
                     (2992, 'Põripõllu', '94613', 2989, 'village'),
                     (2993, 'Randküla', '94656', 2989, 'village'),
                     (2994, 'Imavere', '94623', 2989, 'village'),
                     (2995, 'Mäeküla', '94632', 2989, 'village'),
                     (2996, 'Järveküla', '94654', 2989, 'village'),
                     (2997, 'Maasi', '94630', 2989, 'village'),
                     (2998, 'Ariste', '', 2989, 'village'),
                     (2999, 'Võhma', '', 2989, 'village'),
                     (3000, 'Taaliku', '94637', 2989, 'village'),
                     (3001, 'Suur-Pahila', '94659', 2989, 'village'),
                     (3002, 'Kalma', '94624', 2989, 'village'),
                     (3003, 'Väljaküla', '', 2989, 'village'),
                     (3004, 'Kõinastu', '94611', 2989, 'village'),
                     (3005, 'Arju', '94622', 2989, 'village'),
                     (3006, 'Kavandi', '94655', 2989, 'village'),
                     (3007, 'Väike-Pahila', '94660', 2989, 'village'),
                     (3008, 'Väike-Rahula', '94640', 2989, 'village'),
                     (3009, 'Kareda', '94625', 2989, 'village'),
                     (3010, 'Saikla', '94634', 2989, 'village'),
                     (3011, 'Raugu', '94658', 2989, 'village'),
                     (3012, 'Tumala', '94639', 2989, 'village'),
                     (3013, 'Mehama', '94631', 2989, 'village'),
                     (3014, 'Orinõmme', '94633', 2989, 'village'),
                     (3015, 'Ööriku', '94642', 2989, 'village'),
                     (3016, 'Salu', '94635', 2989, 'village'),
                     (3017, 'Jaani', '94653', 2989, 'village'),
                     (3018, 'Suur-Rahula', '94636', 2989, 'village'),
                     (3019, 'Haapsu', '94651', 2989, 'village'),
                     (3020, 'Liigalaskma', '94628', 2989, 'village'),
                     (3021, 'Kuninguste', '94626', 2989, 'village'),
                     (3022, 'Kärla', '', 2852, 'municipality'),
                     (3023, 'Sõmera', '', 3022, 'village'),
                     (3024, 'Paiküla', '93562', 3022, 'village'),
                     (3025, 'Kulli', '', 3022, 'village'),
                     (3026, 'Mõnnuste', '93512', 3022, 'village'),
                     (3027, 'Nõmpa', '93846', 3022, 'village'),
                     (3028, 'Vendise', '93848', 3022, 'village'),
                     (3029, 'Kõrkküla', '93527', 3022, 'village'),
                     (3030, 'Hirmuste', '93523', 3022, 'village'),
                     (3031, 'Kogula', '', 3022, 'village'),
                     (3032, 'Ulje', '93529', 3022, 'village'),
                     (3033, 'Käesla', '93526', 3022, 'village'),
                     (3034, 'Kuuse', '93551', 3022, 'village'),
                     (3035, 'Arandi', '93521', 3022, 'village'),
                     (3036, 'Jõempa', '93844', 3022, 'village'),
                     (3037, 'Mätasselja', '93520', 3022, 'village'),
                     (3038, 'Paevere', '93528', 3022, 'village'),
                     (3039, 'Kandla', '93845', 3022, 'village'),
                     (3040, 'Vennati', '93530', 3022, 'village'),
                     (3041, 'Anepesa', '93843', 3022, 'village'),
                     (3042, 'Karida', '93524', 3022, 'village'),
                     (3043, 'Sauvere', '93847', 3022, 'village'),
                     (3044, 'Kihelkonna', '', 2852, 'municipality'),
                     (3045, 'Loona', '', 3044, 'village'),
                     (3046, 'Viki', '', 3044, 'village'),
                     (3047, 'Oju', '', 3044, 'village'),
                     (3048, 'Rootsiküla', '', 3044, 'village'),
                     (3049, 'Karujärve', '', 3044, 'village'),
                     (3050, 'Kuralase', '', 3044, 'village'),
                     (3051, 'Tammese', '93449', 3044, 'village'),
                     (3052, 'Abula', '93461', 3044, 'village'),
                     (3053, 'Virita', '93414', 3044, 'village'),
                     (3054, 'Odalätsi', '93468', 3044, 'village'),
                     (3055, 'Üru', '93471', 3044, 'village'),
                     (3056, 'Kiirassaare', '93433', 3044, 'village'),
                     (3057, 'Läägi', '93456', 3044, 'village'),
                     (3058, 'Kurevere', '93439', 3044, 'village'),
                     (3059, 'Kuusiku', '', 3044, 'village'),
                     (3060, 'Neeme', '93444', 3044, 'village'),
                     (3061, 'Kõõru', '93467', 3044, 'village'),
                     (3062, 'Pidula', '93469', 3044, 'village'),
                     (3063, 'Pajumõisa', '93412', 3044, 'village'),
                     (3064, 'Kõruse', '93440', 3044, 'village'),
                     (3065, 'Tagamõisa', '93448', 3044, 'village'),
                     (3066, 'Vedruka', '93432', 3044, 'village'),
                     (3067, 'Sepise', '93447', 3044, 'village'),
                     (3068, 'Kalmu', '93436', 3044, 'village'),
                     (3069, 'Kuremetsa', '93464', 3044, 'village'),
                     (3070, 'Kuumi', '93465', 3044, 'village'),
                     (3071, 'Vaigu', '93452', 3044, 'village'),
                     (3072, 'Lätiniidi', '93441', 3044, 'village'),
                     (3073, 'Vilsandi', '93421', 3044, 'village'),
                     (3074, 'Undva', '93451', 3044, 'village'),
                     (3075, 'Tohku', '93450', 3044, 'village'),
                     (3076, 'Varkja', '93470', 3044, 'village'),
                     (3077, 'Abaja', '93411', 3044, 'village'),
                     (3078, 'Kehila', '93437', 3044, 'village'),
                     (3079, 'Kotsma', '93434', 3044, 'village'),
                     (3080, 'Kuressaare', '', 2852, 'town'),
                     (3081, 'Valjala', '', 2852, 'municipality'),
                     (3082, 'Põlluküla', '', 3081, 'village'),
                     (3083, 'Oessaare', '94313', 3081, 'village'),
                     (3084, 'Kõriska', '94338', 3081, 'village'),
                     (3085, 'Tõnija', '94344', 3081, 'village'),
                     (3086, 'Vanalõve', '94318', 3081, 'village'),
                     (3087, 'Vilidu', '94347', 3081, 'village'),
                     (3088, 'Jööri', '94332', 3081, 'village'),
                     (3089, 'Võrsna', '94323', 3081, 'village'),
                     (3090, 'Kalju', '94333', 3081, 'village'),
                     (3091, 'Jursi', '94321', 3081, 'village'),
                     (3092, 'Kuiste', '94336', 3081, 'village'),
                     (3093, 'Kalli', '94322', 3081, 'village'),
                     (3094, 'Veeriku', '94346', 3081, 'village'),
                     (3095, 'Männiku', '94340', 3081, 'village'),
                     (3096, 'Kallemäe', '94301', 3081, 'village'),
                     (3097, 'Koksi', '94335', 3081, 'village'),
                     (3098, 'Undimäe', '94345', 3081, 'village'),
                     (3099, 'Röösa', '94343', 3081, 'village'),
                     (3100, 'Siiksaare', '94316', 3081, 'village'),
                     (3101, 'Jõelepa', '94331', 3081, 'village'),
                     (3102, 'Rahu', '94342', 3081, 'village'),
                     (3103, 'Turja', '94317', 3081, 'village'),
                     (3104, 'Väkra', '94348', 3081, 'village'),
                     (3105, 'Lööne', '94339', 3081, 'village'),
                     (3106, 'Sakla', '94315', 3081, 'village'),
                     (3107, 'Lümanda', '', 2852, 'municipality'),
                     (3108, 'Himmiste', '93311', 3107, 'village'),
                     (3109, 'Koki', '93327', 3107, 'village'),
                     (3110, 'Koovi', '93314', 3107, 'village'),
                     (3111, 'Atla', '93322', 3107, 'village'),
                     (3112, 'Kipi', '93313', 3107, 'village'),
                     (3113, 'Vahva', '93319', 3107, 'village'),
                     (3114, 'Viidu', '93343', 3107, 'village'),
                     (3115, 'Leedri', '93316', 3107, 'village'),
                     (3116, 'Kotlandi', '93328', 3107, 'village'),
                     (3117, 'Kuusnõmme', '93342', 3107, 'village'),
                     (3118, 'Karala', '93325', 3107, 'village'),
                     (3119, 'Austla', '93323', 3107, 'village'),
                     (3120, 'Taritu', '93331', 3107, 'village'),
                     (3121, 'Vana-Lahetaguse', '93320', 3107, 'village'),
                     (3122, 'Varpe', '93321', 3107, 'village'),
                     (3123, 'Riksu', '93330', 3107, 'village'),
                     (3124, 'Jõgela', '93312', 3107, 'village'),
                     (3125, 'Eeriksaare', '93324', 3107, 'village'),
                     (3126, 'Metsapere', '93329', 3107, 'village'),
                     (3127, 'Koimla', '93326', 3107, 'village'),
                     (3128, 'Pöide', '', 2852, 'municipality'),
                     (3129, 'Tornimäe', '', 3128, 'village'),
                     (3130, 'Muraja', '', 3128, 'village'),
                     (3131, 'Veere', '', 3128, 'village'),
                     (3132, 'Kanissaare', '94533', 3128, 'village'),
                     (3133, 'Unguma', '94545', 3128, 'village'),
                     (3134, 'Reina', '94553', 3128, 'village'),
                     (3135, 'Kübassaare', '94534', 3128, 'village'),
                     (3136, 'Kakuna', '94532', 3128, 'village'),
                     (3137, 'Sundimetsa', '94521', 3128, 'village'),
                     (3138, 'Kõrkvere', '94535', 3128, 'village'),
                     (3139, 'Mui', '94543', 3128, 'village'),
                     (3140, 'Ula', '', 3128, 'village'),
                     (3141, 'Ardla', '94531', 3128, 'village'),
                     (3142, 'Are', '94511', 3128, 'village'),
                     (3143, 'Metsara', '94551', 3128, 'village'),
                     (3144, 'Oti', '94518', 3128, 'village'),
                     (3145, 'Keskvere', '', 3128, 'village'),
                     (3146, 'Välta', '94540', 3128, 'village'),
                     (3147, 'Neemi', '94537', 3128, 'village'),
                     (3148, 'Koigi', '94515', 3128, 'village'),
                     (3149, 'Talila', '94538', 3128, 'village'),
                     (3150, 'Uuemõisa', '94522', 3128, 'village'),
                     (3151, 'Levala', '94517', 3128, 'village'),
                     (3152, 'Nenu', '94552', 3128, 'village'),
                     (3153, 'Kahutsi', '94513', 3128, 'village'),
                     (3154, 'Kärneri', '94542', 3128, 'village'),
                     (3155, 'Puka', '94519', 3128, 'village'),
                     (3156, 'Iruste', '94512', 3128, 'village'),
                     (3157, 'Pihtla', '', 2852, 'municipality'),
                     (3158, 'Kaali', '', 3157, 'village'),
                     (3159, 'Suure-Rootsi', '', 3157, 'village'),
                     (3160, 'Kõljala', '', 3157, 'village'),
                     (3161, 'Püha', '94117', 3157, 'village'),
                     (3162, 'Reeküla', '94148', 3157, 'village'),
                     (3163, 'Metsaküla', '', 3157, 'village'),
                     (3164, 'Hämmelepa', '94111', 3157, 'village'),
                     (3165, 'Kõnnu', '', 3157, 'village'),
                     (3166, 'Tõlluste', '94124', 3157, 'village'),
                     (3167, 'Nässuma', '94116', 3157, 'village'),
                     (3168, 'Haeska', '94142', 3157, 'village'),
                     (3169, 'Matsiranna', '94154', 3157, 'village'),
                     (3170, 'Reo', '94171', 3157, 'village'),
                     (3171, 'Räimaste', '94120', 3157, 'village'),
                     (3172, 'Sepa', '', 3157, 'village'),
                     (3173, 'Sutu', '94123', 3157, 'village'),
                     (3174, 'Eiste', '94141', 3157, 'village'),
                     (3175, 'Masa', '94146', 3157, 'village'),
                     (3176, 'Kiritu', '94113', 3157, 'village'),
                     (3177, 'Ennu', '94126', 3157, 'village'),
                     (3178, 'Iilaste', '94112', 3157, 'village'),
                     (3179, 'Sagariste', '94149', 3157, 'village'),
                     (3180, 'Sauaru', '94122', 3157, 'village'),
                     (3181, 'Saue-Putla', '94151', 3157, 'village'),
                     (3182, 'Väike-Rootsi', '94131', 3157, 'village'),
                     (3183, 'Salavere', '94150', 3157, 'village'),
                     (3184, 'Rahniku', '94118', 3157, 'village'),
                     (3185, 'Kangrusselja', '94153', 3157, 'village'),
                     (3186, 'Kailuka', '94127', 3157, 'village'),
                     (3187, 'Ilpla', '94161', 3157, 'village'),
                     (3188, 'Leina', '94115', 3157, 'village'),
                     (3189, 'Liiva-Putla', '94145', 3157, 'village'),
                     (3190, 'Sandla', '94121', 3157, 'village'),
                     (3191, 'Torgu', '', 2852, 'municipality'),
                     (3192, 'Läbara', '', 3191, 'village'),
                     (3193, 'Iide', '', 3191, 'village'),
                     (3194, 'Kaavi', '93239', 3191, 'village'),
                     (3195, 'Lindmetsa', '93243', 3191, 'village'),
                     (3196, 'Mäebe', '', 3191, 'village'),
                     (3197, 'Mõntu', '93122', 3191, 'village'),
                     (3198, 'Lõupõllu', '93245', 3191, 'village'),
                     (3199, 'Mässa', '93247', 3191, 'village'),
                     (3200, 'Sääre', '93249', 3191, 'village'),
                     (3201, 'Maantee', '93121', 3191, 'village'),
                     (3202, 'Soodevahe', '93114', 3191, 'village'),
                     (3203, 'Karuste', '93241', 3191, 'village'),
                     (3204, 'Tammuna', '93250', 3191, 'village'),
                     (3205, 'Jämaja', '93238', 3191, 'village'),
                     (3206, 'Ohessaare', '93248', 3191, 'village'),
                     (3207, 'Kaunispe', '93242', 3191, 'village'),
                     (3208, 'Laadla', '93112', 3191, 'village'),
                     (3209, 'Kargi', '93240', 3191, 'village'),
                     (3210, 'Hänga', '93111', 3191, 'village'),
                     (3211, 'Lülle', '93113', 3191, 'village'),
                     (3212, 'Türju', '93251', 3191, 'village'),
                     (3213, 'Mustjala', '', 2852, 'municipality'),
                     (3214, 'Merise', '', 3213, 'village'),
                     (3215, 'Silla', '', 3213, 'village'),
                     (3216, 'Rahtla', '93614', 3213, 'village'),
                     (3217, 'Kugalepa', '93611', 3213, 'village'),
                     (3218, 'Küdema', '93622', 3213, 'village'),
                     (3219, 'Selgase', '93642', 3213, 'village'),
                     (3220, 'Jauni', '93641', 3213, 'village'),
                     (3221, 'Ohtja', '93623', 3213, 'village'),
                     (3222, 'Tuiu', '93645', 3213, 'village'),
                     (3223, 'Tagaranna', '93616', 3213, 'village'),
                     (3224, 'Kiruma', '93621', 3213, 'village'),
                     (3225, 'Paatsa', '93644', 3213, 'village'),
                     (3226, 'Vanakubja', '93617', 3213, 'village'),
                     (3227, 'Panga', '93634', 3213, 'village'),
                     (3228, 'Pahapilli', '93633', 3213, 'village'),
                     (3229, 'Ninase', '93613', 3213, 'village'),
                     (3230, 'Järise', '93643', 3213, 'village'),
                     (3231, 'Liiküla', '93631', 3213, 'village'),
                     (3232, 'Laimjala', '', 2852, 'municipality'),
                     (3233, 'Rannaküla', '', 3232, 'village'),
                     (3234, 'Aaviku', '94417', 3232, 'village'),
                     (3235, 'Käo', '94434', 3232, 'village'),
                     (3236, 'Mustla', '', 3232, 'village'),
                     (3237, 'Asva', '94418', 3232, 'village'),
                     (3238, 'Üüvere', '94425', 3232, 'village'),
                     (3239, 'Paju-Kurdla', '94415', 3232, 'village'),
                     (3240, 'Saaremetsa', '94443', 3232, 'village'),
                     (3241, 'Audla', '94431', 3232, 'village'),
                     (3242, 'Kapra', '94432', 3232, 'village'),
                     (3243, 'Kõiguste', '94421', 3232, 'village'),
                     (3244, 'Jõe', '', 3232, 'village'),
                     (3245, 'Saareküla', '94442', 3232, 'village'),
                     (3246, 'Mägi-Kurdla', '94412', 3232, 'village'),
                     (3247, 'Ridala', '94416', 3232, 'village'),
                     (3248, 'Pahavalla', '94414', 3232, 'village'),
                     (3249, 'Kahtla', '94420', 3232, 'village'),
                     (3250, 'Kingli', '94433', 3232, 'village'),
                     (3251, 'Viltina', '94424', 3232, 'village'),
                     (3252, 'Ruhve', '94423', 3232, 'village'),
                     (3253, 'Muhu', '', 2852, 'municipality'),
                     (3254, 'Liiva', '', 3253, 'village'),
                     (3255, 'Rinsi', '94761', 3253, 'village'),
                     (3256, 'Vanamõisa', '', 3253, 'village'),
                     (3257, 'Tamse', '94763', 3253, 'village'),
                     (3258, 'Igaküla', '94722', 3253, 'village'),
                     (3259, 'Pallasmaa', '94754', 3253, 'village'),
                     (3260, 'Päelda', '94755', 3253, 'village'),
                     (3261, 'Koguva', '94724', 3253, 'village'),
                     (3262, 'Kantsi', '94723', 3253, 'village'),
                     (3263, 'Lehtmetsa', '94746', 3253, 'village'),
                     (3264, 'Võiküla', '94713', 3253, 'village'),
                     (3265, 'Simisti', '94719', 3253, 'village'),
                     (3266, 'Nautse', '94728', 3253, 'village'),
                     (3267, 'Levalõpme', '94748', 3253, 'village'),
                     (3268, 'Linnuse', '', 3253, 'village'),
                     (3269, 'Mõega', '94711', 3253, 'village'),
                     (3270, 'Kapi', '94743', 3253, 'village'),
                     (3271, 'Raugi', '94759', 3253, 'village'),
                     (3272, 'Mõisaküla', '', 3253, 'village'),
                     (3273, 'Kuivastu', '94702', 3253, 'village'),
                     (3274, 'Külasema', '94744', 3253, 'village'),
                     (3275, 'Leeskopa', '94726', 3253, 'village'),
                     (3276, 'Vahtraste', '94765', 3253, 'village'),
                     (3277, 'Rässa', '94718', 3253, 'village'),
                     (3278, 'Raegma', '94717', 3253, 'village'),
                     (3279, 'Lõetsa', '94749', 3253, 'village'),
                     (3280, 'Pädaste', '94716', 3253, 'village'),
                     (3281, 'Kallaste', '', 3253, 'village'),
                     (3282, 'Kesse', '94720', 3253, 'village'),
                     (3283, 'Pärase', '94756', 3253, 'village'),
                     (3284, 'Lalli', '94745', 3253, 'village'),
                     (3285, 'Oina', '94715', 3253, 'village'),
                     (3286, 'Ridasi', '94731', 3253, 'village'),
                     (3287, 'Soonda', '94762', 3253, 'village'),
                     (3288, 'Tupenurme', '94764', 3253, 'village'),
                     (3289, 'Piiri', '94730', 3253, 'village'),
                     (3290, 'Mäla', '94750', 3253, 'village'),
                     (3291, 'Paenase', '94753', 3253, 'village'),
                     (3292, 'Suuremõisa', '94733', 3253, 'village'),
                     (3293, 'Põitse', '94757', 3253, 'village'),
                     (3294, 'Tusti', '94712', 3253, 'village'),
                     (3295, 'Lepiku', '94747', 3253, 'village'),
                     (3296, 'Hellamaa', '94741', 3253, 'village'),
                     (3297, 'Rootsivere', '94732', 3253, 'village'),
                     (3298, 'Võlla', '94714', 3253, 'village'),
                     (3299, 'Rebaski', '94760', 3253, 'village'),
                     (3300, 'Aljava', '94721', 3253, 'village'),
                     (3301, 'Nõmmküla', '94752', 3253, 'village'),
                     (3302, 'Ruhnu', '', 2852, 'municipality'),
                     (3303, 'Tartu', '', None, 'county'),
                     (3304, 'Tartu', '', 3303, 'town'),
                     (3305, 'Kõrveküla', '', 3304, 'smallborough'),
                     (3306, 'Vahi', '', 3304, 'smallborough'),
                     (3307, 'Lombi', '', 3304, 'village'),
                     (3308, 'Lähte', '', 3304, 'smallborough'),
                     (3309, 'Maramaa', '', 3304, 'village'),
                     (3310, 'Tila', '', 3304, 'village'),
                     (3311, 'Haava', '', 3304, 'village'),
                     (3312, 'Aovere', '', 3304, 'village'),
                     (3313, 'Vasula', '', 3304, 'village'),
                     (3314, 'Vesneri', '', 3304, 'village'),
                     (3315, 'Äksi', '', 3304, 'smallborough'),
                     (3316, 'Kastli', '60508', 3304, 'village'),
                     (3317, 'Salu', '60525', 3304, 'village'),
                     (3318, 'Soitsjärve', '60527', 3304, 'village'),
                     (3319, 'Sojamaa', '60528', 3304, 'village'),
                     (3320, 'Igavere', '60506', 3304, 'village'),
                     (3321, 'Jõusa', '60507', 3304, 'village'),
                     (3322, 'Võibla', '60540', 3304, 'village'),
                     (3323, 'Pupastvere', '60523', 3304, 'village'),
                     (3324, 'Kobratu', '60510', 3304, 'village'),
                     (3325, 'Väägvere', '60541', 3304, 'village'),
                     (3326, 'Kukulinna', '60511', 3304, 'village'),
                     (3327, 'Tammistu', '60531', 3304, 'village'),
                     (3328, 'Õvi', '60542', 3304, 'village'),
                     (3329, 'Kükitaja', '60514', 3304, 'village'),
                     (3330, 'Vedu', '60536', 3304, 'village'),
                     (3331, 'Arupää', '60504', 3304, 'village'),
                     (3332, 'Sootaga', '60529', 3304, 'village'),
                     (3333, 'Erala', '60505', 3304, 'village'),
                     (3334, 'Toolamaa', '60533', 3304, 'village'),
                     (3335, 'Kikivere', '60509', 3304, 'village'),
                     (3336, 'Viidike', '60538', 3304, 'village'),
                     (3337, 'Nõela', '60521', 3304, 'village'),
                     (3338, 'Lammiku', '60515', 3304, 'village'),
                     (3339, 'Möllatsi', '60519', 3304, 'village'),
                     (3340, 'Puhtaleiva', '60522', 3304, 'village'),
                     (3341, 'Saadjärve', '60524', 3304, 'village'),
                     (3342, 'Vilussaare', '60539', 3304, 'village'),
                     (3343, 'Kärkna', '60513', 3304, 'village'),
                     (3344, 'Soeküla', '60526', 3304, 'village'),
                     (3345, 'Metsanuka', '60518', 3304, 'village'),
                     (3346, 'Nigula', '60520', 3304, 'village'),
                     (3347, 'Taabri', '60530', 3304, 'village'),
                     (3348, 'Luunja', '', 3303, 'municipality'),
                     (3349, 'Lohkva', '', 3348, 'village'),
                     (3350, 'Veibri', '', 3348, 'village'),
                     (3351, 'Kabina', '', 3348, 'village'),
                     (3352, 'Rõõmu', '', 3348, 'village'),
                     (3353, 'Kakumetsa', '', 3348, 'village'),
                     (3354, 'Põvvatu', '', 3348, 'village'),
                     (3355, 'Sava', '62214', 3348, 'village'),
                     (3356, 'Pajukurmu', '62209', 3348, 'village'),
                     (3357, 'Savikoja', '62215', 3348, 'village'),
                     (3358, 'Pilka', '', 3348, 'village'),
                     (3359, 'Poksi', '62211', 3348, 'village'),
                     (3360, 'Sääsekõrva', '62218', 3348, 'village'),
                     (3361, 'Kikaste', '62205', 3348, 'village'),
                     (3362, 'Kõivu', '62206', 3348, 'village'),
                     (3363, 'Sirgumetsa', '62217', 3348, 'village'),
                     (3364, 'Viira', '62221', 3348, 'village'),
                     (3365, 'Muri', '62208', 3348, 'village'),
                     (3366, 'Kavastu', '62204', 3348, 'village'),
                     (3367, 'Sääsküla', '62219', 3348, 'village'),
                     (3368, 'Sirgu', '62216', 3348, 'village'),
                     (3369, 'Ülenurme', '', 3303, 'municipality'),
                     (3370, 'Tõrvandi', '', 3369, 'smallborough'),
                     (3371, 'Soinaste', '', 3369, 'village'),
                     (3372, 'Räni', '', 3369, 'village'),
                     (3373, 'Laane', '', 3369, 'village'),
                     (3374, 'Külitse', '', 3369, 'village'),
                     (3375, 'Lemmatsi', '', 3369, 'village'),
                     (3376, 'Uhti', '', 3369, 'village'),
                     (3377, 'Õssu', '', 3369, 'village'),
                     (3378, 'Reola', '', 3369, 'village'),
                     (3379, 'Lepiku', '', 3369, 'village'),
                     (3380, 'Soosilla', '61710', 3369, 'village'),
                     (3381, 'Läti', '61706', 3369, 'village'),
                     (3382, 'Täsvere', '61711', 3369, 'village'),
                     (3383, 'Haaslava', '', 3303, 'municipality'),
                     (3384, 'Roiu', '', 3383, 'smallborough'),
                     (3385, 'Aardlapalu', '', 3383, 'village'),
                     (3386, 'Tõõraste', '', 3383, 'village'),
                     (3387, 'Aardla', '', 3383, 'village'),
                     (3388, 'Mõra', '', 3383, 'village'),
                     (3389, 'Lange', '', 3383, 'village'),
                     (3390, 'Aadami', '', 3383, 'village'),
                     (3391, 'Ignase', '', 3383, 'village'),
                     (3392, 'Kõivuküla', '', 3383, 'village'),
                     (3393, 'Koke', '62111', 3383, 'village'),
                     (3394, 'Kurepalu', '', 3383, 'village'),
                     (3395, 'Igevere', '62108', 3383, 'village'),
                     (3396, 'Päkste', '62119', 3383, 'village'),
                     (3397, 'Alaküla', '62106', 3383, 'village'),
                     (3398, 'Kitseküla', '62110', 3383, 'village'),
                     (3399, 'Paluküla', '62118', 3383, 'village'),
                     (3400, 'Uniküla', '62121', 3383, 'village'),
                     (3401, 'Metsanurga', '62116', 3383, 'village'),
                     (3402, 'Rõngu', '', 3303, 'municipality'),
                     (3403, 'Käärdi', '', 3402, 'smallborough'),
                     (3404, 'Teedla', '', 3402, 'village'),
                     (3405, 'Kalme', '', 3402, 'village'),
                     (3406, 'Raigaste', '', 3402, 'village'),
                     (3407, 'Valguta', '', 3402, 'village'),
                     (3408, 'Uderna', '', 3402, 'village'),
                     (3409, 'Lapetukme', '', 3402, 'village'),
                     (3410, 'Rannaküla', '61012', 3402, 'village'),
                     (3411, 'Kirepi', '61003', 3402, 'village'),
                     (3412, 'Lossimäe', '61009', 3402, 'village'),
                     (3413, 'Tammiste', '61013', 3402, 'village'),
                     (3414, 'Koruste', '61004', 3402, 'village'),
                     (3415, 'Piigandi', '61010', 3402, 'village'),
                     (3416, 'Käo', '61006', 3402, 'village'),
                     (3417, 'Tilga', '61015', 3402, 'village'),
                     (3418, 'Kõduküla', '61005', 3402, 'village'),
                     (3419, 'Kambja', '', 3303, 'municipality'),
                     (3420, 'Sulu', '', 3419, 'village'),
                     (3421, 'Pangodi', '', 3419, 'village'),
                     (3422, 'Visnapuu', '', 3419, 'village'),
                     (3423, 'Virulase', '', 3419, 'village'),
                     (3424, 'Vana-Kuuste', '', 3419, 'village'),
                     (3425, 'Madise', '', 3419, 'village'),
                     (3426, 'Kullaga', '62009', 3419, 'village'),
                     (3427, 'Kodijärve', '62008', 3419, 'village'),
                     (3428, 'Sirvaku', '62025', 3419, 'village'),
                     (3429, 'Kõrkküla', '62010', 3419, 'village'),
                     (3430, 'Mäeküla', '62013', 3419, 'village'),
                     (3431, 'Pühi', '62019', 3419, 'village'),
                     (3432, 'Raanitsa', '62020', 3419, 'village'),
                     (3433, 'Aakaru', '', 3419, 'village'),
                     (3434, 'Oomiste', '', 3419, 'village'),
                     (3435, 'Sipe', '62024', 3419, 'village'),
                     (3436, 'Kavandu', '62032', 3419, 'village'),
                     (3437, 'Reolasoo', '62022', 3419, 'village'),
                     (3438, 'Ivaste', '62005', 3419, 'village'),
                     (3439, 'Paali', '62015', 3419, 'village'),
                     (3440, 'Tatra', '62029', 3419, 'village'),
                     (3441, 'Pulli', '62018', 3419, 'village'),
                     (3442, 'Talvikese', '62028', 3419, 'village'),
                     (3443, 'Riiviku', '62023', 3419, 'village'),
                     (3444, 'Kammeri', '62007', 3419, 'village'),
                     (3445, 'Palumäe', '62016', 3419, 'village'),
                     (3446, 'Rebase', '62021', 3419, 'village'),
                     (3447, 'Lalli', '62011', 3419, 'village'),
                     (3448, 'Suure-Kambja', '62027', 3419, 'village'),
                     (3449, 'Kaatsi', '62006', 3419, 'village'),
                     (3450, 'Elva', '', 3303, 'town'),
                     (3451, 'Nõo', '', 3303, 'municipality'),
                     (3452, 'Tõravere', '', 3451, 'smallborough'),
                     (3453, 'Luke', '', 3451, 'village'),
                     (3454, 'Meeri', '', 3451, 'village'),
                     (3455, 'Tamsa', '', 3451, 'village'),
                     (3456, 'Nõgiaru', '', 3451, 'village'),
                     (3457, 'Etsaste', '', 3451, 'village'),
                     (3458, 'Vissi', '', 3451, 'village'),
                     (3459, 'Uuta', '61620', 3451, 'village'),
                     (3460, 'Ketneri', '61610', 3451, 'village'),
                     (3461, 'Altmäe', '61604', 3451, 'village'),
                     (3462, 'Kääni', '61612', 3451, 'village'),
                     (3463, 'Voika', '', 3451, 'village'),
                     (3464, 'Aiamaa', '61603', 3451, 'village'),
                     (3465, 'Laguja', '61613', 3451, 'village'),
                     (3466, 'Kolga', '61611', 3451, 'village'),
                     (3467, 'Enno', '61605', 3451, 'village'),
                     (3468, 'Sassi', '61617', 3451, 'village'),
                     (3469, 'Keeri', '61609', 3451, 'village'),
                     (3470, 'Unipiha', '61619', 3451, 'village'),
                     (3471, 'Järiste', '61608', 3451, 'village'),
                     (3472, 'Kallaste', '', 3303, 'town'),
                     (3473, 'Puhja', '', 3303, 'municipality'),
                     (3474, 'Ulila', '', 3473, 'smallborough'),
                     (3475, 'Võsivere', '', 3473, 'village'),
                     (3476, 'Tännassilma', '', 3473, 'village'),
                     (3477, 'Teilma', '', 3473, 'village'),
                     (3478, 'Rämsi', '', 3473, 'village'),
                     (3479, 'Võllinge', '61318', 3473, 'village'),
                     (3480, 'Mõisanurme', '61307', 3473, 'village'),
                     (3481, 'Saare', '', 3473, 'village'),
                     (3482, 'Järvaküla', '61304', 3473, 'village'),
                     (3483, 'Mäeselja', '61308', 3473, 'village'),
                     (3484, 'Poriküla', '61311', 3473, 'village'),
                     (3485, 'Vihavu', '61317', 3473, 'village'),
                     (3486, 'Ridaküla', '61312', 3473, 'village'),
                     (3487, 'Kaimi', '61305', 3473, 'village'),
                     (3488, 'Nasja', '61309', 3473, 'village'),
                     (3489, 'Palupõhja', '60547', 3473, 'village'),
                     (3490, 'Härjanurme', '61303', 3473, 'village'),
                     (3491, 'Alatskivi', '', 3303, 'municipality'),
                     (3492, 'Savimetsa', '60226', 3491, 'village'),
                     (3493, 'Linaleo', '60210', 3491, 'village'),
                     (3494, 'Sudemäe', '60227', 3491, 'village'),
                     (3495, 'Virtsu', '60231', 3491, 'village'),
                     (3496, 'Rupsi', '60223', 3491, 'village'),
                     (3497, 'Savastvere', '60225', 3491, 'village'),
                     (3498, 'Tõruvere', '60230', 3491, 'village'),
                     (3499, 'Orgemäe', '60213', 3491, 'village'),
                     (3500, 'Lahe', '60208', 3491, 'village'),
                     (3501, 'Rootsiküla', '60222', 3491, 'village'),
                     (3502, 'Nina', '60212', 3491, 'village'),
                     (3503, 'Pusi', '60217', 3491, 'village'),
                     (3504, 'Kõdesi', '60207', 3491, 'village'),
                     (3505, 'Ronisoo', '60221', 3491, 'village'),
                     (3506, 'Lahepera', '60209', 3491, 'village'),
                     (3507, 'Toruküla', '60229', 3491, 'village'),
                     (3508, 'Päiksi', '60218', 3491, 'village'),
                     (3509, 'Passi', '60215', 3491, 'village'),
                     (3510, 'Padakõrve', '60214', 3491, 'village'),
                     (3511, 'Kesklahe', '60204', 3491, 'village'),
                     (3512, 'Naelavere', '60211', 3491, 'village'),
                     (3513, 'Kokora', '60205', 3491, 'village'),
                     (3514, 'Alasoo', '60202', 3491, 'village'),
                     (3515, 'Pärsikivi', '60219', 3491, 'village'),
                     (3516, 'Peatskivi', '60216', 3491, 'village'),
                     (3517, 'Torila', '60228', 3491, 'village'),
                     (3518, 'Haapsipea', '60203', 3491, 'village'),
                     (3519, 'Saburi', '60224', 3491, 'village'),
                     (3520, 'Väljaküla', '60232', 3491, 'village'),
                     (3521, 'Riidma', '60220', 3491, 'village'),
                     (3522, 'Kuningvere', '60206', 3491, 'village'),
                     (3523, 'Mäksa', '', 3303, 'municipality'),
                     (3524, 'Melliste', '', 3523, 'village'),
                     (3525, 'Sudaste', '62310', 3523, 'village'),
                     (3526, 'Võõpste', '62316', 3523, 'village'),
                     (3527, 'Tigase', '62312', 3523, 'village'),
                     (3528, 'Kastre', '62305', 3523, 'village'),
                     (3529, 'Tammevaldma', '62311', 3523, 'village'),
                     (3530, 'Veskimäe', '62314', 3523, 'village'),
                     (3531, 'Sarakuste', '62309', 3523, 'village'),
                     (3532, 'Aruaia', '62303', 3523, 'village'),
                     (3533, 'Mäletjärve', '62307', 3523, 'village'),
                     (3534, 'Vana-Kastre', '62313', 3523, 'village'),
                     (3535, 'Kaagvere', '62317', 3523, 'village'),
                     (3536, 'Kaarlimõisa', '62304', 3523, 'village'),
                     (3537, 'Poka', '62308', 3523, 'village'),
                     (3538, 'Võruküla', '62315', 3523, 'village'),
                     (3539, 'Tähtvere', '', 3303, 'municipality'),
                     (3540, 'Märja', '', 3539, 'smallborough'),
                     (3541, 'Pihva', '', 3539, 'village'),
                     (3542, 'Kandiküla', '', 3539, 'village'),
                     (3543, 'Rahinge', '', 3539, 'village'),
                     (3544, 'Tüki', '', 3539, 'village'),
                     (3545, 'Ilmatsalu', '', 3539, 'village'),
                     (3546, 'Rõhu', '', 3539, 'village'),
                     (3547, 'Vorbuse', '', 3539, 'village'),
                     (3548, 'Haage', '', 3539, 'village'),
                     (3549, 'Kardla', '', 3539, 'village'),
                     (3550, 'Konguta', '', 3303, 'municipality'),
                     (3551, 'Annikoru', '', 3550, 'village'),
                     (3552, 'Metsalaane', '', 3550, 'village'),
                     (3553, 'Pööritsa', '61214', 3550, 'village'),
                     (3554, 'Kurelaane', '61206', 3550, 'village'),
                     (3555, 'Külaaseme', '61207', 3550, 'village'),
                     (3556, 'Poole', '61213', 3550, 'village'),
                     (3557, 'Mäeotsa', '61211', 3550, 'village'),
                     (3558, 'Kapsta', '61203', 3550, 'village'),
                     (3559, 'Vahessaare', '61215', 3550, 'village'),
                     (3560, 'Lembevere', '61208', 3550, 'village'),
                     (3561, 'Mälgi', '61212', 3550, 'village'),
                     (3562, 'Karijärve', '61204', 3550, 'village'),
                     (3563, 'Majala', '61209', 3550, 'village'),
                     (3564, 'Vellavere', '61216', 3550, 'village'),
                     (3565, 'Kobilu', '61205', 3550, 'village'),
                     (3566, 'Rannu', '', 3303, 'municipality'),
                     (3567, 'Tamme', '', 3566, 'village'),
                     (3568, 'Koopsi', '61106', 3566, 'village'),
                     (3569, 'Kureküla', '', 3566, 'smallborough'),
                     (3570, 'Utukolga', '61115', 3566, 'village'),
                     (3571, 'Järveküla', '61103', 3566, 'village'),
                     (3572, 'Sangla', '61112', 3566, 'village'),
                     (3573, 'Noorma', '61110', 3566, 'village'),
                     (3574, 'Vallapalu', '61116', 3566, 'village'),
                     (3575, 'Kaarlijärve', '61104', 3566, 'village'),
                     (3576, 'Kulli', '61107', 3566, 'village'),
                     (3577, 'Suure-Rakke', '61113', 3566, 'village'),
                     (3578, 'Ervu', '61102', 3566, 'village'),
                     (3579, 'Väike-Rakke', '61119', 3566, 'village'),
                     (3580, 'Paju', '61111', 3566, 'village'),
                     (3581, 'Verevi', '61118', 3566, 'village'),
                     (3582, 'Kipastu', '61105', 3566, 'village'),
                     (3583, 'Laeva', '', 3303, 'municipality'),
                     (3584, 'Kärevere', '', 3583, 'village'),
                     (3585, 'Siniküla', '', 3583, 'village'),
                     (3586, 'Valmaotsa', '60605', 3583, 'village'),
                     (3587, 'Kämara', '60602', 3583, 'village'),
                     (3588, 'Väänikvere', '60606', 3583, 'village'),
                     (3589, 'Võnnu', '', 3303, 'municipality'),
                     (3590, 'Hammaste', '62404', 3589, 'village'),
                     (3591, 'Imste', '62405', 3589, 'village'),
                     (3592, 'Kannu', '62407', 3589, 'village'),
                     (3593, 'Agali', '62402', 3589, 'village'),
                     (3594, 'Ahunapalu', '62414', 3589, 'village'),
                     (3595, 'Terikeste', '62413', 3589, 'village'),
                     (3596, 'Kurista', '62408', 3589, 'village'),
                     (3597, 'Rookse', '62412', 3589, 'village'),
                     (3598, 'Lääniste', '62411', 3589, 'village'),
                     (3599, 'Issaku', '62406', 3589, 'village'),
                     (3600, 'Kõnnu', '62409', 3589, 'village'),
                     (3601, 'Liispõllu', '62410', 3589, 'village'),
                     (3602, 'Peipsiääre', '', 3303, 'municipality'),
                     (3603, 'Varnja', '', 3602, 'smallborough'),
                     (3604, 'Kolkja', '', 3602, 'smallborough'),
                     (3605, 'Savka', '60303', 3602, 'village'),
                     (3606, 'Kasepää', '60302', 3602, 'smallborough'),
                     (3607, 'Sipelga', '60304', 3602, 'village'),
                     (3608, 'Meeksi', '', 3303, 'municipality'),
                     (3609, 'Mehikoorma', '', 3608, 'smallborough'),
                     (3610, 'Haavametsa', '62504', 3608, 'village'),
                     (3611, 'Rõka', '62509', 3608, 'village'),
                     (3612, 'Järvselja', '62506', 3608, 'village'),
                     (3613, 'Aravu', '62503', 3608, 'village'),
                     (3614, 'Sikakurmu', '62510', 3608, 'village'),
                     (3615, 'Meerapalu', '62502', 3608, 'village'),
                     (3616, 'Jõepera', '62505', 3608, 'village'),
                     (3617, 'Parapalu', '62508', 3608, 'village'),
                     (3618, 'Vara', '', 3303, 'municipality'),
                     (3619, 'Keressaare', '', 3618, 'village'),
                     (3620, 'Koosa', '', 3618, 'village'),
                     (3621, 'Põrgu', '60418', 3618, 'village'),
                     (3622, 'Rehemetsa', '60419', 3618, 'village'),
                     (3623, 'Kusma', '60408', 3618, 'village'),
                     (3624, 'Põdra', '60416', 3618, 'village'),
                     (3625, 'Sookalduse', '60421', 3618, 'village'),
                     (3626, 'Matjama', '60431', 3618, 'village'),
                     (3627, 'Koosalaane', '60407', 3618, 'village'),
                     (3628, 'Vanaussaia', '60425', 3618, 'village'),
                     (3629, 'Praaga', '60415', 3618, 'village'),
                     (3630, 'Selgise', '60420', 3618, 'village'),
                     (3631, 'Pilpaküla', '60414', 3618, 'village'),
                     (3632, 'Tähemaa', '60423', 3618, 'village'),
                     (3633, 'Meoma', '60410', 3618, 'village'),
                     (3634, 'Särgla', '60422', 3618, 'village'),
                     (3635, 'Mustametsa', '60412', 3618, 'village'),
                     (3636, 'Undi', '60424', 3618, 'village'),
                     (3637, 'Metsakivi', '60411', 3618, 'village'),
                     (3638, 'Kuusiku', '60409', 3618, 'village'),
                     (3639, 'Kargaja', '60404', 3618, 'village'),
                     (3640, 'Alajõe', '60403', 3618, 'village'),
                     (3641, 'Kauda', '60405', 3618, 'village'),
                     (3642, 'Põldmaa', '60417', 3618, 'village'),
                     (3643, 'Välgi', '60427', 3618, 'village'),
                     (3644, 'Ätte', '60428', 3618, 'village'),
                     (3645, 'Papiaru', '60413', 3618, 'village'),
                     (3646, 'Piirissaare', '', 3303, 'municipality'),
                     (3647, 'Piiri', '', 3646, 'village'),
                     (3648, 'Tooni', '62603', 3646, 'village'),
                     (3649, 'Vehendi', '', 3303, 'municipality'),
                     (3650, 'Kriimani', '', 3303, 'municipality'),
                     (3651, 'Illi', '', 3303, 'municipality'),
                     (3652, 'Neemisküla', '', 3303, 'municipality'),
                     (3653, 'Valga', '', None, 'county'),
                     (3654, 'Valga', '', 3653, 'town'),
                     (3655, 'Tõrva', '', 3653, 'town'),
                     (3656, 'Otepää', '', 3653, 'town'),
                     (3657, 'Nüpli', '', 3656, 'village'),
                     (3658, 'Sihva', '', 3656, 'village'),
                     (3659, 'Pühajärve', '', 3656, 'village'),
                     (3660, 'Vidrike', '67304', 3656, 'village'),
                     (3661, 'Pedajamäe', '67417', 3656, 'village'),
                     (3662, 'Tõutsi', '67303', 3656, 'village'),
                     (3663, 'Kääriku', '67309', 3656, 'village'),
                     (3664, 'Mägestiku', '67310', 3656, 'village'),
                     (3665, 'Pilkuse', '67416', 3656, 'village'),
                     (3666, 'Kastolatsi', '67410', 3656, 'village'),
                     (3667, 'Truuta', '67302', 3656, 'village'),
                     (3668, 'Kaurutootsi', '67307', 3656, 'village'),
                     (3669, 'Raudsepa', '67415', 3656, 'village'),
                     (3670, 'Arula', '67411', 3656, 'village'),
                     (3671, 'Mäha', '67409', 3656, 'village'),
                     (3672, 'Kassiratta', '67306', 3656, 'village'),
                     (3673, 'Koigu', '67308', 3656, 'village'),
                     (3674, 'Vana-Otepää', '67418', 3656, 'village'),
                     (3675, 'Märdi', '67311', 3656, 'village'),
                     (3676, 'Ilmjärve', '67305', 3656, 'village'),
                     (3677, 'Puka', '', 3653, 'municipality'),
                     (3678, 'Rebaste', '67216', 3677, 'village'),
                     (3679, 'Aakre', '67212', 3677, 'village'),
                     (3680, 'Palamuste', '67213', 3677, 'village'),
                     (3681, 'Pühaste', '67215', 3677, 'village'),
                     (3682, 'Pedaste', '67214', 3677, 'village'),
                     (3683, 'Põru', '67210', 3677, 'village'),
                     (3684, 'Prange', '67209', 3677, 'village'),
                     (3685, 'Purtsi', '68709', 3677, 'village'),
                     (3686, 'Meegaste', '67207', 3677, 'village'),
                     (3687, 'Kolli', '67204', 3677, 'village'),
                     (3688, 'Kibena', '67203', 3677, 'village'),
                     (3689, 'Vaardi', '68229', 3677, 'village'),
                     (3690, 'Kuigatsi', '68222', 3677, 'village'),
                     (3691, 'Kähri', '67206', 3677, 'village'),
                     (3692, 'Plika', '67208', 3677, 'village'),
                     (3693, 'Soontaga', '68617', 3677, 'village'),
                     (3694, 'Ruuna', '67211', 3677, 'village'),
                     (3695, 'Komsi', '67205', 3677, 'village'),
                     (3696, 'Õru', '', 3653, 'municipality'),
                     (3697, 'Õlatu', '67108', 3696, 'village'),
                     (3698, 'Õruste', '67111', 3696, 'village'),
                     (3699, 'Priipalu', '67102', 3696, 'village'),
                     (3700, 'Mustumetsa', '67106', 3696, 'village'),
                     (3701, 'Killinge', '67103', 3696, 'village'),
                     (3702, 'Lota', '67105', 3696, 'village'),
                     (3703, 'Kiviküla', '67104', 3696, 'village'),
                     (3704, 'Uniküla', '67107', 3696, 'village'),
                     (3705, 'Tõlliste', '', 3653, 'municipality'),
                     (3706, 'Tsirguliina', '', 3705, 'smallborough'),
                     (3707, 'Sooru', '', 3705, 'village'),
                     (3708, 'Laatre', '', 3705, 'smallborough'),
                     (3709, 'Jaanikese', '', 3705, 'village'),
                     (3710, 'Tagula', '', 3705, 'village'),
                     (3711, 'Vilaski', '68311', 3705, 'village'),
                     (3712, 'Rampe', '68310', 3705, 'village'),
                     (3713, 'Muhkva', '68309', 3705, 'village'),
                     (3714, 'Paju', '68217', 3705, 'village'),
                     (3715, 'Korijärve', '68313', 3705, 'village'),
                     (3716, 'Iigaste', '68308', 3705, 'village'),
                     (3717, 'Tinu', '68306', 3705, 'village'),
                     (3718, 'Supa', '68305', 3705, 'village'),
                     (3719, 'Väljaküla', '68312', 3705, 'village'),
                     (3720, 'Sangaste', '', 3653, 'municipality'),
                     (3721, 'Keeni', '', 3720, 'village'),
                     (3722, 'Lossiküla', '', 3720, 'village'),
                     (3723, 'Sarapuu', '67009', 3720, 'village'),
                     (3724, 'Vaalu', '68221', 3720, 'village'),
                     (3725, 'Lauküla', '67011', 3720, 'village'),
                     (3726, 'Tiidu', '67010', 3720, 'village'),
                     (3727, 'Kurevere', '67004', 3720, 'village'),
                     (3728, 'Mäeküla', '67003', 3720, 'village'),
                     (3729, 'Risttee', '67007', 3720, 'village'),
                     (3730, 'Mägiste', '68224', 3720, 'village'),
                     (3731, 'Restu', '67006', 3720, 'village'),
                     (3732, 'Ädu', '68219', 3720, 'village'),
                     (3733, 'Pringi', '68223', 3720, 'village'),
                     (3734, 'Karula', '', 3653, 'municipality'),
                     (3735, 'Raavitsa', '', 3734, 'village'),
                     (3736, 'Kaagjärve', '', 3734, 'village'),
                     (3737, 'Valtina', '', 3734, 'village'),
                     (3738, 'Lüllemäe', '', 3734, 'village'),
                     (3739, 'Koobassaare', '68111', 3734, 'village'),
                     (3740, 'Kirbu', '68107', 3734, 'village'),
                     (3741, 'Väheru', '68105', 3734, 'village'),
                     (3742, 'Pikkjärve', '68110', 3734, 'village'),
                     (3743, 'Rebasemõisa', '68113', 3734, 'village'),
                     (3744, 'Pugritsa', '68104', 3734, 'village'),
                     (3745, 'Londi', '68103', 3734, 'village'),
                     (3746, 'Käärikmäe', '68108', 3734, 'village'),
                     (3747, 'Lusti', '68109', 3734, 'village'),
                     (3748, 'Helme', '', 3653, 'municipality'),
                     (3749, 'Taagepera', '', 3748, 'village'),
                     (3750, 'Karjatnurme', '68511', 3748, 'village'),
                     (3751, 'Koorküla', '68508', 3748, 'village'),
                     (3752, 'Linna', '68619', 3748, 'village'),
                     (3753, 'Kirikuküla', '68611', 3748, 'village'),
                     (3754, 'Jõgeveste', '68616', 3748, 'village'),
                     (3755, 'Möldre', '68612', 3748, 'village'),
                     (3756, 'Holdre', '68505', 3748, 'village'),
                     (3757, 'Pilpa', '68504', 3748, 'village'),
                     (3758, 'Roobe', '68614', 3748, 'village'),
                     (3759, 'Patküla', '68613', 3748, 'village'),
                     (3760, 'Ala', '68507', 3748, 'village'),
                     (3761, 'Kalme', '68618', 3748, 'village'),
                     (3762, 'Kähu', '68506', 3748, 'village'),
                     (3763, 'Taheva', '', 3653, 'municipality'),
                     (3764, 'Koikküla', '', 3763, 'village'),
                     (3765, 'Hargla', '', 3763, 'village'),
                     (3766, 'Lutsu', '68005', 3763, 'village'),
                     (3767, 'Lepa', '68004', 3763, 'village'),
                     (3768, 'Sooblase', '68011', 3763, 'village'),
                     (3769, 'Tõrvase', '68008', 3763, 'village'),
                     (3770, 'Tsirgumäe', '68012', 3763, 'village'),
                     (3771, 'Korkuna', '68009', 3763, 'village'),
                     (3772, 'Koiva', '68006', 3763, 'village'),
                     (3773, 'Kalliküla', '68007', 3763, 'village'),
                     (3774, 'Laanemetsa', '68013', 3763, 'village'),
                     (3775, 'Ringiste', '68010', 3763, 'village'),
                     (3776, 'Põdrala', '', 3653, 'municipality'),
                     (3777, 'Leebiku', '', 3776, 'village'),
                     (3778, 'Riidaja', '', 3776, 'village'),
                     (3779, 'Pikasilla', '68715', 3776, 'village'),
                     (3780, 'Liva', '68706', 3776, 'village'),
                     (3781, 'Rulli', '68615', 3776, 'village'),
                     (3782, 'Uralaane', '68712', 3776, 'village'),
                     (3783, 'Lõve', '68707', 3776, 'village'),
                     (3784, 'Kungi', '68705', 3776, 'village'),
                     (3785, 'Karu', '68703', 3776, 'village'),
                     (3786, 'Vanamõisa', '68713', 3776, 'village'),
                     (3787, 'Kaubi', '68704', 3776, 'village'),
                     (3788, 'Pori', '68708', 3776, 'village'),
                     (3789, 'Voorbahi', '68714', 3776, 'village'),
                     (3790, 'Reti', '68710', 3776, 'village'),
                     (3791, 'Palupera', '', 3653, 'municipality'),
                     (3792, 'Hellenurme', '', 3791, 'village'),
                     (3793, 'Nõuni', '', 3791, 'village'),
                     (3794, 'Mäelooga', '67510', 3791, 'village'),
                     (3795, 'Atra', '67508', 3791, 'village'),
                     (3796, 'Räbi', '67503', 3791, 'village'),
                     (3797, 'Urmi', '67513', 3791, 'village'),
                     (3798, 'Päidla', '67506', 3791, 'village'),
                     (3799, 'Miti', '67509', 3791, 'village'),
                     (3800, 'Pastaku', '67512', 3791, 'village'),
                     (3801, 'Makita', '67516', 3791, 'village'),
                     (3802, 'Astuvere', '67507', 3791, 'village'),
                     (3803, 'Neeruti', '67505', 3791, 'village'),
                     (3804, 'Lutike', '67504', 3791, 'village'),
                     (3805, 'Hummuli', '', 3653, 'municipality'),
                     (3806, 'Piiri', '68405', 3805, 'village'),
                     (3807, 'Ransi', '68407', 3805, 'village'),
                     (3808, 'Kulli', '68404', 3805, 'village'),
                     (3809, 'Aitsra', '68402', 3805, 'village'),
                     (3810, 'Jeti', '68513', 3805, 'village'),
                     (3811, 'Soe', '68408', 3805, 'village'),
                     (3812, 'Puide', '68411', 3805, 'village'),
                     (3813, 'Alamõisa', '68403', 3805, 'village'),
                     (3814, 'Viljandi', '', None, 'county'),
                     (3815, 'Suure-Jaani', '', 3814, 'municipality'),
                     (3816, 'Vastemõisa', '', 3815, 'village'),
                     (3817, 'Ülde', '', 3815, 'village'),
                     (3818, 'Võivaku', '', 3815, 'village'),
                     (3819, 'Reegoldi', '', 3815, 'village'),
                     (3820, 'Jälevere', '', 3815, 'village'),
                     (3821, 'Nuutre', '', 3815, 'village'),
                     (3822, 'Olustvere', '', 3815, 'smallborough'),
                     (3823, 'Lõhavere', '', 3815, 'village'),
                     (3824, 'Sürgavere', '', 3815, 'village'),
                     (3825, 'Päraküla', '', 3815, 'village'),
                     (3826, 'Tääksi', '', 3815, 'village'),
                     (3827, 'Kõidama', '', 3815, 'village'),
                     (3828, 'Kärevere', '70407', 3815, 'village'),
                     (3829, 'Karjasoo', '71408', 3815, 'village'),
                     (3830, 'Metsküla', '71302', 3815, 'village'),
                     (3831, 'Tällevere', '71511', 3815, 'village'),
                     (3832, 'Jaska', '70404', 3815, 'village'),
                     (3833, 'Ivaski', '71305', 3815, 'village'),
                     (3834, 'Kobruvere', '71306', 3815, 'village'),
                     (3835, 'Vihi', '71402', 3815, 'village'),
                     (3836, 'Mudiste', '70405', 3815, 'village'),
                     (3837, 'Kootsi', '71411', 3815, 'village'),
                     (3838, 'Mäeküla', '', 3815, 'village'),
                     (3839, 'Aimla', '70403', 3815, 'village'),
                     (3840, 'Navesti', '70406', 3815, 'village'),
                     (3841, 'Kurnuvere', '70412', 3815, 'village'),
                     (3842, 'Võhmassaare', '70606', 3815, 'village'),
                     (3843, 'Epra', '71405', 3815, 'village'),
                     (3844, 'Arjadi', '71505', 3815, 'village'),
                     (3845, 'Munsi', '71403', 3815, 'village'),
                     (3846, 'Ilbaku', '71307', 3815, 'village'),
                     (3847, 'Lahmuse', '71412', 3815, 'village'),
                     (3848, 'Ängi', '71507', 3815, 'village'),
                     (3849, 'Rääka', '71409', 3815, 'village'),
                     (3850, 'Taevere', '71510', 3815, 'village'),
                     (3851, 'Kildu', '71303', 3815, 'village'),
                     (3852, 'Sandra', '71309', 3815, 'village'),
                     (3853, 'Kibaru', '71506', 3815, 'village'),
                     (3854, 'Kuhjavere', '70414', 3815, 'village'),
                     (3855, 'Kuiavere', '70408', 3815, 'village'),
                     (3856, 'Paelama', '71308', 3815, 'village'),
                     (3857, 'Põhjaka', '71410', 3815, 'village'),
                     (3858, 'Kabila', '71404', 3815, 'village'),
                     (3859, 'Riiassaare', '70415', 3815, 'village'),
                     (3860, 'Kerita', '71406', 3815, 'village'),
                     (3861, 'Võlli', '71512', 3815, 'village'),
                     (3862, 'Lemmakõnnu', '71304', 3815, 'village'),
                     (3863, 'Abja', '', 3814, 'municipality'),
                     (3864, 'Abja-Paluoja', '', 3814, 'town'),
                     (3865, 'Veskimäe', '', 3864, 'village'),
                     (3866, 'Penuja', '', 3864, 'village'),
                     (3867, 'Abja-Vanamõisa', '', 3864, 'village'),
                     (3868, 'Põlde', '', 3864, 'village'),
                     (3869, 'Raamatu', '69308', 3864, 'village'),
                     (3870, 'Sarja', '69407', 3864, 'village'),
                     (3871, 'Atika', '69411', 3864, 'village'),
                     (3872, 'Saate', '69202', 3864, 'village'),
                     (3873, 'Veelikse', '69307', 3864, 'village'),
                     (3874, 'Umbsoo', '69309', 3864, 'village'),
                     (3875, 'Kamara', '69304', 3864, 'village'),
                     (3876, 'Räägu', '69310', 3864, 'village'),
                     (3877, 'Lasari', '69306', 3864, 'village'),
                     (3878, 'Laatre', '69305', 3864, 'village'),
                     (3879, 'Abjaku', '69410', 3864, 'village'),
                     (3880, 'Viljandi', '', 3814, 'town'),
                     (3881, 'Võhma', '', 3814, 'town'),
                     (3882, 'Mõisaküla', '', 3814, 'town'),
                     (3883, 'Viiratsi', '', 3814, 'municipality'),
                     (3884, 'Uusna', '', 3883, 'village'),
                     (3885, 'Vana-Võidu', '', 3883, 'village'),
                     (3886, 'Vardja', '', 3883, 'village'),
                     (3887, 'Tänassilma', '', 3883, 'village'),
                     (3888, 'Mähma', '', 3883, 'village'),
                     (3889, 'Jõeküla', '', 3883, 'village'),
                     (3890, 'Loime', '', 3883, 'village'),
                     (3891, 'Tõnuküla', '', 3883, 'village'),
                     (3892, 'Valma', '', 3883, 'village'),
                     (3893, 'Kibeküla', '69619', 3883, 'village'),
                     (3894, 'Saareküla', '70112', 3883, 'village'),
                     (3895, 'Vanavälja', '70114', 3883, 'village'),
                     (3896, 'Mäeltküla', '70105', 3883, 'village'),
                     (3897, 'Kuudeküla', '70111', 3883, 'village'),
                     (3898, 'Verilaske', '70110', 3883, 'village'),
                     (3899, 'Surva', '70115', 3883, 'village'),
                     (3900, 'Rebaste', '70117', 3883, 'village'),
                     (3901, 'Ridaküla', '70122', 3883, 'village'),
                     (3902, 'Vasara', '70107', 3883, 'village'),
                     (3903, 'Tusti', '70113', 3883, 'village'),
                     (3904, 'Ruudiküla', '70106', 3883, 'village'),
                     (3905, 'Halliste', '', 3814, 'municipality'),
                     (3906, 'Mõõnaste', '', 3905, 'village'),
                     (3907, 'Päidre', '', 3905, 'village'),
                     (3908, 'Kalvre', '', 3905, 'village'),
                     (3909, 'Hõbemäe', '69507', 3905, 'village'),
                     (3910, 'Ülemõisa', '69512', 3905, 'village'),
                     (3911, 'Maru', '69522', 3905, 'village'),
                     (3912, 'Naistevalla', '69519', 3905, 'village'),
                     (3913, 'Õisu', '69502', 3905, 'smallborough'),
                     (3914, 'Raja', '69503', 3905, 'village'),
                     (3915, 'Uue-Kariste', '69504', 3905, 'village'),
                     (3916, 'Vabamatsi', '69405', 3905, 'village'),
                     (3917, 'Rimmu', '69505', 3905, 'village'),
                     (3918, 'Mulgi', '69516', 3905, 'village'),
                     (3919, 'Pornuse', '69508', 3905, 'village'),
                     (3920, 'Kulla', '69509', 3905, 'village'),
                     (3921, 'Ereste', '69511', 3905, 'village'),
                     (3922, 'Saksaküla', '69520', 3905, 'village'),
                     (3923, 'Toosi', '69514', 3905, 'village'),
                     (3924, 'Päigiste', '69408', 3905, 'village'),
                     (3925, 'Kaarli', '69510', 3905, 'village'),
                     (3926, 'Tilla', '69517', 3905, 'village'),
                     (3927, 'Sammaste', '69521', 3905, 'village'),
                     (3928, 'Vana-Kariste', '69506', 3905, 'village'),
                     (3929, 'Niguli', '69515', 3905, 'village'),
                     (3930, 'Karksi', '', 3814, 'municipality'),
                     (3931, 'Karksi-Nuia', '', 3814, 'town'),
                     (3932, 'Kõvaküla', '', 3931, 'village'),
                     (3933, 'Morna', '', 3931, 'village'),
                     (3934, 'Univere', '', 3931, 'village'),
                     (3935, 'Polli', '', 3931, 'village'),
                     (3936, 'Lilli', '', 3931, 'village'),
                     (3937, 'Metsaküla', '69109', 3931, 'village'),
                     (3938, 'Hirmuküla', '69003', 3931, 'village'),
                     (3939, 'Leeli', '69106', 3931, 'village'),
                     (3940, 'Suuga', '71053', 3931, 'village'),
                     (3941, 'Muri', '71054', 3931, 'village'),
                     (3942, 'Sudiste', '69001', 3931, 'village'),
                     (3943, 'Ainja', '69105', 3931, 'village'),
                     (3944, 'Tuhalaane', '71056', 3931, 'village'),
                     (3945, 'Pärsi', '69110', 3931, 'village'),
                     (3946, 'Allaste', '69113', 3931, 'village'),
                     (3947, 'Äriküla', '69115', 3931, 'village'),
                     (3948, 'Pöögle', '69111', 3931, 'village'),
                     (3949, 'Oti', '69114', 3931, 'village'),
                     (3950, 'Kolga-Jaani', '', 3814, 'municipality'),
                     (3951, 'Leie', '', 3950, 'village'),
                     (3952, 'Parika', '70307', 3950, 'village'),
                     (3953, 'Eesnurga', '70306', 3950, 'village'),
                     (3954, 'Kaavere', '70318', 3950, 'village'),
                     (3955, 'Järtsaare', '70302', 3950, 'village'),
                     (3956, 'Oorgu', '70309', 3950, 'village'),
                     (3957, 'Odiste', '70308', 3950, 'village'),
                     (3958, 'Oiu', '70317', 3950, 'village'),
                     (3959, 'Vissuvere', '70311', 3950, 'village'),
                     (3960, 'Taganurga', '70310', 3950, 'village'),
                     (3961, 'Otiküla', '70316', 3950, 'village'),
                     (3962, 'Meleski', '70304', 3950, 'village'),
                     (3963, 'Vaibla', '70314', 3950, 'village'),
                     (3964, 'Lalsi', '70313', 3950, 'village'),
                     (3965, 'Lätkalu', '70315', 3950, 'village'),
                     (3966, 'Pärsti', '', 3814, 'municipality'),
                     (3967, 'Päri', '', 3966, 'village'),
                     (3968, 'Jämejala', '', 3966, 'village'),
                     (3969, 'Ramsi', '', 3966, 'smallborough'),
                     (3970, 'Kiisa', '', 3966, 'village'),
                     (3971, 'Vardi', '', 3966, 'village'),
                     (3972, 'Heimtali', '', 3966, 'village'),
                     (3973, 'Raudna', '', 3966, 'village'),
                     (3974, 'Rihkama', '', 3966, 'village'),
                     (3975, 'Puiatu', '', 3966, 'village'),
                     (3976, 'Mustivere', '', 3966, 'village'),
                     (3977, 'Matapera', '', 3966, 'village'),
                     (3978, 'Sinialliku', '', 3966, 'village'),
                     (3979, 'Pinska', '', 3966, 'village'),
                     (3980, 'Marna', '71108', 3966, 'village'),
                     (3981, 'Vanamõisa', '71119', 3966, 'village'),
                     (3982, 'Tõrreküla', '71111', 3966, 'village'),
                     (3983, 'Kookla', '71120', 3966, 'village'),
                     (3984, 'Savikoti', '71103', 3966, 'village'),
                     (3985, 'Kiini', '71125', 3966, 'village'),
                     (3986, 'Leemeti', '71122', 3966, 'village'),
                     (3987, 'Turva', '71112', 3966, 'village'),
                     (3988, 'Väike-Kõpu', '71124', 3966, 'village'),
                     (3989, 'Alustre', '71057', 3966, 'village'),
                     (3990, 'Laanekuru', '71107', 3966, 'village'),
                     (3991, 'Tohvri', '71114', 3966, 'village'),
                     (3992, 'Kingu', '71121', 3966, 'village'),
                     (3993, 'Tarvastu', '', 3814, 'municipality'),
                     (3994, 'Kärstna', '', 3993, 'village'),
                     (3995, 'Mustla', '', 3993, 'smallborough'),
                     (3996, 'Kivilõppe', '69706', 3993, 'village'),
                     (3997, 'Jakobimõisa', '69705', 3993, 'village'),
                     (3998, 'Porsa', '69710', 3993, 'village'),
                     (3999, 'Riuma', '69736', 3993, 'village'),
                     (4000, 'Pahuvere', '69725', 3993, 'village'),
                     (4001, 'Kalbuse', '69737', 3993, 'village'),
                     (4002, 'Vanausse', '69713', 3993, 'village'),
                     (4003, 'Pikru', '69709', 3993, 'village'),
                     (4004, 'Kuressaare', '69708', 3993, 'village'),
                     (4005, 'Maltsa', '69731', 3993, 'village'),
                     (4006, 'Muksi', '69724', 3993, 'village'),
                     (4007, 'Ülensi', '69720', 3993, 'village'),
                     (4008, 'Vilimeeste', '69718', 3993, 'village'),
                     (4009, 'Koidu', '69707', 3993, 'village'),
                     (4010, 'Raassilla', '69722', 3993, 'village'),
                     (4011, 'Põrga', '69726', 3993, 'village'),
                     (4012, 'Tinnikuru', '69716', 3993, 'village'),
                     (4013, 'Unametsa', '69717', 3993, 'village'),
                     (4014, 'Vooru', '69733', 3993, 'village'),
                     (4015, 'Villa', '69719', 3993, 'village'),
                     (4016, 'Järveküla', '69732', 3993, 'village'),
                     (4017, 'Metsla', '69711', 3993, 'village'),
                     (4018, 'Suislepa', '', 3993, 'village'),
                     (4019, 'Veisjärve', '69729', 3993, 'village'),
                     (4020, 'Väluste', '69704', 3993, 'village'),
                     (4021, 'Tagamõisa', '69727', 3993, 'village'),
                     (4022, 'Marjamäe', '69734', 3993, 'village'),
                     (4023, 'Roosilla', '69730', 3993, 'village'),
                     (4024, 'Mõnnaste', '69735', 3993, 'village'),
                     (4025, 'Ämmuste', '69721', 3993, 'village'),
                     (4026, 'Kannuküla', '69728', 3993, 'village'),
                     (4027, 'Anikatsi', '69723', 3993, 'village'),
                     (4028, 'Sooviku', '69714', 3993, 'village'),
                     (4029, 'Saarepeedi', '', 3814, 'municipality'),
                     (4030, 'Peetrimõisa', '', 4029, 'village'),
                     (4031, 'Võistre', '', 4029, 'village'),
                     (4032, 'Karula', '', 4029, 'village'),
                     (4033, 'Moori', '70211', 4029, 'village'),
                     (4034, 'Tõnissaare', '71069', 4029, 'village'),
                     (4035, 'Auksi', '71064', 4029, 'village'),
                     (4036, 'Välgita', '', 4029, 'village'),
                     (4037, 'Taari', '71072', 4029, 'village'),
                     (4038, 'Aindu', '71063', 4029, 'village'),
                     (4039, 'Kokaviidika', '71071', 4029, 'village'),
                     (4040, 'Tobraselja', '71068', 4029, 'village'),
                     (4041, 'Paistu', '', 3814, 'municipality'),
                     (4042, 'Sultsi', '', 4041, 'village'),
                     (4043, 'Loodi', '', 4041, 'village'),
                     (4044, 'Intsu', '', 4041, 'village'),
                     (4045, 'Holstre', '', 4041, 'village'),
                     (4046, 'Rebase', '69610', 4041, 'village'),
                     (4047, 'Pulleritsu', '69609', 4041, 'village'),
                     (4048, 'Luiga', '69606', 4041, 'village'),
                     (4049, 'Aidu', '69604', 4041, 'village'),
                     (4050, 'Tömbi', '69608', 4041, 'village'),
                     (4051, 'Viisuküla', '69607', 4041, 'village'),
                     (4052, 'Kassi', '71052', 4041, 'village'),
                     (4053, 'Mustapali', '69618', 4041, 'village'),
                     (4054, 'Pirmastu', '69620', 4041, 'village'),
                     (4055, 'Lolu', '69617', 4041, 'village'),
                     (4056, 'Hendrikumõisa', '69612', 4041, 'village'),
                     (4057, 'Kõpu', '', 3814, 'municipality'),
                     (4058, 'Tipu', '', 4057, 'village'),
                     (4059, 'Uia', '71206', 4057, 'village'),
                     (4060, 'Supsi', '71205', 4057, 'village'),
                     (4061, 'Iia', '71210', 4057, 'village'),
                     (4062, 'Vanaveski', '71207', 4057, 'village'),
                     (4063, 'Laane', '71202', 4057, 'village'),
                     (4064, 'Kuninga', '69518', 4057, 'village'),
                     (4065, 'Punaküla', '71204', 4057, 'village'),
                     (4066, 'Seruküla', '71203', 4057, 'village'),
                     (4067, 'Kõo', '', 3814, 'municipality'),
                     (4068, 'Soomevere', '', 4067, 'village'),
                     (4069, 'Paaksima', '70607', 4067, 'village'),
                     (4070, 'Koksvere', '70604', 4067, 'village'),
                     (4071, 'Saviaugu', '70503', 4067, 'village'),
                     (4072, 'Pilistvere', '70502', 4067, 'village'),
                     (4073, 'Maalasti', '70608', 4067, 'village'),
                     (4074, 'Kirivere', '70506', 4067, 'village'),
                     (4075, 'Unakvere', '70508', 4067, 'village'),
                     (4076, 'Arjassaare', '70507', 4067, 'village'),
                     (4077, 'Arussaare', '70605', 4067, 'village'),
                     (4078, 'Paenasti', '70509', 4067, 'village'),
                     (4079, 'Kangrussaare', '70505', 4067, 'village'),
                     (4080, 'Loopre', '70504', 4067, 'village'),
                     (4081, 'Venevere', '70511', 4067, 'village'),
                     (4082, 'Soe', '', 3814, 'municipality'),
                     (4083, 'Võru', '', None, 'county'),
                     (4084, 'Vastseliina', '', 4083, 'municipality'),
                     (4085, 'Pari', '65258', 4084, 'village'),
                     (4086, 'Vana-Vastseliina', '65254', 4084, 'village'),
                     (4087, 'Lindora', '65224', 4084, 'village'),
                     (4088, 'Loosi', '65260', 4084, 'village'),
                     (4089, 'Plessi', '65328', 4084, 'village'),
                     (4090, 'Jeedasküla', '65212', 4084, 'village'),
                     (4091, 'Perametsa', '65234', 4084, 'village'),
                     (4092, 'Indra', '65259', 4084, 'village'),
                     (4093, 'Tsolli', '', 4084, 'village'),
                     (4094, 'Kerepäälse', '65217', 4084, 'village'),
                     (4095, 'Halla', '65204', 4084, 'village'),
                     (4096, 'Holsta', '65208', 4084, 'village'),
                     (4097, 'Raadi', '65237', 4084, 'village'),
                     (4098, 'Voki', '65257', 4084, 'village'),
                     (4099, 'Ortuma', '65231', 4084, 'village'),
                     (4100, 'Vatsa', '65255', 4084, 'village'),
                     (4101, 'Luhte', '65171', 4084, 'village'),
                     (4102, 'Kapera', '65216', 4084, 'village'),
                     (4103, 'Külaoru', '65223', 4084, 'village'),
                     (4104, 'Tellaste', '65247', 4084, 'village'),
                     (4105, 'Kõrve', '65221', 4084, 'village'),
                     (4106, 'Kündja', '65168', 4084, 'village'),
                     (4107, 'Tabina', '65246', 4084, 'village'),
                     (4108, 'Mutsu', '65226', 4084, 'village'),
                     (4109, 'Puutli', '65235', 4084, 'village'),
                     (4110, 'Kaagu', '65214', 4084, 'village'),
                     (4111, 'Kornitsa', '65219', 4084, 'village'),
                     (4112, 'Kirikumäe', '65218', 4084, 'village'),
                     (4113, 'Juraski', '65213', 4084, 'village'),
                     (4114, 'Heinasoo', '65205', 4084, 'village'),
                     (4115, 'Illi', '65210', 4084, 'village'),
                     (4116, 'Vana-Saaluse', '65253', 4084, 'village'),
                     (4117, 'Tallikeste', '65337', 4084, 'village'),
                     (4118, 'Viitka', '65256', 4084, 'village'),
                     (4119, 'Sutte', '65245', 4084, 'village'),
                     (4120, 'Kõo', '65165', 4084, 'village'),
                     (4121, 'Hinniala', '65206', 4084, 'village'),
                     (4122, 'Hinsa', '65207', 4084, 'village'),
                     (4123, 'Käpa', '65222', 4084, 'village'),
                     (4124, 'Saarde', '65239', 4084, 'village'),
                     (4125, 'Mäe-Kõoküla', '65227', 4084, 'village'),
                     (4126, 'Võru', '65620', 4083, 'town'),
                     (4127, 'Väimela', '65566', 4126, 'smallborough'),
                     (4128, 'Parksepa', '65509', 4126, 'smallborough'),
                     (4129, 'Võlsi', '', 4126, 'village'),
                     (4130, 'Roosisaare', '', 4126, 'village'),
                     (4131, 'Võrumõisa', '', 4126, 'village'),
                     (4132, 'Verijärve', '', 4126, 'village'),
                     (4133, 'Puiga', '', 4126, 'village'),
                     (4134, 'Kose', '', 4126, 'smallborough'),
                     (4135, 'Lompka', '65525', 4126, 'village'),
                     (4136, 'Sika', '', 4126, 'village'),
                     (4137, 'Hannuste', '65515', 4126, 'village'),
                     (4138, 'Käätso', '65524', 4126, 'village'),
                     (4139, 'Kusma', '65523', 4126, 'village'),
                     (4140, 'Nooska', '65531', 4126, 'village'),
                     (4141, 'Võrusoo', '65565', 4126, 'village'),
                     (4142, 'Kolepi', '65520', 4126, 'village'),
                     (4143, 'Vagula', '65553', 4126, 'village'),
                     (4144, 'Tagaküla', '65514', 4126, 'village'),
                     (4145, 'Kasaritsa', '65519', 4126, 'village'),
                     (4146, 'Väiso', '65503', 4126, 'village'),
                     (4147, 'Räpo', '65535', 4126, 'village'),
                     (4148, 'Umbsaare', '65538', 4126, 'village'),
                     (4149, 'Loosu', '65548', 4126, 'village'),
                     (4150, 'Juba', '65518', 4126, 'village'),
                     (4151, 'Mõisamäe', '65529', 4126, 'village'),
                     (4152, 'Palometsa', '65532', 4126, 'village'),
                     (4153, 'Vana-Nursi', '65540', 4126, 'village'),
                     (4154, 'Mõksi', '65530', 4126, 'village'),
                     (4155, 'Raiste', '65513', 4126, 'village'),
                     (4156, 'Tootsi', '65537', 4126, 'village'),
                     (4157, 'Meeliku', '65527', 4126, 'village'),
                     (4158, 'Kärnamäe', '65504', 4126, 'village'),
                     (4159, 'Lapi', '65505', 4126, 'village'),
                     (4160, 'Koloreino', '65521', 4126, 'village'),
                     (4161, 'Antsla', '', 4083, 'town'),
                     (4162, 'Vana-Antsla', '', 4161, 'smallborough'),
                     (4163, 'Tsooru', '', 4161, 'village'),
                     (4164, 'Säre', '', 4161, 'village'),
                     (4165, 'Kobela', '', 4161, 'smallborough'),
                     (4166, 'Kraavi', '66409', 4161, 'village'),
                     (4167, 'Kaika', '66421', 4161, 'village'),
                     (4168, 'Savilöövi', '66307', 4161, 'village'),
                     (4169, 'Anne', '66423', 4161, 'village'),
                     (4170, 'Antsu', '66424', 4161, 'village'),
                     (4171, 'Soome', '66415', 4161, 'village'),
                     (4172, 'Luhametsa', '66304', 4161, 'village'),
                     (4173, 'Madise', '66411', 4161, 'village'),
                     (4174, 'Oe', '66422', 4161, 'village'),
                     (4175, 'Kikkaoja', '66302', 4161, 'village'),
                     (4176, 'Taberlaane', '66417', 4161, 'village'),
                     (4177, 'Lusti', '66410', 4161, 'village'),
                     (4178, 'Litsmetsa', '66303', 4161, 'village'),
                     (4179, 'Mähkli', '66412', 4161, 'village'),
                     (4180, 'Jõepera', '66425', 4161, 'village'),
                     (4181, 'Ähijärve', '66420', 4161, 'village'),
                     (4182, 'Viirapalu', '66308', 4161, 'village'),
                     (4183, 'Haabsaare', '66405', 4161, 'village'),
                     (4184, 'Roosiku', '66306', 4161, 'village'),
                     (4185, 'Piisi', '66305', 4161, 'village'),
                     (4186, 'Kollino', '66408', 4161, 'village'),
                     (4187, 'Rimmi', '66414', 4161, 'village'),
                     (4188, 'Varstu', '', 4083, 'municipality'),
                     (4189, 'Punsa', '66107', 4188, 'village'),
                     (4190, 'Krabi', '66102', 4188, 'village'),
                     (4191, 'Vana-Roosa', '66109', 4188, 'village'),
                     (4192, 'Kangsti', '66103', 4188, 'village'),
                     (4193, 'Metstaga', '66106', 4188, 'village'),
                     (4194, 'Viru', '66309', 4188, 'village'),
                     (4195, 'Mutemetsa', '66114', 4188, 'village'),
                     (4196, 'Paganamaa', '66115', 4188, 'village'),
                     (4197, 'Hintsiko', '66110', 4188, 'village'),
                     (4198, 'Kõrgepalu', '66104', 4188, 'village'),
                     (4199, 'Laurimäe', '66111', 4188, 'village'),
                     (4200, 'Tagakolga', '66118', 4188, 'village'),
                     (4201, 'Harjuküla', '66120', 4188, 'village'),
                     (4202, 'Lüütsepa', '66113', 4188, 'village'),
                     (4203, 'Liguri', '66112', 4188, 'village'),
                     (4204, 'Soolätte', '66117', 4188, 'village'),
                     (4205, 'Raudsepa', '', 4188, 'village'),
                     (4206, 'Pähni', '66116', 4188, 'village'),
                     (4207, 'Sõmerpalu', '', 4083, 'municipality'),
                     (4208, 'Haava', '', 4207, 'village'),
                     (4209, 'Mustja', '66614', 4207, 'village'),
                     (4210, 'Leiso', '66634', 4207, 'village'),
                     (4211, 'Rummi', '66640', 4207, 'village'),
                     (4212, 'Udsali', '', 4207, 'village'),
                     (4213, 'Heeska', '66625', 4207, 'village'),
                     (4214, 'Kurenurme', '66631', 4207, 'village'),
                     (4215, 'Hargi', '66624', 4207, 'village'),
                     (4216, 'Mäekülä', '66615', 4207, 'village'),
                     (4217, 'Järvere', '66629', 4207, 'village'),
                     (4218, 'Linnamäe', '66635', 4207, 'village'),
                     (4219, 'Mustassaare', '66637', 4207, 'village'),
                     (4220, 'Horma', '66626', 4207, 'village'),
                     (4221, 'Pritsi', '66638', 4207, 'village'),
                     (4222, 'Haidaku', '66623', 4207, 'village'),
                     (4223, 'Osula', '66602', 4207, 'village'),
                     (4224, 'Majala', '66636', 4207, 'village'),
                     (4225, 'Hutita', '66627', 4207, 'village'),
                     (4226, 'Kärgula', '66632', 4207, 'village'),
                     (4227, 'Liiva', '66514', 4207, 'village'),
                     (4228, 'Kahro', '66617', 4207, 'village'),
                     (4229, 'Rauskapalu', '66639', 4207, 'village'),
                     (4230, 'Keema', '66511', 4207, 'village'),
                     (4231, 'Haamaste', '66616', 4207, 'village'),
                     (4232, 'Alakülä', '66620', 4207, 'village'),
                     (4233, 'Varese', '66642', 4207, 'village'),
                     (4234, 'Lakovitsa', '66633', 4207, 'village'),
                     (4235, 'Alapõdra', '66621', 4207, 'village'),
                     (4236, 'Punakülä', '66619', 4207, 'village'),
                     (4237, 'Lilli-Anne', '66613', 4207, 'village'),
                     (4238, 'Hänike', '66628', 4207, 'village'),
                     (4239, 'Rõuge', '', 4083, 'municipality'),
                     (4240, 'Hallimäe', '', 4239, 'village'),
                     (4241, 'Horsa', '', 4239, 'village'),
                     (4242, 'Kahru', '', 4239, 'village'),
                     (4243, 'Tüütsi', '66703', 4239, 'village'),
                     (4244, 'Rebäsemõisa', '66276', 4239, 'village'),
                     (4245, 'Pulli', '', 4239, 'village'),
                     (4246, 'Märdi', '66260', 4239, 'village'),
                     (4247, 'Laossaarõ', '66246', 4239, 'village'),
                     (4248, 'Savioru', '66285', 4239, 'village'),
                     (4249, 'Suurõ-Ruuga', '66292', 4239, 'village'),
                     (4250, 'Nilbõ', '66262', 4239, 'village'),
                     (4251, 'Vanamõisa', '66707', 4239, 'village'),
                     (4252, 'Tallima', '66293', 4239, 'village'),
                     (4253, 'Simmuli', '66288', 4239, 'village'),
                     (4254, 'Hapsu', '66214', 4239, 'village'),
                     (4255, 'Lauri', '66247', 4239, 'village'),
                     (4256, 'Sikalaanõ', '66287', 4239, 'village'),
                     (4257, 'Haki', '66209', 4239, 'village'),
                     (4258, 'Raudsepä', '66274', 4239, 'village'),
                     (4259, 'Soemõisa', '66290', 4239, 'village'),
                     (4260, 'Tiidu', '66296', 4239, 'village'),
                     (4261, 'Muhkamõtsa', '66255', 4239, 'village'),
                     (4262, 'Mõõlu', '66259', 4239, 'village'),
                     (4263, 'Kokõjüri', '66237', 4239, 'village'),
                     (4264, 'Kuuda', '66243', 4239, 'village'),
                     (4265, 'Kiidi', '66234', 4239, 'village'),
                     (4266, 'Möldri', '', 4239, 'village'),
                     (4267, 'Püssä', '66272', 4239, 'village'),
                     (4268, 'Kogrõ', '66235', 4239, 'village'),
                     (4269, 'Mikita', '', 4239, 'village'),
                     (4270, 'Vadsa', '66706', 4239, 'village'),
                     (4271, 'Viitina', '66711', 4239, 'village'),
                     (4272, 'Järvekülä', '66223', 4239, 'village'),
                     (4273, 'Hinu', '66217', 4239, 'village'),
                     (4274, 'Jugu', '66222', 4239, 'village'),
                     (4275, 'Kaugu', '66231', 4239, 'village'),
                     (4276, 'Soomõoru', '66291', 4239, 'village'),
                     (4277, 'Sandisuu', '66284', 4239, 'village'),
                     (4278, 'Matsi', '', 4239, 'village'),
                     (4279, 'Viliksaarõ', '66708', 4239, 'village'),
                     (4280, 'Nogu', '66263', 4239, 'village'),
                     (4281, 'Järvepalu', '66224', 4239, 'village'),
                     (4282, 'Rasva', '66273', 4239, 'village'),
                     (4283, 'Ahitsa', '66206', 4239, 'village'),
                     (4284, 'Väiku-Ruuga', '66709', 4239, 'village'),
                     (4285, 'Sadramõtsa', '66282', 4239, 'village'),
                     (4286, 'Handimiku', '66213', 4239, 'village'),
                     (4287, 'Augli', '66207', 4239, 'village'),
                     (4288, 'Aabra', '66205', 4239, 'village'),
                     (4289, 'Saarlasõ', '66281', 4239, 'village'),
                     (4290, 'Kurgjärve', '66241', 4239, 'village'),
                     (4291, 'Tilgu', '66297', 4239, 'village'),
                     (4292, 'Hansi', '65516', 4239, 'village'),
                     (4293, 'Toodsi', '', 4239, 'village'),
                     (4294, 'Rebäse', '', 4239, 'village'),
                     (4295, 'Kurvitsa', '66242', 4239, 'village'),
                     (4296, 'Hurda', '', 4239, 'village'),
                     (4297, 'Murdõmäe', '66257', 4239, 'village'),
                     (4298, 'Heedu', '66215', 4239, 'village'),
                     (4299, 'Muna', '66256', 4239, 'village'),
                     (4300, 'Tialasõ', '66295', 4239, 'village'),
                     (4301, 'Petrakuudi', '66267', 4239, 'village'),
                     (4302, 'Roobi', '66279', 4239, 'village'),
                     (4303, 'Kähri', '66244', 4239, 'village'),
                     (4304, 'Tsirgupalu', '66701', 4239, 'village'),
                     (4305, 'Nursi', '66712', 4239, 'village'),
                     (4306, 'Põru', '66271', 4239, 'village'),
                     (4307, 'Paaburissa', '66265', 4239, 'village'),
                     (4308, 'Utessuu', '66705', 4239, 'village'),
                     (4309, 'Karaski', '66229', 4239, 'village'),
                     (4310, 'Pugõstu', '66268', 4239, 'village'),
                     (4311, 'Kaluka', '66228', 4239, 'village'),
                     (4312, 'Sänna', '66710', 4239, 'village'),
                     (4313, 'Kolga', '66239', 4239, 'village'),
                     (4314, 'Tsutsu', '66702', 4239, 'village'),
                     (4315, 'Lutika', '66250', 4239, 'village'),
                     (4316, 'Paeboja', '66266', 4239, 'village'),
                     (4317, 'Põdra', '66270', 4239, 'village'),
                     (4318, 'Ruuksu', '66280', 4239, 'village'),
                     (4319, 'Kokõ', '66236', 4239, 'village'),
                     (4320, 'Kellämäe', '66233', 4239, 'village'),
                     (4321, 'Kavõldi', '66232', 4239, 'village'),
                     (4322, 'Saki', '66283', 4239, 'village'),
                     (4323, 'Kokõmäe', '66238', 4239, 'village'),
                     (4324, 'Heibri', '66216', 4239, 'village'),
                     (4325, 'Taudsa', '66294', 4239, 'village'),
                     (4326, 'Liivakupalu', '66248', 4239, 'village'),
                     (4327, 'Haabsilla', '66208', 4239, 'village'),
                     (4328, 'Kadõni', '66225', 4239, 'village'),
                     (4329, 'Ortumäe', '66264', 4239, 'village'),
                     (4330, 'Pärlijõe', '66211', 4239, 'village'),
                     (4331, 'Soekõrdsi', '66289', 4239, 'village'),
                     (4332, 'Tindi', '66298', 4239, 'village'),
                     (4333, 'Hotõmäe', '66218', 4239, 'village'),
                     (4334, 'Karba', '66230', 4239, 'village'),
                     (4335, 'Muduri', '66254', 4239, 'village'),
                     (4336, 'Kängsepä', '66245', 4239, 'village'),
                     (4337, 'Jaanipeebu', '66221', 4239, 'village'),
                     (4338, 'Lükkä', '66251', 4239, 'village'),
                     (4339, 'Kuklasõ', '66240', 4239, 'village'),
                     (4340, 'Härämäe', '66220', 4239, 'village'),
                     (4341, 'Riitsilla', '66277', 4239, 'village'),
                     (4342, 'Ristemäe', '66278', 4239, 'village'),
                     (4343, 'Mõniste', '', 4083, 'municipality'),
                     (4344, 'Hürova', '', 4343, 'village'),
                     (4345, 'Karisöödi', '66005', 4343, 'village'),
                     (4346, 'Koemetsa', '66006', 4343, 'village'),
                     (4347, 'Peebu', '66007', 4343, 'village'),
                     (4348, 'Parmupalu', '66015', 4343, 'village'),
                     (4349, 'Kallaste', '', 4343, 'village'),
                     (4350, 'Singa', '66010', 4343, 'village'),
                     (4351, 'Saru', '66009', 4343, 'village'),
                     (4352, 'Sakurgi', '66008', 4343, 'village'),
                     (4353, 'Tiitsa', '66011', 4343, 'village'),
                     (4354, 'Tursa', '66012', 4343, 'village'),
                     (4355, 'Tundu', '66016', 4343, 'village'),
                     (4356, 'Kuutsi', '66018', 4343, 'village'),
                     (4357, 'Hüti', '66014', 4343, 'village'),
                     (4358, 'Villike', '66017', 4343, 'village'),
                     (4359, 'Vastse-Roosa', '66013', 4343, 'village'),
                     (4360, 'Haanja', '', 4083, 'municipality'),
                     (4361, 'Pausakunnu', '65131', 4360, 'village'),
                     (4362, 'Andsumäe', '', 4360, 'village'),
                     (4363, 'Mustahamba', '', 4360, 'village'),
                     (4364, 'Mäe-Suhka', '65128', 4360, 'village'),
                     (4365, 'Mäe-Tilga', '65129', 4360, 'village'),
                     (4366, 'Tsiamäe', '65144', 4360, 'village'),
                     (4367, 'Soodi', '65142', 4360, 'village'),
                     (4368, 'Trolla', '65143', 4360, 'village'),
                     (4369, 'Purka', '65137', 4360, 'village'),
                     (4370, 'Posti', '65183', 4360, 'village'),
                     (4371, 'Kirbu', '65118', 4360, 'village'),
                     (4372, 'Vaarkali', '', 4360, 'village'),
                     (4373, 'Kääraku', '65120', 4360, 'village'),
                     (4374, 'Tsiiruli', '65196', 4360, 'village'),
                     (4375, 'Haavistu', '65105', 4360, 'village'),
                     (4376, 'Tsilgutaja', '65198', 4360, 'village'),
                     (4377, 'Lillimõisa', '65169', 4360, 'village'),
                     (4378, 'Saluora', '65190', 4360, 'village'),
                     (4379, 'Märdimiku', '65177', 4360, 'village'),
                     (4380, 'Rusa', '65189', 4360, 'village'),
                     (4381, 'Vastsekivi', '65191', 4360, 'village'),
                     (4382, 'Käänu', '65167', 4360, 'village'),
                     (4383, 'Holdi', '', 4360, 'village'),
                     (4384, 'Vaalimäe', '65148', 4360, 'village'),
                     (4385, 'Tõnkova', '65166', 4360, 'village'),
                     (4386, 'Mäe-Palo', '65176', 4360, 'village'),
                     (4387, 'Pressi', '65136', 4360, 'village'),
                     (4388, 'Kergatsi', '65117', 4360, 'village'),
                     (4389, 'Kuiandi', '65162', 4360, 'village'),
                     (4390, 'Ihatsi', '65109', 4360, 'village'),
                     (4391, 'Kaldemäe', '65114', 4360, 'village'),
                     (4392, 'Raagi', '65188', 4360, 'village'),
                     (4393, 'Horoski', '65107', 4360, 'village'),
                     (4394, 'Pillardi', '65182', 4360, 'village'),
                     (4395, 'Külma', '65121', 4360, 'village'),
                     (4396, 'Kaaratautsa', '65113', 4360, 'village'),
                     (4397, 'Sarise', '65192', 4360, 'village'),
                     (4398, 'Saika', '', 4360, 'village'),
                     (4399, 'Hulaku', '65156', 4360, 'village'),
                     (4400, 'Palanumäe', '65130', 4360, 'village'),
                     (4401, 'Preeksa', '65184', 4360, 'village'),
                     (4402, 'Naapka', '65178', 4360, 'village'),
                     (4403, 'Kriguli', '65161', 4360, 'village'),
                     (4404, 'Ala-Suhka', '65103', 4360, 'village'),
                     (4405, 'Sormuli', '65194', 4360, 'village'),
                     (4406, 'Vihkla', '65193', 4360, 'village'),
                     (4407, 'Kuklase', '65163', 4360, 'village'),
                     (4408, 'Palli', '65179', 4360, 'village'),
                     (4409, 'Ruusmäe', '65102', 4360, 'village'),
                     (4410, 'Loogamäe', '65170', 4360, 'village'),
                     (4411, 'Meelaku', '65125', 4360, 'village'),
                     (4412, 'Murati', '65174', 4360, 'village'),
                     (4413, 'Uue-Saaluse', '65147', 4360, 'village'),
                     (4414, 'Lüütsepä', '65172', 4360, 'village'),
                     (4415, 'Ala-Palo', '65152', 4360, 'village'),
                     (4416, 'Mallika', '65124', 4360, 'village'),
                     (4417, 'Mahtja', '65123', 4360, 'village'),
                     (4418, 'Kaloga', '65116', 4360, 'village'),
                     (4419, 'Vungi', '65181', 4360, 'village'),
                     (4420, 'Ala-Tilga', '65104', 4360, 'village'),
                     (4421, 'Resto', '65138', 4360, 'village'),
                     (4422, 'Leoski', '65122', 4360, 'village'),
                     (4423, 'Palujüri', '65180', 4360, 'village'),
                     (4424, 'Tummelka', '65146', 4360, 'village'),
                     (4425, 'Vänni', '65151', 4360, 'village'),
                     (4426, 'Hanija', '65155', 4360, 'village'),
                     (4427, 'Plaksi', '65135', 4360, 'village'),
                     (4428, 'Kilomani', '65159', 4360, 'village'),
                     (4429, 'Piipsemäe', '65133', 4360, 'village'),
                     (4430, 'Luutsniku', '65110', 4360, 'village'),
                     (4431, 'Puspuri', '65186', 4360, 'village'),
                     (4432, 'Hämkoti', '65108', 4360, 'village'),
                     (4433, 'Simula', '65141', 4360, 'village'),
                     (4434, 'Vorstimäe', '65197', 4360, 'village'),
                     (4435, 'Miilimäe', '65126', 4360, 'village'),
                     (4436, 'Kuura', '65164', 4360, 'village'),
                     (4437, 'Kõomäe', '65119', 4360, 'village'),
                     (4438, 'Söödi', '65195', 4360, 'village'),
                     (4439, 'Plaani', '65134', 4360, 'village'),
                     (4440, 'Vakari', '65149', 4360, 'village'),
                     (4441, 'Peedo', '65132', 4360, 'village'),
                     (4442, 'Tuuka', '65199', 4360, 'village'),
                     (4443, 'Pundi', '65185', 4360, 'village'),
                     (4444, 'Kotka', '65160', 4360, 'village'),
                     (4445, 'Urvaste', '', 4083, 'municipality'),
                     (4446, 'Kuldre', '', 4445, 'village'),
                     (4447, 'Lümatu', '66515', 4445, 'village'),
                     (4448, 'Uhtjärve', '66508', 4445, 'village'),
                     (4449, 'Visela', '66510', 4445, 'village'),
                     (4450, 'Kirikuküla', '66512', 4445, 'village'),
                     (4451, 'Pihleni', '66506', 4445, 'village'),
                     (4452, 'Vaabina', '66519', 4445, 'village'),
                     (4453, 'Uue-Antsla', '66509', 4445, 'village'),
                     (4454, 'Koigu', '66513', 4445, 'village'),
                     (4455, 'Kassi', '66504', 4445, 'village'),
                     (4456, 'Kõlbi', '66505', 4445, 'village'),
                     (4457, 'Toku', '66507', 4445, 'village'),
                     (4458, 'Ruhingu', '66516', 4445, 'village'),
                     (4459, 'Lasva', '', 4083, 'municipality'),
                     (4460, 'Nõnova', '65230', 4459, 'village'),
                     (4461, 'Lauga', '65506', 4459, 'village'),
                     (4462, 'Listaku', '', 4459, 'village'),
                     (4463, 'Kõrgessaare', '65404', 4459, 'village'),
                     (4464, 'Kaku', '', 4459, 'village'),
                     (4465, 'Kääpa', '65545', 4459, 'village'),
                     (4466, 'Puusepa', '65551', 4459, 'village'),
                     (4467, 'Mõrgi', '65549', 4459, 'village'),
                     (4468, 'Peraküla', '65510', 4459, 'village'),
                     (4469, 'Noodasküla', '65229', 4459, 'village'),
                     (4470, 'Kannu', '65544', 4459, 'village'),
                     (4471, 'Saaremaa', '65240', 4459, 'village'),
                     (4472, 'Kühmamäe', '65405', 4459, 'village'),
                     (4473, 'Madala', '65406', 4459, 'village'),
                     (4474, 'Tohkri', '65249', 4459, 'village'),
                     (4475, 'Oleski', '65507', 4459, 'village'),
                     (4476, 'Mäessaare', '65407', 4459, 'village'),
                     (4477, 'Tammsaare', '65413', 4459, 'village'),
                     (4478, 'Rusima', '65412', 4459, 'village'),
                     (4479, 'Lehemetsa', '65546', 4459, 'village'),
                     (4480, 'Sooküla', '65244', 4459, 'village'),
                     (4481, 'Voki-Tamme', '65415', 4459, 'village'),
                     (4482, 'Tüütsmäe', '65251', 4459, 'village'),
                     (4483, 'Pindi', '65410', 4459, 'village'),
                     (4484, 'Tiri', '65414', 4459, 'village'),
                     (4485, 'Villa', '', 4459, 'village'),
                     (4486, 'Pässä', '65411', 4459, 'village'),
                     (4487, 'Hellekunnu', '65402', 4459, 'village'),
                     (4488, 'Otsa', '65408', 4459, 'village'),
                     (4489, 'Pikasilla', '65511', 4459, 'village'),
                     (4490, 'Pikakannu', '65409', 4459, 'village'),
                     (4491, 'Pille', '65512', 4459, 'village'),
                     (4492, 'Tsolgo', '65552', 4459, 'village'),
                     (4493, 'Husari', '65403', 4459, 'village'),
                     (4494, 'Paidra', '65508', 4459, 'village'),
                     (4495, 'Misso', '', 4083, 'municipality'),
                     (4496, 'Häärmäni', '65209', 4495, 'village'),
                     (4497, 'Põnni', '65042', 4495, 'village'),
                     (4498, 'Mokra', '65020', 4495, 'village'),
                     (4499, 'Kärinä', '65041', 4495, 'village'),
                     (4500, 'Sapi', '65242', 4495, 'village'),
                     (4501, 'Pupli', '65026', 4495, 'village'),
                     (4502, 'Tserebi', '65039', 4495, 'village'),
                     (4503, 'Tiastõ', '65036', 4495, 'village'),
                     (4504, 'Tiilige', '65037', 4495, 'village'),
                     (4505, 'Ritsiko', '65029', 4495, 'village'),
                     (4506, 'Kriiva', '65013', 4495, 'village'),
                     (4507, 'Põrstõ', '65027', 4495, 'village'),
                     (4508, 'Suurõsuu', '65035', 4495, 'village'),
                     (4509, 'Lütä', '65018', 4495, 'village'),
                     (4510, 'Tika', '65248', 4495, 'village'),
                     (4511, 'Määsi', '65045', 4495, 'village'),
                     (4512, 'Kaubi', '65006', 4495, 'village'),
                     (4513, 'Parmu', '65023', 4495, 'village'),
                     (4514, 'Hürsi', '65158', 4495, 'village'),
                     (4515, 'Savimäe', '65033', 4495, 'village'),
                     (4516, 'Savioja', '', 4495, 'village'),
                     (4517, 'Korgõssaarõ', '65010', 4495, 'village'),
                     (4518, 'Mauri', '65225', 4495, 'village'),
                     (4519, 'Horosuu', '65005', 4495, 'village'),
                     (4520, 'Pruntova', '65024', 4495, 'village'),
                     (4521, 'Tsiistre', '65002', 4495, 'village'),
                     (4522, 'Laisi', '65016', 4495, 'village'),
                     (4523, 'Kurõ', '65014', 4495, 'village'),
                     (4524, 'Hino', '65004', 4495, 'village'),
                     (4525, 'Pältre', '65236', 4495, 'village'),
                     (4526, 'Koorla', '65009', 4495, 'village'),
                     (4527, 'Muraski', '65021', 4495, 'village'),
                     (4528, 'Siksälä', '65034', 4495, 'village'),
                     (4529, 'Napi', '65022', 4495, 'village'),
                     (4530, 'Kossa', '65012', 4495, 'village'),
                     (4531, 'Kiviora', '65008', 4495, 'village'),
                     (4532, 'Väiko-Tiilige', '65040', 4495, 'village'),
                     (4533, 'Käbli', '65015', 4495, 'village'),
                     (4534, 'Saagri', '', 4495, 'village'),
                     (4535, 'Möldre', '65228', 4495, 'village'),
                     (4536, 'Kundsa', '65220', 4495, 'village'),
                     (4537, 'Hindsa', '65003', 4495, 'village'),
                     (4538, 'Kimalasõ', '65007', 4495, 'village'),
                     (4539, 'Rammuka', '65028', 4495, 'village'),
                     (4540, 'Saagrimäe', '65031', 4495, 'village'),
                     (4541, 'Sakudi', '65032', 4495, 'village'),
                     (4542, 'Pedejä', '65233', 4495, 'village'),
                     (4543, 'Leimani', '65017', 4495, 'village'),
                     (4544, 'Missokülä', '65019', 4495, 'village'),
                     (4545, 'Sandi', '65043', 4495, 'village'),
                     (4546, 'Meremäe', '', 4083, 'municipality'),
                     (4547, 'Obinitsa', '', 4546, 'village'),
                     (4548, 'Kõõru', '65371', 4546, 'village'),
                     (4549, 'Vinski', '65352', 4546, 'village'),
                     (4550, 'Vaaksaarõ', '65350', 4546, 'village'),
                     (4551, 'Ruutsi', '65333', 4546, 'village'),
                     (4552, 'Teterüvä', '65339', 4546, 'village'),
                     (4553, 'Tuulova', '65347', 4546, 'village'),
                     (4554, 'Martsina', '65375', 4546, 'village'),
                     (4555, 'Võmmorski', '65391', 4546, 'village'),
                     (4556, 'Viro', '65353', 4546, 'village'),
                     (4557, 'Antkruva', '65357', 4546, 'village'),
                     (4558, 'Lutja', '65316', 4546, 'village'),
                     (4559, 'Ostrova', '65322', 4546, 'village'),
                     (4560, 'Raotu', '65332', 4546, 'village'),
                     (4561, 'Tessova', '65385', 4546, 'village'),
                     (4562, 'Härmä', '65361', 4546, 'village'),
                     (4563, 'Veretinä', '65390', 4546, 'village'),
                     (4564, 'Lindsi', '65373', 4546, 'village'),
                     (4565, 'Karamsina', '65365', 4546, 'village'),
                     (4566, 'Lepä', '65315', 4546, 'village'),
                     (4567, 'Paklova', '65323', 4546, 'village'),
                     (4568, 'Kiiova', '65366', 4546, 'village'),
                     (4569, 'Miku', '65378', 4546, 'village'),
                     (4570, 'Jaanimäe', '', 4546, 'village'),
                     (4571, 'Väiko-Härmä', '65354', 4546, 'village'),
                     (4572, 'Treiali', '65343', 4546, 'village'),
                     (4573, 'Triginä', '65344', 4546, 'village'),
                     (4574, 'Kuksina', '65314', 4546, 'village'),
                     (4575, 'Pelsi', '65327', 4546, 'village'),
                     (4576, 'Kasakova', '65308', 4546, 'village'),
                     (4577, 'Tsumba', '65386', 4546, 'village'),
                     (4578, 'Tedre', '65384', 4546, 'village'),
                     (4579, 'Marinova', '65317', 4546, 'village'),
                     (4580, 'Rokina', '65381', 4546, 'village'),
                     (4581, 'Kiislova', '65311', 4546, 'village'),
                     (4582, 'Kuigõ', '65313', 4546, 'village'),
                     (4583, 'Tsergondõ', '65345', 4546, 'village'),
                     (4584, 'Tääglova', '65388', 4546, 'village'),
                     (4585, 'Korski', '65369', 4546, 'village'),
                     (4586, 'Palandõ', '65324', 4546, 'village'),
                     (4587, 'Juusa', '65364', 4546, 'village'),
                     (4588, 'Miikse', '65319', 4546, 'village'),
                     (4589, 'Serga', '65334', 4546, 'village'),
                     (4590, 'Tsirgu', '65346', 4546, 'village'),
                     (4591, 'Navikõ', '65379', 4546, 'village'),
                     (4592, 'Küllätüvä', '65372', 4546, 'village'),
                     (4593, 'Ala-Tsumba', '65356', 4546, 'village'),
                     (4594, 'Ermakova', '65358', 4546, 'village'),
                     (4595, 'Maaslova', '65374', 4546, 'village'),
                     (4596, 'Kusnetsova', '65370', 4546, 'village'),
                     (4597, 'Kiksova', '65367', 4546, 'village'),
                     (4598, 'Ulaskova', '65348', 4546, 'village'),
                     (4599, 'Sirgova', '65335', 4546, 'village'),
                     (4600, 'Sulbi', '', 4546, 'village'),
                     (4601, 'Paloveere', '', 4546, 'village'),
                     (4602, 'Tiirhanna', '65340', 4546, 'village'),
                     (4603, 'Tuplova', '65387', 4546, 'village'),
                     (4604, 'Tobrova', '65342', 4546, 'village'),
                     (4605, 'Väiko-Serga', '65355', 4546, 'village'),
                     (4606, 'Talka', '65383', 4546, 'village'),
                     (4607, 'Jõksi', '65305', 4546, 'village'),
                     (4608, 'Hilläkeste', '65303', 4546, 'village'),
                     (4609, 'Tiklasõ', '65341', 4546, 'village'),
                     (4610, 'Masluva', '65376', 4546, 'village'),
                     (4611, 'Pliia', '65329', 4546, 'village'),
                     (4612, 'Kalatsova', '65306', 4546, 'village'),
                     (4613, 'Klistina', '65368', 4546, 'village'),
                     (4614, 'Vasla', '65389', 4546, 'village'),
                     (4615, 'Helbi', '65359', 4546, 'village'),
                     (4616, 'Hilana', '65360', 4546, 'village'),
                     (4617, 'Melso', '65377', 4546, 'village'),
                     (4618, 'Kangavitsa', '65307', 4546, 'village'),
                     (4619, 'Keerba', '65310', 4546, 'village'),
                     (4620, 'Merekülä', '65318', 4546, 'village'),
                     (4621, 'Puista', '65331', 4546, 'village'),
                     (4622, 'Kitsõ', '65312', 4546, 'village'),
                     (4623, 'Olehkova', '65321', 4546, 'village'),
                     (4624, 'Palo', '65325', 4546, 'village'),
                     (4625, 'Ignasõ', '65362', 4546, 'village'),
                     (4626, 'Poksa', '65330', 4546, 'village'),
                     (4627, 'Seretsüvä', '65382', 4546, 'village'),
                     (4628, 'Tepia', '65338', 4546, 'village'),
                     (4629, 'Kastamara', '65309', 4546, 'village'),
                     (4630, 'Polovina', '65380', 4546, 'village'),
                     (4631, 'Uusvada', '65349', 4546, 'village'),
                     (4632, 'Kirumpää', '', 4083, 'municipality'),
                     (4633, 'Navi', '', 4083, 'municipality'),
                     (4634, 'Meegomäe', '', 4083, 'municipality')]

PLACES = {}
COUNTIES = []


def doit(lst):
    todo = []
    for id, name, zip_code, parent_id, type in lst:
        if parent_id is None:
            assert type == "county"
            p = Place(name, type, zip_code, None, [])
            PLACES[id] = p
            COUNTIES.append(p)
        elif (parent := PLACES.get(parent_id, None)) is not None:
            p = Place(name, type, zip_code, parent, [])
            PLACES[id] = p
            parent.children.append(p)
        else:
            todo.append((id, name, zip_code, parent_id, type))
            continue
    return todo


todo = doit(unresolved_places)
while len(todo) > 0:
    todo = doit(todo)

PLACES = list(PLACES.values())
